@@ -23,6 +23,7 @@ import org.apache.inlong.agent.utils.AgentUtils;
 import org.apache.inlong.agent.utils.DateTransUtils;
 import org.apache.inlong.common.enums.InstanceStateEnum;
 import org.apache.inlong.common.enums.TaskStateEnum;
+import org.apache.inlong.common.enums.TaskTypeEnum;
 import org.apache.inlong.common.pojo.agent.DataConfig;
 
 import com.google.gson.Gson;
@@ -32,18 +33,33 @@ import org.slf4j.LoggerFactory;
 import java.text.ParseException;
 import java.util.TimeZone;
 
+import static java.util.Objects.requireNonNull;
 import static org.apache.inlong.agent.constant.CommonConstants.DEFAULT_PROXY_INLONG_GROUP_ID;
 import static org.apache.inlong.agent.constant.CommonConstants.DEFAULT_PROXY_INLONG_STREAM_ID;
 import static org.apache.inlong.agent.constant.CommonConstants.PROXY_INLONG_GROUP_ID;
 import static org.apache.inlong.agent.constant.CommonConstants.PROXY_INLONG_STREAM_ID;
 import static org.apache.inlong.agent.constant.TaskConstants.TASK_RETRY;
 import static org.apache.inlong.agent.constant.TaskConstants.TASK_STATE;
+import static org.apache.inlong.agent.constant.TaskConstants.TASK_TYPE;
 
 /**
  * job profile which contains details describing properties of one job.
  */
 public class TaskProfile extends AbstractConfiguration {
 
+    public static final String SQL_TASK = "org.apache.inlong.agent.plugin.task.logcollection.SQLTask";
+    public static final String FILE_TASK = "org.apache.inlong.agent.plugin.task.logcollection.local.FileTask";
+    public static final String COS_TASK = "org.apache.inlong.agent.plugin.task.logcollection.cos.COSTask";
+    public static final String KAFKA_TASK = "org.apache.inlong.agent.plugin.task.KafkaTask";
+    public static final String PULSAR_TASK = "org.apache.inlong.agent.plugin.task.PulsarTask";
+    public static final String MONGODB_TASK = "org.apache.inlong.agent.plugin.task.MongoDBTask";
+    public static final String ORACLE_TASK = "org.apache.inlong.agent.plugin.task.OracleTask";
+    public static final String REDIS_TASK = "org.apache.inlong.agent.plugin.task.RedisTask";
+    public static final String POSTGRESQL_TASK = "org.apache.inlong.agent.plugin.task.PostgreSQLTask";
+    public static final String MQTT_TASK = "org.apache.inlong.agent.plugin.task.MqttTask";
+    public static final String SQLSERVER_TASK = "org.apache.inlong.agent.plugin.task.SQLServerTask";
+    public static final String MOCK_TASK = "org.apache.inlong.agent.plugin.task.MockTask";
+
     private static final Gson GSON = new Gson();
     private static final Logger logger = LoggerFactory.getLogger(TaskProfile.class);
 
@@ -57,6 +73,39 @@ public class TaskProfile extends AbstractConfiguration {
         return TaskProfileDto.convertToTaskProfile(dataConfig);
     }
 
+    public String getTaskClass() {
+        TaskTypeEnum taskType = TaskTypeEnum.getTaskType(getInt(TASK_TYPE, TaskTypeEnum.FILE.getType()));
+        switch (requireNonNull(taskType)) {
+            case SQL:
+                return SQL_TASK;
+            case FILE:
+                return FILE_TASK;
+            case KAFKA:
+                return KAFKA_TASK;
+            case PULSAR:
+                return PULSAR_TASK;
+            case POSTGRES:
+                return POSTGRESQL_TASK;
+            case ORACLE:
+                return ORACLE_TASK;
+            case SQLSERVER:
+                return SQLSERVER_TASK;
+            case MONGODB:
+                return MONGODB_TASK;
+            case REDIS:
+                return REDIS_TASK;
+            case MQTT:
+                return MQTT_TASK;
+            case COS:
+                return COS_TASK;
+            case MOCK:
+                return MOCK_TASK;
+            default:
+                logger.error("invalid task type {}", taskType);
+                return null;
+        }
+    }
+
     public String getTaskId() {
         return get(TaskConstants.TASK_ID);
     }
@@ -65,10 +114,6 @@ public class TaskProfile extends AbstractConfiguration {
         return get(TaskConstants.TASK_CYCLE_UNIT);
     }
 
-    public String getTimeOffset() {
-        return get(TaskConstants.TASK_FILE_TIME_OFFSET, "");
-    }
-
     public String getTimeZone() {
         return get(TaskConstants.TASK_TIME_ZONE);
     }
@@ -85,14 +130,6 @@ public class TaskProfile extends AbstractConfiguration {
         return getBoolean(TASK_RETRY, false);
     }
 
-    public String getTaskClass() {
-        return get(TaskConstants.TASK_CLASS);
-    }
-
-    public void setTaskClass(String className) {
-        set(TaskConstants.TASK_CLASS, className);
-    }
-
     public String getInlongGroupId() {
         return get(PROXY_INLONG_GROUP_ID, DEFAULT_PROXY_INLONG_GROUP_ID);
     }
@@ -119,7 +156,7 @@ public class TaskProfile extends AbstractConfiguration {
      */
     @Override
     public boolean allRequiredKeyExist() {
-        return hasKey(TaskConstants.TASK_ID) && hasKey(TaskConstants.TASK_SOURCE)
+        return hasKey(TaskConstants.TASK_ID)
                 && hasKey(TaskConstants.TASK_SINK) && hasKey(TaskConstants.TASK_CHANNEL)
                 && hasKey(TaskConstants.TASK_GROUP_ID) && hasKey(TaskConstants.TASK_STREAM_ID);
     }
@@ -128,11 +165,9 @@ public class TaskProfile extends AbstractConfiguration {
         return GSON.toJson(getConfigStorage());
     }
 
-    public InstanceProfile createInstanceProfile(String instanceClass, String fileName, String cycleUnit,
-            String dataTime,
+    public InstanceProfile createInstanceProfile(String fileName, String cycleUnit, String dataTime,
             long fileUpdateTime) {
         InstanceProfile instanceProfile = InstanceProfile.parseJsonStr(toJsonStr());
-        instanceProfile.setInstanceClass(instanceClass);
         instanceProfile.setInstanceId(fileName);
         instanceProfile.setSourceDataTime(dataTime);
         Long sinkDataTime = 0L;
