@@ -25,8 +25,6 @@ public class FetcherConstants {
     public static final String AGENT_FETCHER_INTERVAL = "agent.fetcher.interval";
     public static final int DEFAULT_AGENT_FETCHER_INTERVAL = 60;
 
-    public static final String AGENT_HEARTBEAT_INTERVAL = "agent.heartbeat.interval";
-    public static final int DEFAULT_AGENT_HEARTBEAT_INTERVAL = 10;
     public static final String AGENT_MANAGER_REQUEST_TIMEOUT = "agent.manager.request.timeout";
     // default is 30s
     public static final int DEFAULT_AGENT_MANAGER_REQUEST_TIMEOUT = 30;
@@ -38,8 +36,9 @@ public class FetcherConstants {
     public static final String DEFAULT_AGENT_MANAGER_VIP_HTTP_PREFIX_PATH = "/inlong/manager/openapi";
 
     public static final String AGENT_MANAGER_TASK_HTTP_PATH = "agent.manager.task.http.path";
-    public static final String DEFAULT_AGENT_MANAGER_TASK_HTTP_PATH = "/agent/reportAndGetTask";
-    public static final String DEFAULT_AGENT_MANAGER_CONFIG_HTTP_PATH = "/agent/getExistTaskConfig";
+    public static final String DEFAULT_AGENT_MANAGER_EXIST_TASK_HTTP_PATH = "/agent/getExistTaskConfig";
+    public static final String AGENT_MANAGER_CONFIG_HTTP_PATH = "agent.manager.config.http.path";
+    public static final String DEFAULT_AGENT_MANAGER_CONFIG_HTTP_PATH = "/agent/getConfig";
 
     public static final String INSTALLER_MANAGER_CONFIG_HTTP_PATH = "installer.manager.config.http.path";
     public static final String DEFAULT_INSTALLER_MANAGER_CONFIG_HTTP_PATH = "/installer/getConfig";
@@ -51,7 +50,6 @@ public class FetcherConstants {
 
     public static final int AGENT_HTTP_SUCCESS_CODE = 200;
 
-    public static final String AGENT_MANAGER_RETURN_PARAM_IP = "ip";
     public static final String AGENT_MANAGER_RETURN_PARAM_DATA = "data";
 
     public static final String AGENT_MANAGER_AUTH_SECRET_ID = "agent.manager.auth.secretId";
