@@ -30,6 +30,13 @@ public class RedisTask {
     private String readTimeout;
     private String queueSize;
     private String replId;
+    private String dbName;
+    private String command;
+    private String keys;
+    private String fieldOrMember;
+    private Boolean isSubscribe;
+    private String syncFreq;
+    private String subscriptionOperation;
 
     @Data
     public static class RedisTaskConfig {
@@ -42,5 +49,12 @@ public class RedisTask {
         private String timeout;
         private String queueSize;
         private String replId;
+        private String dbName;
+        private String command;
+        private String keys;
+        private String fieldOrMember;
+        private Boolean isSubscribe;
+        private String syncFreq;
+        private String subscriptionOperation;
     }
 }
