@@ -21,6 +21,7 @@ import org.apache.inlong.agent.conf.AgentConfiguration;
 import org.apache.inlong.agent.conf.TaskProfile;
 import org.apache.inlong.agent.constant.CycleUnitType;
 import org.apache.inlong.agent.pojo.BinlogTask.BinlogTaskConfig;
+import org.apache.inlong.agent.pojo.COSTask.COSTaskConfig;
 import org.apache.inlong.agent.pojo.FileTask.FileTaskConfig;
 import org.apache.inlong.agent.pojo.FileTask.Line;
 import org.apache.inlong.agent.pojo.KafkaTask.KafkaTaskConfig;
@@ -30,6 +31,7 @@ import org.apache.inlong.agent.pojo.OracleTask.OracleTaskConfig;
 import org.apache.inlong.agent.pojo.PostgreSQLTask.PostgreSQLTaskConfig;
 import org.apache.inlong.agent.pojo.PulsarTask.PulsarTaskConfig;
 import org.apache.inlong.agent.pojo.RedisTask.RedisTaskConfig;
+import org.apache.inlong.agent.pojo.SQLTask.SQLTaskConfig;
 import org.apache.inlong.agent.pojo.SqlServerTask.SqlserverTaskConfig;
 import org.apache.inlong.common.constant.MQType;
 import org.apache.inlong.common.enums.TaskTypeEnum;
@@ -37,6 +39,8 @@ import org.apache.inlong.common.pojo.agent.DataConfig;
 
 import com.google.gson.Gson;
 import lombok.Data;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import java.util.stream.Collectors;
 
@@ -48,60 +52,14 @@ import static org.apache.inlong.common.enums.DataReportTypeEnum.NORMAL_SEND_TO_D
 @Data
 public class TaskProfileDto {
 
-    public static final String DEFAULT_FILE_TASK = "org.apache.inlong.agent.plugin.task.file.LogFileTask";
-    public static final String DEFAULT_KAFKA_TASK = "org.apache.inlong.agent.plugin.task.KafkaTask";
-    public static final String DEFAULT_PULSAR_TASK = "org.apache.inlong.agent.plugin.task.PulsarTask";
-    public static final String DEFAULT_MONGODB_TASK = "org.apache.inlong.agent.plugin.task.MongoDBTask";
-    public static final String DEFAULT_POSTGRESQL_TASK = "org.apache.inlong.agent.plugin.task.PostgreSQLTask";
+    private static final Logger logger = LoggerFactory.getLogger(TaskProfileDto.class);
     public static final String DEFAULT_CHANNEL = "org.apache.inlong.agent.plugin.channel.MemoryChannel";
     public static final String MANAGER_JOB = "MANAGER_JOB";
     public static final String DEFAULT_DATA_PROXY_SINK = "org.apache.inlong.agent.plugin.sinks.ProxySink";
     public static final String PULSAR_SINK = "org.apache.inlong.agent.plugin.sinks.PulsarSink";
     public static final String KAFKA_SINK = "org.apache.inlong.agent.plugin.sinks.KafkaSink";
-
-    /**
-     * file source
-     */
-    public static final String DEFAULT_SOURCE = "org.apache.inlong.agent.plugin.sources.LogFileSource";
-    /**
-     * binlog source
-     */
-    public static final String BINLOG_SOURCE = "org.apache.inlong.agent.plugin.sources.BinlogSource";
-    /**
-     * kafka source
-     */
-    public static final String KAFKA_SOURCE = "org.apache.inlong.agent.plugin.sources.KafkaSource";
-    // pulsar source
-    public static final String PULSAR_SOURCE = "org.apache.inlong.agent.plugin.sources.PulsarSource";
-    /**
-     * PostgreSQL source
-     */
-    public static final String POSTGRESQL_SOURCE = "org.apache.inlong.agent.plugin.sources.PostgreSQLSource";
-    /**
-     * mongo source
-     */
-    public static final String MONGO_SOURCE = "org.apache.inlong.agent.plugin.sources.MongoDBSource";
-    /**
-     * oracle source
-     */
-    public static final String ORACLE_SOURCE = "org.apache.inlong.agent.plugin.sources.OracleSource";
-    /**
-     * redis source
-     */
-    public static final String REDIS_SOURCE = "org.apache.inlong.agent.plugin.sources.RedisSource";
-    /**
-     * mqtt source
-     */
-    public static final String MQTT_SOURCE = "org.apache.inlong.agent.plugin.sources.MqttSource";
-    /**
-     * sqlserver source
-     */
-    public static final String SQLSERVER_SOURCE = "org.apache.inlong.agent.plugin.sources.SQLServerSource";
-
     private static final Gson GSON = new Gson();
-
     public static final String deafult_time_offset = "0";
-
     private static final String DEFAULT_AUDIT_VERSION = "0";
 
     private Task task;
@@ -152,7 +110,7 @@ public class TaskProfileDto {
                 FileTaskConfig.class);
 
         FileTask.Dir dir = new FileTask.Dir();
-        dir.setPatterns(taskConfig.getPattern());
+        dir.setPatterns(taskConfig.getPattern().trim());
         dir.setBlackList(taskConfig.getBlackList());
         fileTask.setDir(dir);
         fileTask.setCollectType(taskConfig.getCollectType());
@@ -162,8 +120,11 @@ public class TaskProfileDto {
         fileTask.setMaxFileCount(taskConfig.getMaxFileCount());
         fileTask.setRetry(taskConfig.getRetry());
         fileTask.setCycleUnit(taskConfig.getCycleUnit());
-        fileTask.setStartTime(taskConfig.getStartTime());
-        fileTask.setEndTime(taskConfig.getEndTime());
+        fileTask.setDataTimeFrom(taskConfig.getDataTimeFrom());
+        fileTask.setDataTimeTo(taskConfig.getDataTimeTo());
+        if (taskConfig.getFilterStreams() != null) {
+            fileTask.setFilterStreams(GSON.toJson(taskConfig.getFilterStreams()));
+        }
         if (taskConfig.getTimeOffset() != null) {
             fileTask.setTimeOffset(taskConfig.getTimeOffset());
         } else {
@@ -190,6 +151,59 @@ public class TaskProfileDto {
         return fileTask;
     }
 
+    private static COSTask getCOSTask(DataConfig dataConfig) {
+        COSTask cosTask = new COSTask();
+        cosTask.setId(dataConfig.getTaskId());
+        COSTaskConfig taskConfig = GSON.fromJson(dataConfig.getExtParams(),
+                COSTaskConfig.class);
+        cosTask.setPattern(taskConfig.getPattern().trim());
+        cosTask.setCollectType(taskConfig.getCollectType());
+        cosTask.setContentStyle(taskConfig.getContentStyle());
+        cosTask.setDataSeparator(taskConfig.getDataSeparator());
+        cosTask.setMaxFileCount(taskConfig.getMaxFileCount());
+        cosTask.setRetry(taskConfig.getRetry());
+        cosTask.setCycleUnit(taskConfig.getCycleUnit());
+        cosTask.setDataTimeFrom(taskConfig.getDataTimeFrom());
+        cosTask.setDataTimeTo(taskConfig.getDataTimeTo());
+        cosTask.setBucketName(taskConfig.getBucketName());
+        cosTask.setSecretId(taskConfig.getCredentialsId());
+        cosTask.setSecretKey(taskConfig.getCredentialsKey());
+        cosTask.setRegion(taskConfig.getRegion());
+        if (taskConfig.getFilterStreams() != null) {
+            cosTask.setFilterStreams(GSON.toJson(taskConfig.getFilterStreams()));
+        }
+        if (taskConfig.getTimeOffset() != null) {
+            cosTask.setTimeOffset(taskConfig.getTimeOffset());
+        } else {
+            cosTask.setTimeOffset(deafult_time_offset + cosTask.getCycleUnit());
+        }
+        return cosTask;
+    }
+
+    private static SQLTask getSQLTask(DataConfig dataConfig) {
+        SQLTask sqlTask = new SQLTask();
+        sqlTask.setId(dataConfig.getTaskId());
+        SQLTaskConfig taskConfig = GSON.fromJson(dataConfig.getExtParams(),
+                SQLTaskConfig.class);
+        sqlTask.setSql(taskConfig.getSql());
+        sqlTask.setMaxInstanceCount(taskConfig.getMaxInstanceCount());
+        sqlTask.setRetry(taskConfig.getRetry());
+        sqlTask.setCycleUnit(taskConfig.getCycleUnit());
+        sqlTask.setDataTimeFrom(taskConfig.getDataTimeFrom());
+        sqlTask.setDataTimeTo(taskConfig.getDataTimeTo());
+        sqlTask.setUsername(taskConfig.getUsername());
+        sqlTask.setJdbcPassword(taskConfig.getJdbcPassword());
+        sqlTask.setDataSeparator(taskConfig.getDataSeparator());
+        sqlTask.setFetchSize(taskConfig.getFetchSize());
+        sqlTask.setJdbcUrl(taskConfig.getJdbcUrl());
+        if (taskConfig.getTimeOffset() != null) {
+            sqlTask.setTimeOffset(taskConfig.getTimeOffset());
+        } else {
+            sqlTask.setTimeOffset(deafult_time_offset + sqlTask.getCycleUnit());
+        }
+        return sqlTask;
+    }
+
     private static KafkaTask getKafkaTask(DataConfig dataConfigs) {
 
         KafkaTaskConfig kafkaTaskConfig = GSON.fromJson(dataConfigs.getExtParams(),
@@ -268,8 +282,14 @@ public class TaskProfileDto {
         redisTask.setPort(config.getPort());
         redisTask.setSsl(config.getSsl());
         redisTask.setReadTimeout(config.getTimeout());
-        redisTask.setQueueSize(config.getQueueSize());
         redisTask.setReplId(config.getReplId());
+        redisTask.setCommand(config.getCommand());
+        redisTask.setDbName(config.getDbName());
+        redisTask.setKeys(config.getKeys());
+        redisTask.setFieldOrMember(config.getFieldOrMember());
+        redisTask.setIsSubscribe(config.getIsSubscribe());
+        redisTask.setSyncFreq(config.getSyncFreq());
+        redisTask.setSubscriptionOperation(config.getSubscriptionOperation());
 
         return redisTask;
     }
@@ -308,12 +328,14 @@ public class TaskProfileDto {
         OracleTaskConfig config = GSON.fromJson(dataConfigs.getExtParams(),
                 OracleTaskConfig.class);
         OracleTask oracleTask = new OracleTask();
-        oracleTask.setUser(config.getUser());
+
         oracleTask.setHostname(config.getHostname());
-        oracleTask.setPassword(config.getPassword());
         oracleTask.setPort(config.getPort());
-        oracleTask.setServerName(config.getServerName());
-        oracleTask.setDbname(config.getDbname());
+        oracleTask.setUser(config.getUsername());
+        oracleTask.setPassword(config.getPassword());
+        oracleTask.setSchemaIncludeList(config.getSchemaName());
+        oracleTask.setDbname(config.getDatabase());
+        oracleTask.setTableIncludeList(config.getTableName());
 
         OracleTask.Offset offset = new OracleTask.Offset();
         offset.setFilename(config.getOffsetFilename());
@@ -322,7 +344,7 @@ public class TaskProfileDto {
         oracleTask.setOffset(offset);
 
         OracleTask.Snapshot snapshot = new OracleTask.Snapshot();
-        snapshot.setMode(config.getSnapshotMode());
+        snapshot.setMode(config.getScanStartupMode());
         oracleTask.setSnapshot(snapshot);
 
         OracleTask.History history = new OracleTask.History();
@@ -342,6 +364,10 @@ public class TaskProfileDto {
         sqlServerTask.setPort(config.getPort());
         sqlServerTask.setServerName(config.getSchemaName());
         sqlServerTask.setDbname(config.getDatabase());
+        sqlServerTask.setSchemaName(config.getSchemaName());
+        sqlServerTask.setTableName(config.getSchemaName() + "." + config.getTableName());
+        sqlServerTask.setServerTimezone(config.getServerTimezone());
+        sqlServerTask.setUnixTimestampFormatEnable(config.getUnixTimestampFormatEnable());
 
         SqlServerTask.Offset offset = new SqlServerTask.Offset();
         offset.setFilename(config.getOffsetFilename());
@@ -413,6 +439,7 @@ public class TaskProfileDto {
 
         // common attribute
         task.setId(String.valueOf(dataConfig.getTaskId()));
+        task.setTaskType(dataConfig.getTaskType());
         task.setGroupId(dataConfig.getInlongGroupId());
         task.setStreamId(dataConfig.getInlongStreamId());
         task.setChannel(DEFAULT_CHANNEL);
@@ -449,79 +476,80 @@ public class TaskProfileDto {
                 throw new IllegalArgumentException("invalid mq type " + mqType + " please check");
             }
         }
+        task.setRetry(false);
         TaskTypeEnum taskType = TaskTypeEnum.getTaskType(dataConfig.getTaskType());
         switch (requireNonNull(taskType)) {
             case SQL:
+                SQLTask sqlTask = getSQLTask(dataConfig);
+                task.setCycleUnit(sqlTask.getCycleUnit());
+                task.setSqlTask(sqlTask);
+                task.setRetry(sqlTask.getRetry());
+                profileDto.setTask(task);
+                break;
             case BINLOG:
                 BinlogTask binlogTask = getBinlogTask(dataConfig);
                 task.setBinlogTask(binlogTask);
-                task.setSource(BINLOG_SOURCE);
                 profileDto.setTask(task);
                 break;
             case FILE:
-                task.setTaskClass(DEFAULT_FILE_TASK);
                 FileTask fileTask = getFileTask(dataConfig);
                 task.setCycleUnit(fileTask.getCycleUnit());
                 task.setFileTask(fileTask);
-                task.setSource(DEFAULT_SOURCE);
+                task.setRetry(fileTask.getRetry());
                 profileDto.setTask(task);
                 break;
             case KAFKA:
-                task.setTaskClass(DEFAULT_KAFKA_TASK);
                 KafkaTask kafkaTask = getKafkaTask(dataConfig);
                 task.setKafkaTask(kafkaTask);
-                task.setSource(KAFKA_SOURCE);
                 profileDto.setTask(task);
                 break;
             case PULSAR:
-                task.setTaskClass(DEFAULT_PULSAR_TASK);
                 PulsarTask pulsarTask = getPulsarTask(dataConfig);
                 task.setPulsarTask(pulsarTask);
-                task.setSource(PULSAR_SOURCE);
                 profileDto.setTask(task);
                 break;
             case POSTGRES:
-                task.setTaskClass(DEFAULT_POSTGRESQL_TASK);
                 PostgreSQLTask postgreSQLTask = getPostgresTask(dataConfig);
                 task.setPostgreSQLTask(postgreSQLTask);
-                task.setSource(POSTGRESQL_SOURCE);
                 profileDto.setTask(task);
                 break;
             case ORACLE:
                 OracleTask oracleTask = getOracleTask(dataConfig);
                 task.setOracleTask(oracleTask);
-                task.setSource(ORACLE_SOURCE);
                 profileDto.setTask(task);
                 break;
             case SQLSERVER:
                 SqlServerTask sqlserverTask = getSqlServerTask(dataConfig);
                 task.setSqlserverTask(sqlserverTask);
-                task.setSource(SQLSERVER_SOURCE);
                 profileDto.setTask(task);
                 break;
             case MONGODB:
-                task.setTaskClass(DEFAULT_MONGODB_TASK);
                 MongoTask mongoTask = getMongoTask(dataConfig);
                 task.setMongoTask(mongoTask);
-                task.setSource(MONGO_SOURCE);
                 profileDto.setTask(task);
                 break;
             case REDIS:
                 RedisTask redisTask = getRedisTask(dataConfig);
                 task.setRedisTask(redisTask);
-                task.setSource(REDIS_SOURCE);
                 profileDto.setTask(task);
                 break;
             case MQTT:
                 MqttTask mqttTask = getMqttTask(dataConfig);
                 task.setMqttTask(mqttTask);
-                task.setSource(MQTT_SOURCE);
                 profileDto.setTask(task);
                 break;
             case MOCK:
                 profileDto.setTask(task);
                 break;
+            case COS:
+                COSTask cosTask = getCOSTask(dataConfig);
+                task.setCycleUnit(cosTask.getCycleUnit());
+                task.setCosTask(cosTask);
+                task.setRetry(cosTask.getRetry());
+                profileDto.setTask(task);
+                break;
             default:
+                logger.error("invalid task type {}", taskType);
         }
         return TaskProfile.parseJsonStr(GSON.toJson(profileDto));
     }
@@ -546,11 +574,13 @@ public class TaskProfileDto {
         private String mqClusters;
         private String topicInfo;
         private String taskClass;
+        private Integer taskType;
         private String predefinedFields;
         private Integer state;
         private String cycleUnit;
         private String timeZone;
         private String auditVersion;
+        private boolean retry;
 
         private FileTask fileTask;
         private BinlogTask binlogTask;
@@ -562,6 +592,8 @@ public class TaskProfileDto {
         private RedisTask redisTask;
         private MqttTask mqttTask;
         private SqlServerTask sqlserverTask;
+        private COSTask cosTask;
+        private SQLTask sqlTask;
     }
 
     @Data
