@@ -18,6 +18,7 @@
 package org.apache.inlong.agent.utils;
 
 import org.apache.inlong.agent.conf.AgentConfiguration;
+import org.apache.inlong.agent.constant.AgentConstants;
 
 import org.apache.commons.codec.digest.DigestUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -39,20 +40,11 @@ import java.time.format.DateTimeFormatter;
 import java.util.HashMap;
 import java.util.Locale;
 import java.util.Map;
+import java.util.StringTokenizer;
 import java.util.TimeZone;
 import java.util.concurrent.ThreadLocalRandom;
 import java.util.concurrent.TimeUnit;
 
-import static org.apache.inlong.agent.constant.AgentConstants.AGENT_ENABLE_OOM_EXIT;
-import static org.apache.inlong.agent.constant.AgentConstants.AGENT_LOCAL_IP;
-import static org.apache.inlong.agent.constant.AgentConstants.AGENT_LOCAL_UUID;
-import static org.apache.inlong.agent.constant.AgentConstants.AGENT_LOCAL_UUID_OPEN;
-import static org.apache.inlong.agent.constant.AgentConstants.CUSTOM_FIXED_IP;
-import static org.apache.inlong.agent.constant.AgentConstants.DEFAULT_AGENT_LOCAL_UUID_OPEN;
-import static org.apache.inlong.agent.constant.AgentConstants.DEFAULT_ENABLE_OOM_EXIT;
-import static org.apache.inlong.agent.constant.AgentConstants.DEFAULT_LOCAL_HOST;
-import static org.apache.inlong.agent.constant.AgentConstants.DEFAULT_LOCAL_IP;
-
 /**
  * Agent utils
  */
@@ -131,7 +123,7 @@ public class AgentUtils {
      * Get local IP
      */
     public static String getLocalIp() {
-        String ip = DEFAULT_LOCAL_IP;
+        String ip = AgentConstants.DEFAULT_LOCAL_IP;
         try (DatagramSocket socket = new DatagramSocket()) {
             socket.connect(InetAddress.getByName("8.8.8.8"), 10002);
             ip = socket.getLocalAddress().getHostAddress();
@@ -145,7 +137,7 @@ public class AgentUtils {
      * Get local host
      */
     public static String getLocalHost() {
-        String host = DEFAULT_LOCAL_HOST;
+        String host = AgentConstants.DEFAULT_LOCAL_HOST;
         try {
             host = InetAddress.getLocalHost().getHostName();
         } catch (Exception ex) {
@@ -260,6 +252,30 @@ public class AgentUtils {
         return Pair.of(mValue, attr);
     }
 
+    public static Map<String, String> parseAddAttrToMap(String addictiveAttr) {
+        StringTokenizer token = new StringTokenizer(addictiveAttr, "&");
+        Map<String, String> attr = new HashMap<String, String>();
+        while (token.hasMoreTokens()) {
+            String value = token.nextToken().trim();
+            if (value.contains("=")) {
+                String[] pairs = value.split("=");
+
+                if (pairs[0].equalsIgnoreCase("m")) {
+                    continue;
+                }
+
+                // when addictiveattr like "m=10&__addcol1__worldid="
+                if (value.endsWith("=") && pairs.length == 1) {
+                    attr.put(pairs[0], "");
+                } else {
+                    attr.put(pairs[0], pairs[1]);
+                }
+
+            }
+        }
+        return attr;
+    }
+
     /**
      * Get the attrs in pairs can be complicated in online env
      */
@@ -292,10 +308,10 @@ public class AgentUtils {
      * Check agent ip from manager
      */
     public static String fetchLocalIp() {
-        if (StringUtils.isNoneBlank(AgentConfiguration.getAgentConf().get(CUSTOM_FIXED_IP, null))) {
-            return AgentConfiguration.getAgentConf().get(CUSTOM_FIXED_IP);
+        if (StringUtils.isNoneBlank(AgentConfiguration.getAgentConf().get(AgentConstants.CUSTOM_FIXED_IP, null))) {
+            return AgentConfiguration.getAgentConf().get(AgentConstants.CUSTOM_FIXED_IP);
         }
-        return AgentConfiguration.getAgentConf().get(AGENT_LOCAL_IP, getLocalIp());
+        return AgentConfiguration.getAgentConf().get(AgentConstants.AGENT_LOCAL_IP, getLocalIp());
     }
 
     /**
@@ -303,11 +319,12 @@ public class AgentUtils {
      */
     public static String fetchLocalUuid() {
         String uuid = "";
-        if (!AgentConfiguration.getAgentConf().getBoolean(AGENT_LOCAL_UUID_OPEN, DEFAULT_AGENT_LOCAL_UUID_OPEN)) {
+        if (!AgentConfiguration.getAgentConf().getBoolean(AgentConstants.AGENT_LOCAL_UUID_OPEN,
+                AgentConstants.DEFAULT_AGENT_LOCAL_UUID_OPEN)) {
             return uuid;
         }
         try {
-            String localUuid = AgentConfiguration.getAgentConf().get(AGENT_LOCAL_UUID);
+            String localUuid = AgentConfiguration.getAgentConf().get(AgentConstants.AGENT_LOCAL_UUID);
             if (StringUtils.isNotEmpty(localUuid)) {
                 uuid = localUuid;
                 return uuid;
@@ -386,6 +403,7 @@ public class AgentUtils {
      * Whether the config of exiting the program when OOM is enabled
      */
     public static boolean enableOOMExit() {
-        return AgentConfiguration.getAgentConf().getBoolean(AGENT_ENABLE_OOM_EXIT, DEFAULT_ENABLE_OOM_EXIT);
+        return AgentConfiguration.getAgentConf().getBoolean(AgentConstants.AGENT_ENABLE_OOM_EXIT,
+                AgentConstants.DEFAULT_ENABLE_OOM_EXIT);
     }
 }
