@@ -27,7 +27,6 @@ import org.apache.inlong.common.pojo.agent.AgentConfigInfo;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.File;
 import java.lang.reflect.Constructor;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
@@ -92,14 +91,10 @@ public class AgentManager extends AbstractDaemon {
                 while (true) {
                     try {
                         Thread.sleep(10 * 1000); // 10s check
-                        File file = new File(
-                                conf.getConfigLocation(AgentConfiguration.DEFAULT_CONFIG_FILE).getFile());
-                        if (!file.exists()) {
-                            continue;
-                        }
-                        if (file.lastModified() > lastModifiedTime) {
+                        long maxLastModifiedTime = conf.maxLastModifiedTime();
+                        if (maxLastModifiedTime > lastModifiedTime) {
                             conf.reloadFromLocalPropertiesFile();
-                            lastModifiedTime = file.lastModified();
+                            lastModifiedTime = maxLastModifiedTime;
                         }
                     } catch (InterruptedException e) {
                         LOGGER.error("Interrupted when flush agent conf.", e);
