@@ -18,9 +18,8 @@
 package org.apache.inlong.agent.plugin.sources;
 
 import org.apache.inlong.agent.conf.InstanceProfile;
-import org.apache.inlong.agent.conf.TaskProfile;
 import org.apache.inlong.agent.except.FileException;
-import org.apache.inlong.agent.plugin.file.Reader;
+import org.apache.inlong.agent.plugin.sources.extend.DefaultExtendedHandler;
 import org.apache.inlong.agent.plugin.sources.file.AbstractSource;
 
 import org.apache.commons.lang3.ObjectUtils;
@@ -68,6 +67,11 @@ public class KafkaSource extends AbstractSource {
     public KafkaSource() {
     }
 
+    @Override
+    protected void initExtendClass() {
+        extendClass = DefaultExtendedHandler.class.getCanonicalName();
+    }
+
     @Override
     protected void initSource(InstanceProfile profile) {
         try {
@@ -168,11 +172,6 @@ public class KafkaSource extends AbstractSource {
         return runnable;
     }
 
-    @Override
-    public List<Reader> split(TaskProfile conf) {
-        return null;
-    }
-
     @Override
     public boolean sourceExist() {
         return true;
