@@ -20,11 +20,10 @@ package org.apache.inlong.agent.plugin.sources;
 import org.apache.inlong.agent.common.AgentThreadFactory;
 import org.apache.inlong.agent.conf.AgentConfiguration;
 import org.apache.inlong.agent.conf.InstanceProfile;
-import org.apache.inlong.agent.conf.TaskProfile;
 import org.apache.inlong.agent.constant.AgentConstants;
 import org.apache.inlong.agent.constant.TaskConstants;
 import org.apache.inlong.agent.except.FileException;
-import org.apache.inlong.agent.plugin.file.Reader;
+import org.apache.inlong.agent.plugin.sources.extend.DefaultExtendedHandler;
 import org.apache.inlong.agent.plugin.sources.file.AbstractSource;
 
 import io.debezium.connector.postgresql.PostgresConnector;
@@ -76,6 +75,11 @@ public class PostgreSQLSource extends AbstractSource {
 
     }
 
+    @Override
+    protected void initExtendClass() {
+        extendClass = DefaultExtendedHandler.class.getCanonicalName();
+    }
+
     @Override
     protected void initSource(InstanceProfile profile) {
         try {
@@ -145,11 +149,6 @@ public class PostgreSQLSource extends AbstractSource {
         committer.markBatchFinished();
     }
 
-    @Override
-    public List<Reader> split(TaskProfile conf) {
-        return null;
-    }
-
     @Override
     protected String getThreadName() {
         return "postgres-source-" + taskId + "-" + instanceId;
