@@ -18,9 +18,8 @@
 package org.apache.inlong.agent.plugin.sources;
 
 import org.apache.inlong.agent.conf.InstanceProfile;
-import org.apache.inlong.agent.conf.TaskProfile;
 import org.apache.inlong.agent.except.FileException;
-import org.apache.inlong.agent.plugin.file.Reader;
+import org.apache.inlong.agent.plugin.sources.extend.DefaultExtendedHandler;
 import org.apache.inlong.agent.plugin.sources.file.AbstractSource;
 
 import org.apache.commons.lang3.ObjectUtils;
@@ -52,10 +51,10 @@ public class PulsarSource extends AbstractSource {
     private String serviceUrl;
     private String subscription;
     private String subscriptionType;
-    private String subscriptionPosition;
     private PulsarClient pulsarClient;
     private Long timestamp;
     private final static String PULSAR_SUBSCRIPTION_PREFIX = "inlong-agent-";
+    private final static String SUBSCRIPTION_CUSTOM = "Custom";
     private boolean isRestoreFromDB = false;
     private Consumer<byte[]> consumer;
     private long offset = 0L;
@@ -63,6 +62,11 @@ public class PulsarSource extends AbstractSource {
     public PulsarSource() {
     }
 
+    @Override
+    protected void initExtendClass() {
+        extendClass = DefaultExtendedHandler.class.getCanonicalName();
+    }
+
     @Override
     protected void initSource(InstanceProfile profile) {
         try {
@@ -70,8 +74,6 @@ public class PulsarSource extends AbstractSource {
             topic = profile.getInstanceId();
             serviceUrl = profile.get(TASK_PULSAR_SERVICE_URL);
             subscription = profile.get(TASK_PULSAR_SUBSCRIPTION, PULSAR_SUBSCRIPTION_PREFIX + inlongStreamId);
-            subscriptionPosition = profile.get(TASK_PULSAR_SUBSCRIPTION_POSITION,
-                    SubscriptionInitialPosition.Latest.name());
             subscriptionType = profile.get(TASK_PULSAR_SUBSCRIPTION_TYPE, SubscriptionType.Shared.name());
             timestamp = profile.getLong(TASK_PULSAR_RESET_TIME, 0);
             pulsarClient = PulsarClient.builder().serviceUrl(serviceUrl).build();
@@ -99,40 +101,53 @@ public class PulsarSource extends AbstractSource {
         org.apache.pulsar.client.api.Message<byte[]> message = null;
         try {
             message = consumer.receive(0, TimeUnit.MILLISECONDS);
-            offset = message.getSequenceId();
         } catch (PulsarClientException e) {
             LOGGER.error("read from pulsar error", e);
         }
         if (!ObjectUtils.isEmpty(message)) {
+            offset = message.getSequenceId();
             dataList.add(new SourceData(message.getValue(), new String(message.getMessageId().toByteArray(),
                     StandardCharsets.UTF_8)));
+            try {
+                consumer.acknowledge(message);
+            } catch (PulsarClientException e) {
+                LOGGER.error("ack pulsar error", e);
+            }
         }
-        try {
-            consumer.acknowledge(message);
-        } catch (PulsarClientException e) {
-            LOGGER.error("ack pulsar error", e);
-        }
+
         return dataList;
     }
 
     private Consumer<byte[]> getConsumer() {
         Consumer<byte[]> consumer = null;
         try {
-            consumer = pulsarClient.newConsumer(Schema.BYTES)
-                    .topic(topic)
-                    .subscriptionName(subscription)
-                    .subscriptionInitialPosition(SubscriptionInitialPosition.valueOf(subscriptionPosition))
-                    .subscriptionType(SubscriptionType.valueOf(subscriptionType))
-                    .subscribe();
-            if (!isRestoreFromDB && timestamp != 0L) {
-                consumer.seek(timestamp);
-                LOGGER.info("Reset consume from {}", timestamp);
+            String position = profile.get(TASK_PULSAR_SUBSCRIPTION_POSITION, SubscriptionInitialPosition.Latest.name());
+            if (position.equals(SUBSCRIPTION_CUSTOM)) {
+                consumer = pulsarClient.newConsumer(Schema.BYTES)
+                        .topic(topic)
+                        .subscriptionName(subscription)
+                        .subscriptionType(SubscriptionType.valueOf(subscriptionType))
+                        .subscribe();
+                if (!isRestoreFromDB) {
+                    if (timestamp == 0L) {
+                        LOGGER.error("Reset consume but timestamp is 0L");
+                    } else {
+                        consumer.seek(timestamp);
+                        LOGGER.info("Reset consume from {}", timestamp);
+                    }
+                }
             } else {
+                consumer = pulsarClient.newConsumer(Schema.BYTES)
+                        .topic(topic)
+                        .subscriptionName(subscription)
+                        .subscriptionInitialPosition(SubscriptionInitialPosition.valueOf(position))
+                        .subscriptionType(SubscriptionType.valueOf(subscriptionType))
+                        .subscribe();
                 LOGGER.info("Skip to reset consume");
             }
             return consumer;
         } catch (PulsarClientException | IllegalArgumentException e) {
-            if (consumer == null) {
+            if (consumer != null) {
                 try {
                     consumer.close();
                 } catch (PulsarClientException ex) {
@@ -165,11 +180,6 @@ public class PulsarSource extends AbstractSource {
         }
     }
 
-    @Override
-    public List<Reader> split(TaskProfile conf) {
-        return null;
-    }
-
     @Override
     public boolean sourceExist() {
         return true;
