@@ -56,6 +56,11 @@ public class CronTask extends Task {
         return true;
     }
 
+    @Override
+    public int getInstanceNum() {
+        return 0;
+    }
+
     @Override
     public void addCallbacks() {
 
