@@ -18,17 +18,28 @@
 package org.apache.inlong.audit.util;
 
 import org.apache.inlong.audit.AuditIdEnum;
+import org.apache.inlong.audit.CdcIdEnum;
 import org.apache.inlong.audit.MetricIdEnum;
 import org.apache.inlong.audit.entity.AuditInformation;
+import org.apache.inlong.audit.entity.CdcType;
 import org.apache.inlong.audit.entity.FlowType;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.util.ArrayList;
 import java.util.LinkedList;
 import java.util.List;
 
-import static org.apache.inlong.audit.AuditIdEnum.*;
+import static org.apache.inlong.audit.AuditIdEnum.AGENT_INPUT;
+import static org.apache.inlong.audit.AuditIdEnum.AGENT_OUTPUT;
+import static org.apache.inlong.audit.AuditIdEnum.DATA_PROXY_INPUT;
+import static org.apache.inlong.audit.AuditIdEnum.DATA_PROXY_OUTPUT;
+import static org.apache.inlong.audit.AuditIdEnum.SDK_INPUT;
+import static org.apache.inlong.audit.AuditIdEnum.SDK_OUTPUT;
+import static org.apache.inlong.audit.entity.AuditRules.START_CDC_INPUT_ID;
+import static org.apache.inlong.audit.entity.AuditRules.START_CDC_OUTPUT_ID;
+import static org.apache.inlong.audit.entity.AuditRules.START_METRIC_ID;
 
 /**
  * Audit item ID generation rules: composed of basic audit item ID + extension bits.
@@ -235,11 +246,131 @@ public class AuditManagerUtils {
     }
 
     /**
-     * Get max Audit ID.
+     * Gets the maximum possible audit ID based on the defined bit length constraints.
      *
-     * @return
+     * @return int The maximum audit ID calculated as:
+     *         1 shifted left by (AUDIT_SUFFIX_LENGTH + AUDIT_MAX_PREFIX_LENGTH)
+     *         This represents the upper bound of the regular audit ID space.
      */
-    public static int getStartAuditIdForMetric() {
+    private static int getMaxAuditId() {
         return 1 << (AUDIT_SUFFIX_LENGTH + AUDIT_MAX_PREFIX_LENGTH);
     }
+
+    /**
+     * Gets the starting audit ID for metric items.
+     *
+     * @return int The starting audit ID for metrics, calculated as:
+     *         maximum audit ID plus predefined metric ID offset.
+     *         This ensures metric IDs are in a separate range from regular audit IDs.
+     */
+    public static int getStartAuditIdForMetric() {
+        return getMaxAuditId() + START_METRIC_ID;
+    }
+
+    /**
+     * Gets the starting audit ID for CDC (Change Data Capture) items.
+     *
+     * @return int The starting audit ID for CDC, calculated as:
+     * maximum audit ID plus predefined CDC input ID offset.
+     * This ensures CDC IDs are in a separate range from regular audit IDs.
+     */
+    public static int getStartAuditIdForCdcInput() {
+        return getMaxAuditId() + START_CDC_INPUT_ID;
+    }
+
+    /**
+     * Gets the starting audit ID for CDC output items.
+     *
+     * @return int The starting audit ID for CDC output, calculated as:
+     * maximum audit ID plus predefined CDC output ID offset.
+     * This ensures CDC output IDs are in a separate range from regular audit IDs.
+     */
+    public static int getStartAuditIdForCdcOutput() {
+        return getMaxAuditId() + START_CDC_OUTPUT_ID;
+    }
+
+    /**
+     * Get all CDC audit information by combining all flow types with all CDC ID enums.
+     * @return List of AuditInformation containing all possible CDC audit combinations
+     */
+    public static List<AuditInformation> getAllCdcIdInformation() {
+        List<AuditInformation> result = new ArrayList<>(FlowType.values().length * CdcIdEnum.values().length);
+        for (FlowType flowType : FlowType.values()) {
+            for (CdcIdEnum cdcIdEnum : CdcIdEnum.values()) {
+                result.add(createAuditInformation(cdcIdEnum, flowType));
+            }
+        }
+        return result;
+    }
+
+    /**
+     * Get the CDC ID based on the audit type, flow type, and CDC type.
+     * @param auditType The type of audit (e.g., MySQL, TDSQL)
+     * @param flowType  The flow type (e.g., INPUT, OUTPUT)
+     * @param cdcType   The CDC type (e.g., INSERT, DELETE, UPDATE_BEFORE, UPDATE_AFTER)
+     * @return int The corresponding CDC ID
+     */
+    public static int getCdcId(String auditType, FlowType flowType, CdcType cdcType) {
+        return CdcIdEnum.getCdcId(auditType, flowType, cdcType);
+    }
+
+    /**
+     * Get all CDC audit information based on the audit type.
+     * @param auditType The type of audit (e.g., MySQL, TDSQL)
+     * @return List of AuditInformation containing all possible CDC audit combinations for the given audit type
+     */
+    public static List<AuditInformation> getAllCdcIdInformation(String auditType) {
+        List<AuditInformation> result = new ArrayList<>(FlowType.values().length * CdcIdEnum.values().length);
+        for (FlowType flowType : FlowType.values()) {
+            for (CdcIdEnum cdcIdEnum : CdcIdEnum.values()) {
+                if (cdcIdEnum.getAuditType().value().equals(auditType)) {
+                    result.add(createAuditInformation(cdcIdEnum, flowType));
+                }
+            }
+        }
+        return result;
+    }
+
+    /**
+     * Get all CDC audit information based on audit type and flow type.
+     * @param auditType The type of audit (e.g., MySQL, TDSQL)
+     * @param flowType  The flow type (e.g., INPUT, OUTPUT)
+     * @return List of AuditInformation containing matching CDC audit combinations
+     */
+    public static List<AuditInformation> getAllCdcIdInformation(String auditType, FlowType flowType) {
+        List<AuditInformation> result = new ArrayList<>(CdcIdEnum.values().length);
+        for (CdcIdEnum cdcIdEnum : CdcIdEnum.values()) {
+            if (cdcIdEnum.getAuditType().value().equals(auditType)) {
+                result.add(createAuditInformation(cdcIdEnum, flowType));
+            }
+        }
+        return result;
+    }
+
+    /**
+     * Get specific CDC audit information based on audit type, flow type and CDC type.
+     * @param auditType The type of audit (e.g., MySQL, TDSQL)
+     * @param flowType  The flow type (e.g., INPUT, OUTPUT)
+     * @param cdcType   The CDC type (e.g., INSERT, DELETE, UPDATE_BEFORE, UPDATE_AFTER)
+     * @return AuditInformation matching the criteria, or null if not found
+     */
+    public static AuditInformation getCdcIdInformation(String auditType, FlowType flowType, CdcType cdcType) {
+        for (CdcIdEnum cdcIdEnum : CdcIdEnum.values()) {
+            if (cdcIdEnum.getAuditType().value().equals(auditType) && cdcIdEnum.getCdcType() == cdcType) {
+                return createAuditInformation(cdcIdEnum, flowType);
+            }
+        }
+        return null;
+    }
+
+    /**
+     * Helper method to create AuditInformation from CdcIdEnum and FlowType.
+     */
+    private static AuditInformation createAuditInformation(CdcIdEnum cdcIdEnum, FlowType flowType) {
+        return new AuditInformation(
+                cdcIdEnum.getValue(flowType),
+                cdcIdEnum.getEnglishDescription(flowType),
+                cdcIdEnum.getChineseDescription(flowType));
+    }
+
 }
