@@ -24,7 +24,8 @@ public enum MetricDimension {
     SEND_COUNT_SUCCESS("sendCountSuccess"),
     SEND_COUNT_FAILED("sendCountFailed"),
     SEND_DURATION("sendDuration"),
-    INVALID_DATA("invalidData");
+    INVALID_DATA("invalidData"),
+    FILTER_SUCCESS("filterSuccess");
 
     private final String key;
 
