@@ -32,8 +32,8 @@ cd "$BASE_DIR"
 
 # Prepare common dependency
 ROOT_DIR=$BASE_DIR/..
-if [ -e $ROOT_DIR/bin/prepare_module_dependencys.sh ]; then
-    $ROOT_DIR/bin/prepare_module_dependencys.sh ./inlong-audit/lib
+if [ -e $ROOT_DIR/bin/prepare_module_dependencies.sh ]; then
+    $ROOT_DIR/bin/prepare_module_dependencies.sh ./inlong-audit/lib
 fi
 
 error() {
