@@ -35,5 +35,8 @@ public class TaskResult {
 
     private List<CmdConfig> cmdConfigs;
     private List<DataConfig> dataConfigs;
+    private String md5;
+    private Integer version;
+    AgentResponseCode code;
 
 }
\ No newline at end of file
