@@ -30,7 +30,6 @@ public class DataProxyNodeResponse {
     /**
      * DataProxy cluster id
      */
-    @Deprecated
     private Integer clusterId;
 
     private String reportSourceType;
@@ -50,6 +49,11 @@ public class DataProxyNodeResponse {
      */
     private Integer load = 20;
 
+    /**
+     * Node max packet length
+     */
+    private Integer maxPacketLength;
+
     /**
      * List of the cluster node
      */
