@@ -17,6 +17,7 @@
 
 package org.apache.inlong.common.pojo.sort.dataflow;
 
+import org.apache.inlong.common.pojo.sort.dataflow.dataType.DataTypeConfig;
 import org.apache.inlong.common.pojo.sort.dataflow.deserialization.DeserializationConfig;
 import org.apache.inlong.common.pojo.sort.dataflow.field.FieldConfig;
 
@@ -30,7 +31,10 @@ public class SourceConfig implements Serializable {
 
     private String topic;
     private String subscription;
+    private String startConsumeTime;
+    private String stopConsumeTime;
     private String encodingType;
     private DeserializationConfig deserializationConfig;
+    private DataTypeConfig dataTypeConfig;
     private List<FieldConfig> fieldConfigs;
 }
