@@ -27,6 +27,8 @@ const resources = {
     translation: {
       'configs.menus.Process': 'Approval',
       'configs.menus.Groups': 'Ingestion',
+      'configs.menus.GroupsManagement': 'Ingestion Management',
+      'configs.menus.Groups.Template': 'Template Management',
       'configs.menus.Subscribe': 'Subscription',
       'configs.menus.Clusters': 'Clusters',
       'configs.menus.ClusterTags': 'ClusterTags',
@@ -46,6 +48,8 @@ const resources = {
     translation: {
       'configs.menus.Process': '审批管理',
       'configs.menus.Groups': '数据接入',
+      'configs.menus.GroupsManagement': '接入管理',
+      'configs.menus.Groups.Template': '模板管理',
       'configs.menus.Subscribe': '数据订阅',
       'configs.menus.Clusters': '集群管理',
       'configs.menus.ClusterTags': '标签管理',
