@@ -23,7 +23,7 @@ import { RenderList } from '@/plugins/RenderList';
 import { SourceInfo } from '../common/SourceInfo';
 
 const { I18n } = DataWithBackend;
-const { FieldDecorator, SyncField } = RenderRow;
+const { FieldDecorator, SyncField, IngestionField } = RenderRow;
 const { ColumnDecorator } = RenderList;
 
 export default class RedisSource
@@ -39,6 +39,7 @@ export default class RedisSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.Database')
   database: number;
 
@@ -51,6 +52,7 @@ export default class RedisSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.Username')
   username: string;
 
@@ -62,6 +64,7 @@ export default class RedisSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.Password')
   password: string;
 
@@ -92,6 +95,7 @@ export default class RedisSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.RedisCommand')
   redisCommand: string;
 
@@ -117,6 +121,7 @@ export default class RedisSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.RedisMode')
   redisMode: string;
 
@@ -129,6 +134,7 @@ export default class RedisSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.ClusterNodes')
   clusterNodes: string;
 
@@ -150,6 +156,7 @@ export default class RedisSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.AdditionalKey')
   additionalKey: string;
 
@@ -162,6 +169,7 @@ export default class RedisSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.Hostname')
   host: string;
 
@@ -177,6 +185,7 @@ export default class RedisSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.Port')
   port: number;
 
@@ -187,6 +196,7 @@ export default class RedisSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.PrimaryKey')
   primaryKey: string;
 
@@ -198,6 +208,7 @@ export default class RedisSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.Redis.Timeout')
   timeout: number;
 }
