@@ -24,7 +24,7 @@ import { SourceInfo } from '../common/SourceInfo';
 import i18n from '@/i18n';
 
 const { I18n } = DataWithBackend;
-const { FieldDecorator, SyncField } = RenderRow;
+const { FieldDecorator, SyncField, IngestionField } = RenderRow;
 const { ColumnDecorator } = RenderList;
 
 export default class SQLServerSource
@@ -40,6 +40,7 @@ export default class SQLServerSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.Hostname')
   hostname: string;
 
@@ -55,6 +56,7 @@ export default class SQLServerSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.Port')
   port: number;
 
@@ -67,6 +69,7 @@ export default class SQLServerSource
   })
   @ColumnDecorator()
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.Username')
   username: string;
 
@@ -78,6 +81,7 @@ export default class SQLServerSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.Password')
   password: string;
 
@@ -89,6 +93,7 @@ export default class SQLServerSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.Database')
   database: string;
 
@@ -111,6 +116,7 @@ export default class SQLServerSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.AllMigration')
   allMigration: boolean;
 
@@ -123,6 +129,7 @@ export default class SQLServerSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.ServerTimezone')
   serverTimezone: string;
 
@@ -134,6 +141,7 @@ export default class SQLServerSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.SchemaName')
   schemaName: string;
 
@@ -145,6 +153,7 @@ export default class SQLServerSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.TableName')
   tableName: string;
 
@@ -155,6 +164,7 @@ export default class SQLServerSource
     }),
   })
   @SyncField()
+  @IngestionField()
   @I18n('meta.Sources.SQLServer.PrimaryKey')
   primaryKey: string;
 }
