@@ -23,7 +23,7 @@ import { ModalProps } from 'antd/es/modal';
 import { useForm } from '@/ui/components/FormGenerator';
 import { useRequest } from '@/ui/hooks';
 import { useTranslation } from 'react-i18next';
-import { useDefaultMeta, useLoadMeta, TransformMetaType } from '@/plugins';
+import { useDefaultMeta, useLoadMeta } from '@/plugins';
 import request from '@/core/utils/request';
 import EditableTable, { ColumnsItemProps } from '../EditableTable';
 import i18n from '@/i18n';
@@ -39,14 +39,8 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId, isSource, ...mod
   const [form] = useForm();
   const { t } = useTranslation();
 
-  const { defaultValue } = useDefaultMeta('transform');
-
-  const [type, setType] = useState(defaultValue);
-
   const [sinkType, setSinkType] = useState('');
 
-  const { loading, Entity } = useLoadMeta<TransformMetaType>('transform', type);
-
   const { data, run: getData } = useRequest(
     streamId => ({
       url: `/stream/getBrief`,
@@ -77,25 +71,26 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId, isSource, ...mod
     },
   );
 
-  const fieldTypes = ['int', 'long', 'float', 'double', 'string', 'date', 'timestamp'].map(
-    item => ({
-      label: item,
-      value: item,
-    }),
-  );
+  const fieldTypes = [
+    'int',
+    'long',
+    'float',
+    'double',
+    'string',
+    'date',
+    'timestamp',
+    'function',
+  ].map(item => ({
+    label: item,
+    value: item,
+  }));
 
   const sinkFieldList: ColumnsItemProps[] = [
     {
       title: i18n.t('meta.Sinks.SourceFieldName'),
       dataIndex: 'sourceFieldName',
       type: 'input',
-      rules: [
-        { required: true },
-        {
-          pattern: /^[a-zA-Z_][a-zA-Z0-9_]*$/,
-          message: i18n.t('meta.Stream.FieldNameRule'),
-        },
-      ],
+      rules: [{ required: true }],
     },
     {
       title: i18n.t('meta.Sinks.SourceFieldType'),
@@ -108,7 +103,7 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId, isSource, ...mod
       },
     },
     {
-      title: i18n.t('meta.Stream.FieldName'),
+      title: i18n.t('components.FieldList.SinkFieldName'),
       dataIndex: 'fieldName',
       type: 'input',
       rules: [
@@ -120,7 +115,7 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId, isSource, ...mod
       ],
     },
     {
-      title: i18n.t('meta.Stream.FieldType'),
+      title: i18n.t('components.FieldList.SinkFieldType'),
       dataIndex: 'fieldType',
       type: 'select',
       initialValue: '',
@@ -130,7 +125,7 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId, isSource, ...mod
       rules: [{ required: true }],
     },
     {
-      title: i18n.t('meta.Stream.FieldComment'),
+      title: i18n.t('components.FieldList.FieldComment'),
       dataIndex: 'fieldComment',
     },
   ];
@@ -140,13 +135,7 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId, isSource, ...mod
       title: i18n.t('meta.Stream.FieldName'),
       dataIndex: 'fieldName',
       type: 'input',
-      rules: [
-        { required: true },
-        {
-          pattern: /^[a-zA-Z_][a-zA-Z0-9_]*$/,
-          message: i18n.t('meta.Stream.FieldNameRule'),
-        },
-      ],
+      rules: [{ required: true }],
     },
     {
       title: i18n.t('meta.Stream.FieldType'),
@@ -243,7 +232,7 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId, isSource, ...mod
             ? t('components.FieldList.CreateSource')
             : t('components.FieldList.CreateSink')
         }
-        width={888}
+        width={1000}
         onOk={onOk}
         footer={[
           <Button key="cancel" onClick={e => modalProps.onCancel(e)}>
@@ -254,16 +243,16 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId, isSource, ...mod
           </Button>,
         ]}
       >
-        <Spin spinning={loading}>
-          <Form form={form} initialValues={isSource === true ? data : sinkData?.list[0]}>
-            <Form.Item name={isSource === true ? 'fieldList' : 'sinkFieldList'}>
-              <EditableTable
-                columns={isSource === true ? fieldList : sinkFieldList}
-                dataSource={isSource === true ? data?.fieldList : sinkData?.list[0]?.sinkFieldList}
-              ></EditableTable>
-            </Form.Item>
-          </Form>
-        </Spin>
+        <Form form={form} initialValues={isSource === true ? data : sinkData?.list[0]}>
+          <Form.Item name={isSource === true ? 'fieldList' : 'sinkFieldList'}>
+            <EditableTable
+              columns={isSource === true ? fieldList : sinkFieldList}
+              dataSource={isSource === true ? data?.fieldList : sinkData?.list[0]?.sinkFieldList}
+              canBatchAdd={true}
+              upsetByFieldKey={true}
+            ></EditableTable>
+          </Form.Item>
+        </Form>
       </Modal>
     </>
   );
