@@ -277,7 +277,31 @@ const mysqlTypesConf = {
   varbinary: (m, d) => (1 <= m && m <= 64 ? '' : '1<=M<=64'),
   blob: () => '',
 };
-
+const oceanBaseTypesConf = {
+  tinyint: (m, d) => (1 <= m && m <= 4 ? '' : '1<=M<=4'),
+  smallint: (m, d) => (1 <= m && m <= 6 ? '' : '1<=M<=6'),
+  mediumint: (m, d) => (1 <= m && m <= 9 ? '' : '1<=M<=9'),
+  int: (m, d) => (1 <= m && m <= 11 ? '' : '1<=M<=11'),
+  float: (m, d) =>
+    1 <= m && m <= 255 && 1 <= d && d <= 30 && d <= m - 2 ? '' : '1<=M<=255,1<=D<=30,D<=M-2',
+  bigint: (m, d) => (1 <= m && m <= 20 ? '' : '1<=M<=20'),
+  double: (m, d) =>
+    1 <= m && m <= 255 && 1 <= d && d <= 30 && d <= m - 2 ? '' : '1<=M<=255,1<=D<=30,D<=M-2',
+  numeric: (m, d) =>
+    1 <= m && m <= 255 && 1 <= d && d <= 30 && d <= m - 2 ? '' : '1<=M<=255,1<=D<=30,D<=M-2',
+  decimal: (m, d) =>
+    1 <= m && m <= 255 && 1 <= d && d <= 30 && d <= m - 2 ? '' : '1<=M<=255,1<=D<=30,D<=M-2',
+  boolean: () => '',
+  date: () => '',
+  time: () => '',
+  datetime: () => '',
+  char: (m, d) => (1 <= m && m <= 255 ? '' : '1<=M<=255'),
+  varchar: (m, d) => (1 <= m && m <= 16383 ? '' : '1<=M<=16383'),
+  text: () => '',
+  binary: (m, d) => (1 <= m && m <= 64 ? '' : '1<=M<=64'),
+  varbinary: (m, d) => (1 <= m && m <= 64 ? '' : '1<=M<=64'),
+  blob: () => '',
+};
 const oracleTypesConf = {
   binary_float: (m, d) => (1 <= m && m <= 6 ? '' : '1 <= M <= 6'),
   binary_double: (m, d) => (1 <= m && m <= 10 ? '' : '1 <= M <= 10'),
@@ -394,6 +418,7 @@ export const fieldAllTypes = {
   ICEBERG: icebergFieldTypes,
   HUDI: hudiFieldTypes,
   MYSQL: getFieldTypes(mysqlTypesConf),
+  OCEANBASE: getFieldTypes(oceanBaseTypesConf),
   ORACLE: getFieldTypes(oracleTypesConf),
   POSTGRESQL: getFieldTypes(pgTypesConf),
   SQLSERVER: getFieldTypes(sqlServerTypesConf),
