@@ -71,7 +71,8 @@ const Comp: React.FC<Props> = ({ id, defaultType, ...modalProps }) => {
       values.type === 'SORT_ES' ||
       values.type === 'SORT_CKAFKA' ||
       values.type === 'SORT_KAFKA' ||
-      values.type === 'SORT_PULSAR'
+      values.type === 'SORT_PULSAR' ||
+      values.type === 'SORT_HTTP'
     ) {
       submitData.name = values.displayName;
     }
