@@ -27,13 +27,15 @@ import request from '@/core/utils/request';
 import { useFormContent } from './config';
 import { CommonInterface } from '../common';
 import { State } from '@/core/stores';
+import dayjs from 'dayjs';
+import { format } from '@/plugins/sync/common/SyncDefaultInfo';
 
 type Props = CommonInterface;
 
 const Comp = ({ inlongGroupId, inlongStreamId, readonly, isCreate }: Props, ref) => {
   const { t } = useTranslation();
   const [editing, { setTrue, setFalse }] = useBoolean(isCreate);
-
+  const conventionalTimeFormat = 'YYYY-MM-DD HH:mm';
   const { defaultValue } = useDefaultMeta('sync');
 
   const { userName } = useSelector<State, State>(state => state);
@@ -46,6 +48,17 @@ const Comp = ({ inlongGroupId, inlongStreamId, readonly, isCreate }: Props, ref)
     return !!inlongGroupId;
   }, [inlongGroupId]);
 
+  useEffect(() => {
+    if (isCreate) {
+      form.setFieldValue('scheduleType', 0);
+      form.setFieldValue('scheduleUnit', 'H');
+    }
+    if (isUpdate) {
+      form.setFieldValue('scheduleType', 0);
+      form.setFieldValue('scheduleUnit', 'H');
+    }
+  }, [form, isCreate, isUpdate]);
+
   const isUpdateStream = useMemo(() => {
     return !!inlongStreamId;
   }, [inlongStreamId]);
@@ -53,10 +66,27 @@ const Comp = ({ inlongGroupId, inlongStreamId, readonly, isCreate }: Props, ref)
   const { data, run: getData } = useRequest(`/group/get/${inlongGroupId}`, {
     ready: isUpdate,
     refreshDeps: [inlongGroupId],
-    formatResult: data => ({
-      ...data,
-      inCharges: data.inCharges.split(','),
-    }),
+    formatResult: data => {
+      if (data.inlongGroupMode === 1) {
+        return {
+          ...data,
+          scheduleType: 0,
+          scheduleUnit: 'H',
+          scheduleInterval: 0,
+          delayTime: dayjs('00:00', format),
+          selfDepend: 0,
+        };
+      }
+      return {
+        ...data,
+        inCharges: data.inCharges.split(','),
+        time: [
+          dayjs(dayjs(data?.startTime), conventionalTimeFormat),
+          dayjs(dayjs(data?.endTime), conventionalTimeFormat),
+        ],
+        delayTime: convertMinutesToDelayTime(data.delayTime),
+      };
+    },
     onSuccess: data => {
       setMqType(data.mqType);
       form.setFieldsValue(data);
@@ -77,6 +107,16 @@ const Comp = ({ inlongGroupId, inlongStreamId, readonly, isCreate }: Props, ref)
       },
     },
   );
+  const convertTimeToMinutes = timeString => {
+    const time = dayjs(timeString, 'HH:mm');
+    return time.hour() * 60 + time.minute();
+  };
+
+  const convertMinutesToDelayTime = totalMinutes => {
+    const hours = Math.floor(totalMinutes / 60);
+    const minutes = totalMinutes % 60;
+    return dayjs().hour(hours).minute(minutes);
+  };
   const { data: streamData, run: getDataStream } = useRequest(
     {
       url: '/stream/list',
@@ -98,14 +138,20 @@ const Comp = ({ inlongGroupId, inlongStreamId, readonly, isCreate }: Props, ref)
 
   const onOk = async () => {
     const values = await form.validateFields();
-
-    const submitData = {
+    let submitData = {
       ...values,
       version: data?.version,
-      inCharges: values.inCharges?.join(','),
-      inlongGroupMode: 1,
+      inCharges: values.inCharges instanceof Array ? values.inCharges?.join(',') : values.inCharges,
     };
-
+    if (values.inlongGroupMode === 2) {
+      submitData = {
+        ...submitData,
+        delayTime: convertTimeToMinutes(values?.delayTime?.format('HH:mm')),
+        startTime: dayjs(values?.time?.[0]?.format(conventionalTimeFormat)).valueOf(),
+        endTime: dayjs(values?.time?.[1]?.format(conventionalTimeFormat)).valueOf(),
+      };
+    }
+    delete submitData.time;
     const submitDataStream = {
       inlongGroupId: values.inlongGroupId,
       inlongStreamId: values.inlongGroupId,
@@ -181,9 +227,12 @@ const Comp = ({ inlongGroupId, inlongStreamId, readonly, isCreate }: Props, ref)
         form={form}
         content={formContent}
         initialValues={data}
-        onValuesChange={(c, values) => setMqType(values.mqType)}
+        onValuesChange={(c, values) => {
+          setMqType(values.mqType);
+        }}
         useMaxWidth={1400}
         col={14}
+        labelWrap
       />
 
       {!isCreate && !readonly && (
