@@ -17,7 +17,7 @@
  * under the License.
  */
 
-import React, { useState } from 'react';
+import React, { useEffect, useState } from 'react';
 import { Button, Card, Col, Divider, Row, Table } from 'antd';
 import { DoubleRightOutlined, PlusCircleOutlined } from '@ant-design/icons';
 import SyncSources from '../SyncSources';
@@ -27,6 +27,7 @@ import EditableTable, { ColumnsItemProps } from '@/ui/components/EditableTable';
 import i18n from '@/i18n';
 import FieldList from '@/ui/components/FieldList';
 import { ColumnsType } from 'antd/es/table';
+import { useRequest } from 'ahooks';
 
 export interface Props {
   inlongGroupId: string;
@@ -39,23 +40,30 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId }) => {
     setOpenT({ open: openT.open === false ? true : false });
   };
 
+  const { data, run: getList } = useRequest({
+    url: '/transform/list',
+    method: 'POST',
+    data: {
+      inlongGroupId,
+      inlongStreamId,
+      pageSize: 10,
+      pageNum: 1,
+    },
+  });
+
   const sinkColumns: ColumnsType = [
     {
-      title: i18n.t('meta.Sinks.SourceFieldName'),
-      dataIndex: 'sourceFieldName',
-    },
-    {
-      title: i18n.t('meta.Sinks.SourceFieldType'),
-      dataIndex: 'sourceFieldType',
-    },
-    {
-      title: i18n.t('meta.Stream.FieldName'),
+      title: i18n.t('components.FieldList.SinkFieldName'),
       dataIndex: 'fieldName',
     },
     {
-      title: i18n.t('meta.Stream.FieldType'),
+      title: i18n.t('components.FieldList.SinkFieldType'),
       dataIndex: 'fieldType',
     },
+    {
+      title: i18n.t('components.FieldList.FieldComment'),
+      dataIndex: 'fieldComment',
+    },
   ];
 
   const sourceColumns: ColumnsType = [
@@ -73,9 +81,13 @@ const Comp: React.FC<Props> = ({ inlongGroupId, inlongStreamId }) => {
     },
   ];
 
+  useEffect(() => {
+    getList();
+  }, [getList]);
+
   return (
     <>
-      {openT.open ? (
+      {openT.open || data?.total !== 0 ? (
         <Row gutter={[40, 48]}>
           <Col span={8}>
             <SyncSources inlongGroupId={inlongGroupId} inlongStreamId={inlongStreamId} />
