@@ -47,15 +47,22 @@ export const getColumns = ({ onEdit, onDelete }) => {
     {
       title: i18n.t('pages.UserManagement.config.Creator'),
       dataIndex: 'creator',
+      render: (text, record) => (
+        <>
+          <div>{text}</div>
+          <div>{record.createTime && timestampFormat(record.createTime)}</div>
+        </>
+      ),
     },
     {
       title: i18n.t('basic.Modifier'),
       dataIndex: 'modifier',
-    },
-    {
-      title: i18n.t('pages.UserManagement.config.CreateTime'),
-      dataIndex: 'createTime',
-      render: text => text && timestampFormat(text),
+      render: (text, record) => (
+        <>
+          <div>{text}</div>
+          <div>{record.modifyTime && timestampFormat(record.modifyTime)}</div>
+        </>
+      ),
     },
     {
       title: i18n.t('basic.Status'),
