@@ -17,26 +17,19 @@
 
 package org.apache.inlong.dataproxy.config.holder;
 
-import org.apache.inlong.common.constant.Constants;
-import org.apache.inlong.common.enums.DataTypeEnum;
-import org.apache.inlong.common.pojo.dataproxy.CacheClusterObject;
-import org.apache.inlong.common.pojo.dataproxy.CacheClusterSetObject;
-import org.apache.inlong.common.pojo.dataproxy.DataProxyCluster;
-import org.apache.inlong.common.pojo.dataproxy.DataProxyConfigResponse;
-import org.apache.inlong.common.pojo.dataproxy.InLongIdObject;
-import org.apache.inlong.common.pojo.dataproxy.ProxyClusterObject;
 import org.apache.inlong.dataproxy.config.CommonConfigHolder;
 import org.apache.inlong.dataproxy.config.ConfigHolder;
 import org.apache.inlong.dataproxy.config.ConfigManager;
 import org.apache.inlong.dataproxy.config.pojo.CacheClusterConfig;
 import org.apache.inlong.dataproxy.config.pojo.CacheType;
 import org.apache.inlong.dataproxy.config.pojo.IdTopicConfig;
-import org.apache.inlong.dataproxy.consts.ConfigConstants;
+import org.apache.inlong.dataproxy.config.pojo.InLongMetaConfig;
 import org.apache.inlong.sdk.commons.protocol.InlongId;
 
 import com.google.gson.Gson;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.tuple.ImmutablePair;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -74,7 +67,6 @@ public class MetaConfigHolder extends ConfigHolder {
     private String tmpDataMd5 = "";
     private final AtomicLong lastSyncVersion = new AtomicLong(0);
     // cached data
-    private final List<String> defTopics = new ArrayList<>();
     private final AtomicInteger clusterType = new AtomicInteger(CacheType.N.getId());
     private final ConcurrentHashMap<String, CacheClusterConfig> mqClusterMap = new ConcurrentHashMap<>();
     private final ConcurrentHashMap<String, IdTopicConfig> id2TopicSrcMap = new ConcurrentHashMap<>();
@@ -84,13 +76,6 @@ public class MetaConfigHolder extends ConfigHolder {
         super(metaConfigFileName);
     }
 
-    public void addDefTopic(String defTopic) {
-        if (StringUtils.isBlank(defTopic)) {
-            return;
-        }
-        defTopics.add(defTopic);
-    }
-
     /**
      * get source topic by groupId and streamId
      */
@@ -153,28 +138,46 @@ public class MetaConfigHolder extends ConfigHolder {
         }
     }
 
-    public boolean updateConfigMap(String inDataMd5, String inDataJsonStr) {
-        if (StringUtils.isBlank(inDataMd5)
-                || StringUtils.isBlank(inDataJsonStr)) {
-            return false;
-        }
+    public boolean updateConfigMap(InLongMetaConfig metaConfig) {
+        String inDataJsonStr;
+        // check cache data
         synchronized (this.lastSyncVersion) {
             if (this.lastSyncVersion.get() > this.lastUpdVersion.get()) {
-                if (inDataJsonStr.equals(tmpDataMd5)) {
+                if (tmpDataMd5.equals(metaConfig.getMd5())) {
                     return false;
                 }
-                LOG.info("Load changed metadata {} , but reloading content, over {} ms",
+                LOG.info("Update metadata: NOT UPDATE, {} is loading, but wast over {} ms",
                         getFileName(), System.currentTimeMillis() - this.lastSyncVersion.get());
                 return false;
             } else {
-                if (inDataMd5.equals(dataMd5)) {
+                if (dataMd5.equals(metaConfig.getMd5())) {
                     return false;
                 }
             }
-            return storeConfigToFile(inDataMd5, inDataJsonStr);
+            InLongMetaConfig newMetaConfig = buildMixedMetaConfig(metaConfig);
+            try {
+                inDataJsonStr = GSON.toJson(newMetaConfig);
+            } catch (Throwable e) {
+                LOG.error("Update metadata: failure to serial meta config to json", e);
+                return false;
+            }
+            return storeConfigToFile(inDataJsonStr, newMetaConfig);
         }
     }
 
+    private InLongMetaConfig buildMixedMetaConfig(InLongMetaConfig metaConfig) {
+        // process and check cluster info
+        Map<String, CacheClusterConfig> newClusterConfigMap =
+                new HashMap<>(metaConfig.getClusterConfigMap().size());
+        newClusterConfigMap.putAll(metaConfig.getClusterConfigMap());
+        // process id2topic info
+        Map<String, IdTopicConfig> newIdTopicConfigMap =
+                new HashMap<>(metaConfig.getIdTopicConfigMap().size());
+        newIdTopicConfigMap.putAll(metaConfig.getIdTopicConfigMap());
+        return new InLongMetaConfig(metaConfig.getMd5(),
+                metaConfig.getMqType(), newClusterConfigMap, newIdTopicConfigMap);
+    }
+
     public List<CacheClusterConfig> forkCachedCLusterConfig() {
         List<CacheClusterConfig> result = new ArrayList<>();
         if (mqClusterMap.isEmpty()) {
@@ -214,231 +217,66 @@ public class MetaConfigHolder extends ConfigHolder {
         // check meta update setting
         if (!CommonConfigHolder.getInstance().isEnableStartupUsingLocalMetaFile()
                 && !ConfigManager.handshakeManagerOk.get()) {
-            LOG.warn("Failed to load json config from {}, don't obtain metadata from the Manager,"
-                    + " and the startup via the cache file is false", getFileName());
+            LOG.warn("Load metadata: StartupUsingLocalMetaFile is false, don't obtain metadata from {}"
+                    + " before handshake with Manager", getFileName());
             return false;
         }
         String jsonString = "";
+        InLongMetaConfig metaConfig;
         readWriteLock.writeLock().lock();
         try {
             jsonString = loadConfigFromFile();
             if (StringUtils.isBlank(jsonString)) {
-                LOG.warn("Load changed json {}, but no records configured", getFileName());
+                LOG.error("Load metadata: NOT LOADED, changed but empty records, file:{}", getFileName());
                 return true;
             }
-            DataProxyConfigResponse metaConfig =
-                    GSON.fromJson(jsonString, DataProxyConfigResponse.class);
-            // check result tag
-            if (!metaConfig.isResult() || metaConfig.getErrCode() != DataProxyConfigResponse.SUCC) {
-                LOG.warn("Load failed json config from {}, error code is {}",
-                        getFileName(), metaConfig.getErrCode());
+            try {
+                metaConfig = GSON.fromJson(jsonString, InLongMetaConfig.class);
+            } catch (Throwable e) {
+                LOG.error("Load metadata: NOT LOADED, parse json config failure, file:{}", getFileName(), e);
                 return true;
             }
-            // check cluster data
-            DataProxyCluster clusterObj = metaConfig.getData();
-            if (clusterObj == null) {
-                LOG.warn("Load failed json config from {}, malformed content, data is null", getFileName());
+            // check required fields
+            ImmutablePair<Boolean, String> paramChkResult = validRequiredFields(metaConfig);
+            if (!paramChkResult.getLeft()) {
+                LOG.error("Load metadata: NOT LOADED, {}, file:{}",
+                        paramChkResult.getRight(), getFileName());
                 return true;
             }
-            // update cache data
-            if (updateCacheData(jsonString, metaConfig)) {
-                LOG.info("Load changed {} file success!", getFileName());
-            }
+            // update cached data
+            replaceCacheConfig(metaConfig.getMqType(),
+                    metaConfig.getClusterConfigMap(), metaConfig.getIdTopicConfigMap());
+            this.dataMd5 = metaConfig.getMd5();
+            this.dataStr = jsonString;
+            LOG.info("Load metadata: LOADED success, from {}!", getFileName());
             return true;
         } catch (Throwable e) {
-            LOG.warn("Process json {} changed data {} failure", getFileName(), jsonString, e);
+            LOG.error("Load metadata: NOT LOADED, load from {} throw exception", getFileName(), e);
             return false;
         } finally {
+            if (this.lastSyncVersion.get() == 0) {
+                this.lastUpdVersion.set(System.currentTimeMillis());
+                this.lastSyncVersion.compareAndSet(0, this.lastUpdVersion.get());
+            } else {
+                this.lastUpdVersion.set(this.lastSyncVersion.get());
+            }
             readWriteLock.writeLock().unlock();
         }
     }
 
-    private boolean updateCacheData(String jsonString, DataProxyConfigResponse metaConfig) {
-        // get and valid inlongIds configure
-        ProxyClusterObject proxyClusterObject = metaConfig.getData().getProxyCluster();
-        if (proxyClusterObject == null) {
-            LOG.warn("Load failed json config from {}, malformed content, proxyCluster field is null",
-                    getFileName());
-            return false;
-        }
-        CacheClusterSetObject clusterSetObject = metaConfig.getData().getCacheClusterSet();
-        if (clusterSetObject == null) {
-            LOG.warn("Load failed json config from {}, malformed content, cacheClusterSet field is null",
-                    getFileName());
-            return false;
-        }
-        List<InLongIdObject> inLongIds = proxyClusterObject.getInlongIds();
-        if (inLongIds == null) {
-            LOG.warn("Load failed json config from {}, malformed content, inlongIds field is null",
-                    getFileName());
-            return false;
-        }
-        // get mq type
-        CacheType mqType = CacheType.convert(clusterSetObject.getType());
-        if (mqType == CacheType.N) {
-            LOG.warn("Load failed json config from {}, unsupported mq type {}",
-                    getFileName(), clusterSetObject.getType());
-            return false;
-        }
-        // get mq cluster info
-        Map<String, CacheClusterConfig> tmpClusterConfigMap = new HashMap<>();
-        for (CacheClusterObject clusterObject : clusterSetObject.getCacheClusters()) {
-            if (clusterObject == null || StringUtils.isBlank(clusterObject.getName())) {
-                continue;
-            }
-            CacheClusterConfig config = new CacheClusterConfig();
-            config.setClusterName(clusterObject.getName());
-            config.setToken(clusterObject.getToken());
-            config.getParams().putAll(clusterObject.getParams());
-            tmpClusterConfigMap.put(config.getClusterName(), config);
-        }
-        if (tmpClusterConfigMap.isEmpty()) {
-            LOG.warn("Load failed json config from {}, no valid {} mq cluster",
-                    getFileName(), clusterSetObject.getType());
-            return false;
-        }
-        // get topic config info
-        Map<String, IdTopicConfig> tmpTopicConfigMap = buildCacheTopicConfig(mqType, inLongIds);
-        replaceCacheConfig(mqType, tmpClusterConfigMap, tmpTopicConfigMap);
-        // update cached data
-        this.dataMd5 = metaConfig.getMd5();
-        this.dataStr = jsonString;
-        if (this.lastSyncVersion.get() == 0) {
-            this.lastUpdVersion.set(System.currentTimeMillis());
-            this.lastSyncVersion.compareAndSet(0, this.lastUpdVersion.get());
-        } else {
-            this.lastUpdVersion.set(this.lastSyncVersion.get());
-        }
-        return true;
-    }
-
-    private void replaceCacheConfig(CacheType cacheType,
-            Map<String, CacheClusterConfig> clusterConfigMap,
-            Map<String, IdTopicConfig> topicConfigMap) {
-        this.clusterType.getAndSet(cacheType.getId());
-        // remove deleted id2topic config
-        Set<String> tmpKeys = new HashSet<>();
-        for (Map.Entry<String, IdTopicConfig> entry : id2TopicSrcMap.entrySet()) {
-            if (entry == null || entry.getKey() == null || entry.getValue() == null) {
-                continue;
-            }
-            if (!topicConfigMap.containsKey(entry.getKey())) {
-                tmpKeys.add(entry.getKey());
-            }
-        }
-        for (String key : tmpKeys) {
-            id2TopicSrcMap.remove(key);
-        }
-        // add new id2topic source config
-        id2TopicSrcMap.putAll(topicConfigMap);
-        // add new id2topic sink config
-        id2TopicSinkMap.putAll(topicConfigMap);
-        // remove deleted cluster config
-        tmpKeys.clear();
-        for (Map.Entry<String, CacheClusterConfig> entry : mqClusterMap.entrySet()) {
-            if (entry == null || entry.getKey() == null || entry.getValue() == null) {
-                continue;
-            }
-            if (!clusterConfigMap.containsKey(entry.getKey())) {
-                tmpKeys.add(entry.getKey());
-            }
-        }
-        for (String key : tmpKeys) {
-            mqClusterMap.remove(key);
-        }
-        // add new mq cluster config
-        mqClusterMap.putAll(clusterConfigMap);
-    }
-
-    private Map<String, IdTopicConfig> buildCacheTopicConfig(
-            CacheType mqType, List<InLongIdObject> inLongIds) {
-        Map<String, IdTopicConfig> tmpTopicConfigMap = new HashMap<>();
-        if (inLongIds.isEmpty()) {
-            return tmpTopicConfigMap;
-        }
-        int index;
-        String[] idItems;
-        String groupId;
-        String streamId;
-        String topicName;
-        String tenant;
-        String nameSpace;
-        for (InLongIdObject idObject : inLongIds) {
-            if (idObject == null
-                    || StringUtils.isBlank(idObject.getInlongId())
-                    || StringUtils.isBlank(idObject.getTopic())) {
-                continue;
-            }
-            // parse inlong id
-            idItems = idObject.getInlongId().split("\\.");
-            if (idItems.length == 2) {
-                if (StringUtils.isBlank(idItems[0])) {
-                    continue;
-                }
-                groupId = idItems[0].trim();
-                streamId = idItems[1].trim();
-            } else {
-                groupId = idObject.getInlongId().trim();
-                streamId = "";
-            }
-            topicName = idObject.getTopic().trim();
-            // change full topic name "pulsar-xxx/test/base_topic_name" to
-            // base topic name "base_topic_name"
-            index = topicName.lastIndexOf('/');
-            if (index >= 0) {
-                topicName = topicName.substring(index + 1).trim();
-            }
-            tenant = idObject.getParams().getOrDefault(ConfigConstants.KEY_TENANT, "");
-            nameSpace = idObject.getParams().getOrDefault(ConfigConstants.KEY_NAMESPACE, "");
-            if (StringUtils.isBlank(idObject.getTopic())) {
-                // namespace field must exist and value not be empty,
-                // otherwise it is an illegal configuration item.
-                continue;
-            }
-            if (mqType.equals(CacheType.TUBE)) {
-                topicName = nameSpace;
-            } else if (mqType.equals(CacheType.KAFKA)) {
-                if (topicName.equals(streamId)) {
-                    topicName = String.format(Constants.DEFAULT_KAFKA_TOPIC_FORMAT, nameSpace, topicName);
-                }
-            }
-            IdTopicConfig tmpConfig = new IdTopicConfig();
-            tmpConfig.setInlongGroupIdAndStreamId(groupId, streamId);
-            tmpConfig.setTenantAndNameSpace(tenant, nameSpace);
-            tmpConfig.setTopicName(topicName);
-            tmpConfig.setParams(idObject.getParams());
-            tmpConfig.setDataType(DataTypeEnum.convert(
-                    idObject.getParams().getOrDefault("dataType", DataTypeEnum.TEXT.getType())));
-            tmpConfig.setFieldDelimiter(idObject.getParams().getOrDefault("fieldDelimiter", "|"));
-            tmpConfig.setFileDelimiter(idObject.getParams().getOrDefault("fileDelimiter", "\n"));
-            tmpConfig.setUseExtendedFields(Boolean.valueOf(
-                    idObject.getParams().getOrDefault("useExtendedFields", "false")));
-            tmpTopicConfigMap.put(tmpConfig.getUid(), tmpConfig);
-            if (mqType.equals(CacheType.TUBE)
-                    && !tmpConfig.getUid().equals(tmpConfig.getInlongGroupId())
-                    && tmpTopicConfigMap.get(tmpConfig.getInlongGroupId()) == null) {
-                IdTopicConfig tmpConfig2 = new IdTopicConfig();
-                tmpConfig2.setInlongGroupIdAndStreamId(groupId, "");
-                tmpConfig.setTenantAndNameSpace(tenant, nameSpace);
-                tmpConfig2.setTopicName(topicName);
-                tmpConfig2.setDataType(tmpConfig.getDataType());
-                tmpConfig2.setFieldDelimiter(tmpConfig.getFieldDelimiter());
-                tmpConfig2.setFileDelimiter(tmpConfig.getFileDelimiter());
-                tmpConfig2.setParams(tmpConfig.getParams());
-                tmpTopicConfigMap.put(tmpConfig.getUid(), tmpConfig2);
-            }
-        }
-        return tmpTopicConfigMap;
-    }
-
     /**
      * store meta config to file
+     *
+     * @param metaJsonStr meta info string
+     * @param metaConfig  meta info object
+     *
+     * @return  store result
      */
-    private boolean storeConfigToFile(String inDataMd5, String metaJsonStr) {
+    private boolean storeConfigToFile(String metaJsonStr, InLongMetaConfig metaConfig) {
         boolean isSuccess = false;
         String filePath = getFilePath();
         if (StringUtils.isBlank(filePath)) {
-            LOG.error("Error in writing file {} as the file path is null.", getFileName());
+            LOG.error("Store metadata: error in writing file {} as the file path is null.", getFileName());
             return isSuccess;
         }
         readWriteLock.writeLock().lock();
@@ -453,12 +291,12 @@ public class MetaConfigHolder extends ConfigHolder {
             FileUtils.writeStringToFile(tmpNewFile, metaJsonStr, StandardCharsets.UTF_8);
             FileUtils.copyFile(tmpNewFile, sourceFile);
             tmpNewFile.delete();
-            tmpDataMd5 = inDataMd5;
+            tmpDataMd5 = metaConfig.getMd5();
             lastSyncVersion.set(System.currentTimeMillis());
             isSuccess = true;
             setFileChanged();
         } catch (Throwable ex) {
-            LOG.error("Error in writing file {}", getFileName(), ex);
+            LOG.error("Store metadata: exception thrown while writing to file {}", getFileName(), ex);
         } finally {
             readWriteLock.writeLock().unlock();
         }
@@ -466,12 +304,59 @@ public class MetaConfigHolder extends ConfigHolder {
     }
 
     /**
-     * load from holder
+     * update locally cached configuration with input information
+     *
+     * @param cacheType  mq cluster type
+     * @param clusterConfigMap  mq cluster config
+     * @param idTopicConfigMap  id to topic config
+     */
+    private void replaceCacheConfig(CacheType cacheType,
+            Map<String, CacheClusterConfig> clusterConfigMap,
+            Map<String, IdTopicConfig> idTopicConfigMap) {
+        this.clusterType.getAndSet(cacheType.getId());
+        // remove deleted id2topic config
+        Set<String> tmpRmvKeys = new HashSet<>();
+        for (Map.Entry<String, IdTopicConfig> entry : id2TopicSrcMap.entrySet()) {
+            if (entry == null || entry.getKey() == null || entry.getValue() == null) {
+                continue;
+            }
+            if (!idTopicConfigMap.containsKey(entry.getKey())) {
+                tmpRmvKeys.add(entry.getKey());
+            }
+        }
+        for (String key : tmpRmvKeys) {
+            id2TopicSrcMap.remove(key);
+        }
+        // add new id2topic source config
+        id2TopicSrcMap.putAll(idTopicConfigMap);
+        // add new id2topic sink config
+        id2TopicSinkMap.putAll(idTopicConfigMap);
+        // remove deleted cluster config
+        tmpRmvKeys.clear();
+        for (Map.Entry<String, CacheClusterConfig> entry : mqClusterMap.entrySet()) {
+            if (entry == null || entry.getKey() == null || entry.getValue() == null) {
+                continue;
+            }
+            if (!clusterConfigMap.containsKey(entry.getKey())) {
+                tmpRmvKeys.add(entry.getKey());
+            }
+        }
+        for (String key : tmpRmvKeys) {
+            mqClusterMap.remove(key);
+        }
+        // add new mq cluster config
+        mqClusterMap.putAll(clusterConfigMap);
+    }
+
+    /**
+     * load configure from holder
+     *
+     * @return the configure info
      */
     private String loadConfigFromFile() {
         String result = "";
         if (StringUtils.isBlank(getFileName())) {
-            LOG.error("Fail to load json {} as the file name is null.", getFileName());
+            LOG.error("Load metadata: fail to load json {} as the file name is null.", getFileName());
             return result;
         }
         InputStream inStream = null;
@@ -479,12 +364,12 @@ public class MetaConfigHolder extends ConfigHolder {
             URL url = getClass().getClassLoader().getResource(getFileName());
             inStream = url != null ? url.openStream() : null;
             if (inStream == null) {
-                LOG.error("Fail to load json {} as the input stream is null", getFileName());
+                LOG.error("Load metadata: fail to load json {} as the input stream is null", getFileName());
                 return result;
             }
             int size = inStream.available();
             if (size > MAX_ALLOWED_JSON_FILE_SIZE) {
-                LOG.error("Fail to load json {} as the content size({}) over max allowed size({})",
+                LOG.error("Load metadata: fail to load json {} as the content size({}) over max allowed size({})",
                         getFileName(), size, MAX_ALLOWED_JSON_FILE_SIZE);
                 return result;
             }
@@ -492,16 +377,45 @@ public class MetaConfigHolder extends ConfigHolder {
             inStream.read(buffer);
             result = new String(buffer, StandardCharsets.UTF_8);
         } catch (Throwable e) {
-            LOG.error("Fail to load json {}", getFileName(), e);
+            LOG.error("Load metadata: exception thrown while load from file {}", getFileName(), e);
         } finally {
             if (null != inStream) {
                 try {
                     inStream.close();
                 } catch (IOException e) {
-                    LOG.error("Fail in inStream.close for file {}", getFileName(), e);
+                    LOG.error("Load metadata: fail in inStream.close for file {}", getFileName(), e);
                 }
             }
         }
         return result;
     }
+
+    /**
+     * check required fields status
+     *
+     * @param metaConfig  response from Manager
+     *
+     * @return   check result
+     */
+    public ImmutablePair<Boolean, String> validRequiredFields(InLongMetaConfig metaConfig) {
+        if (metaConfig == null) {
+            return ImmutablePair.of(false, "metaConfig object is null");
+        } else if (metaConfig.getMd5() == null) {
+            return ImmutablePair.of(false, "metaConfig.md5 field is null");
+        } else if (metaConfig.getMqType() == null) {
+            return ImmutablePair.of(false, "metaConfig.mqType field is null");
+        } else if (metaConfig.getMqType() == CacheType.N) {
+            return ImmutablePair.of(false, "metaConfig.mqType value is CacheType.N");
+        } else if (metaConfig.getClusterConfigMap() == null) {
+            return ImmutablePair.of(false, "metaConfig.clusterConfigMap field is null");
+        } else if (metaConfig.getClusterConfigMap().isEmpty()) {
+            return ImmutablePair.of(false, "metaConfig.clusterConfigMap field is empty");
+        } else if (metaConfig.getIdTopicConfigMap() == null) {
+            return ImmutablePair.of(false, "metaConfig.idTopicConfigMap field is null");
+        } else if (metaConfig.getIdTopicConfigMap().isEmpty()) {
+            return ImmutablePair.of(false, "metaConfig.idTopicConfigMap is empty");
+        }
+        return ImmutablePair.of(true, "ok");
+    }
+
 }
