@@ -25,6 +25,7 @@ import org.apache.inlong.dataproxy.config.CommonConfigHolder;
 import org.apache.inlong.dataproxy.config.ConfigManager;
 import org.apache.inlong.dataproxy.config.holder.ConfigUpdateCallback;
 import org.apache.inlong.dataproxy.consts.AttrConstants;
+import org.apache.inlong.dataproxy.consts.SourceConstants;
 import org.apache.inlong.dataproxy.consts.StatConstants;
 import org.apache.inlong.dataproxy.metrics.DataProxyMetricItem;
 import org.apache.inlong.dataproxy.metrics.DataProxyMetricItemSet;
@@ -148,9 +149,9 @@ public abstract class BaseSource
         this.strPort = String.valueOf(this.srcPort);
         // get source logic type
         String tmpVal = context.getString(
-                SourceConstants.SRCCXT_LOGIC_TYPE_NAME, ReportResourceType.INLONG);
+                SourceConstants.SRCCXT_LOGIC_EXECUTE_TYPE, ReportResourceType.INLONG);
         Preconditions.checkArgument(StringUtils.isNotBlank(tmpVal),
-                SourceConstants.SRCCXT_LOGIC_TYPE_NAME + " config is blank");
+                SourceConstants.SRCCXT_LOGIC_EXECUTE_TYPE + " config is blank");
         this.rptSrcType = tmpVal.trim().toUpperCase();
         // get message factory
         tmpVal = context.getString(SourceConstants.SRCCXT_MSG_FACTORY_NAME,
@@ -275,7 +276,12 @@ public abstract class BaseSource
         }
         startSource();
         // register
+        ConfigManager.getInstance().addSourceReportInfo(srcHost,
+                String.valueOf(srcPort), rptSrcType, getProtocolName().toUpperCase());
         AdminServiceRegister.register(ProxyServiceMBean.MBEAN_TYPE, this.cachedSrcName, this);
+        logger.info("Source {} started at ({}:{}), {}={}, Protocal={}", this.getCachedSrcName(),
+                srcHost, srcPort, SourceConstants.SRCCXT_LOGIC_EXECUTE_TYPE, rptSrcType,
+                getProtocolName().toUpperCase());
     }
 
     @Override
@@ -479,7 +485,7 @@ public abstract class BaseSource
         if (result) {
             metricItem.readSuccessCount.incrementAndGet();
             metricItem.readSuccessSize.addAndGet(size);
-            AuditUtils.add(AuditUtils.AUDIT_ID_DATAPROXY_READ_SUCCESS, event);
+            AuditUtils.addInputSuccess(event);
         } else {
             metricItem.readFailCount.incrementAndGet();
             metricItem.readFailSize.addAndGet(size);
