@@ -17,28 +17,33 @@
 
 package org.apache.inlong.manager.client.cli;
 
-import com.beust.jcommander.Parameter;
-import com.beust.jcommander.Parameters;
-import com.beust.jcommander.converters.FileConverter;
 import org.apache.inlong.manager.client.api.InlongClient;
 import org.apache.inlong.manager.client.api.InlongGroup;
 import org.apache.inlong.manager.client.api.InlongGroupContext;
 import org.apache.inlong.manager.client.api.InlongStreamBuilder;
 import org.apache.inlong.manager.client.api.inner.client.InlongClusterClient;
+import org.apache.inlong.manager.client.api.inner.client.InlongTenantClient;
+import org.apache.inlong.manager.client.api.inner.client.InlongTenantRoleClient;
 import org.apache.inlong.manager.client.api.inner.client.UserClient;
 import org.apache.inlong.manager.client.cli.pojo.CreateGroupConf;
 import org.apache.inlong.manager.client.cli.util.ClientUtils;
 import org.apache.inlong.manager.client.cli.validator.UserTypeValidator;
 import org.apache.inlong.manager.common.enums.DataFormat;
-import org.apache.inlong.manager.common.enums.UserTypeEnum;
+import org.apache.inlong.manager.common.enums.TenantUserTypeEnum;
 import org.apache.inlong.manager.common.util.JsonUtils;
 import org.apache.inlong.manager.pojo.cluster.ClusterNodeRequest;
 import org.apache.inlong.manager.pojo.cluster.ClusterRequest;
 import org.apache.inlong.manager.pojo.cluster.ClusterTagRequest;
 import org.apache.inlong.manager.pojo.sort.FlinkSortConf;
 import org.apache.inlong.manager.pojo.stream.InlongStreamInfo;
+import org.apache.inlong.manager.pojo.tenant.InlongTenantRequest;
+import org.apache.inlong.manager.pojo.user.TenantRoleRequest;
 import org.apache.inlong.manager.pojo.user.UserRequest;
 
+import com.beust.jcommander.Parameter;
+import com.beust.jcommander.Parameters;
+import com.beust.jcommander.converters.FileConverter;
+
 import java.io.File;
 import java.util.List;
 import java.util.Optional;
@@ -46,7 +51,7 @@ import java.util.Optional;
 import static org.apache.inlong.manager.client.cli.consts.GroupConstants.DEFAULT_DATA_ENCODING;
 import static org.apache.inlong.manager.client.cli.consts.GroupConstants.DEFAULT_DATA_SEPARATOR;
 import static org.apache.inlong.manager.client.cli.consts.GroupConstants.DEFAULT_IGNORE_PARSE_ERROR;
-import static org.apache.inlong.manager.client.cli.consts.GroupConstants.DEFAULT_LIGHTWEIGHT;
+import static org.apache.inlong.manager.client.cli.consts.GroupConstants.DEFAULT_INLONG_GROUP_MODE;
 import static org.apache.inlong.manager.common.consts.InlongConstants.ADMIN_USER;
 
 /**
@@ -65,6 +70,8 @@ public class CreateCommand extends AbstractCommand {
         jcommander.addCommand("cluster-tag", new CreateClusterTag());
         jcommander.addCommand("cluster-node", new CreateClusterNode());
         jcommander.addCommand("user", new CreateUser());
+        jcommander.addCommand("tenant", new CreateTenant());
+        jcommander.addCommand("tenant-role", new CreateTenantRole());
     }
 
     @Parameters(commandDescription = "Create group by json file")
@@ -117,7 +124,7 @@ public class CreateCommand extends AbstractCommand {
             String inlongStreamId = groupConf.getStreamInfo().getInlongStreamId();
             // group
             groupConf.getGroupInfo().setInCharges(ADMIN_USER);
-            groupConf.getGroupInfo().setLightweight(DEFAULT_LIGHTWEIGHT);
+            groupConf.getGroupInfo().setInlongGroupMode(DEFAULT_INLONG_GROUP_MODE);
             groupConf.getGroupInfo().setSortConf(new FlinkSortConf());
 
             // stream
@@ -253,7 +260,7 @@ public class CreateCommand extends AbstractCommand {
                 UserRequest request = new UserRequest();
                 request.setName(username);
                 request.setPassword(password);
-                request.setAccountType(UserTypeEnum.parseName(type));
+                request.setAccountType(TenantUserTypeEnum.parseName(type));
                 request.setValidDays(validDays);
                 ClientUtils.initClientFactory();
                 UserClient userClient = ClientUtils.clientFactory.getUserClient();
@@ -266,4 +273,70 @@ public class CreateCommand extends AbstractCommand {
             }
         }
     }
+
+    @Parameters(commandDescription = "Create tenant")
+    private static class CreateTenant extends AbstractCommandRunner {
+
+        @Parameter()
+        private List<String> params;
+
+        @Parameter(names = {"-n", "--name"}, description = "tenant name")
+        private String name;
+
+        @Parameter(names = {"-d", "--description"}, description = "tenant description")
+        private String description;
+
+        @Override
+        void run() {
+            try {
+                InlongTenantRequest request = new InlongTenantRequest();
+                request.setName(name);
+                request.setDescription(description);
+                request.setVersion(0);
+                ClientUtils.initClientFactory();
+                InlongTenantClient tenantClient = ClientUtils.clientFactory.getInlongTenantClient();
+                Integer userId = tenantClient.save(request);
+                if (userId != null) {
+                    System.out.println("Create tenant success! ID: " + userId);
+                }
+            } catch (Exception e) {
+                System.out.println(e.getMessage());
+            }
+        }
+    }
+
+    @Parameters(commandDescription = "Create tenant role")
+    private static class CreateTenantRole extends AbstractCommandRunner {
+
+        @Parameter()
+        private List<String> params;
+
+        @Parameter(names = {"-u", "--username"}, description = "username")
+        private String username;
+
+        @Parameter(names = {"-p", "--role-code"}, description = "role code")
+        private String roleCode;
+
+        @Parameter(names = {"-t", "--tenant"}, description = "tenant")
+        private String tenant;
+
+        @Override
+        void run() {
+            try {
+                TenantRoleRequest request = new TenantRoleRequest();
+                request.setUsername(username);
+                request.setRoleCode(roleCode);
+                request.setTenant(tenant);
+                request.setVersion(0);
+                ClientUtils.initClientFactory();
+                InlongTenantRoleClient roleClient = ClientUtils.clientFactory.getInlongTenantRoleClient();
+                Integer roleId = roleClient.save(request);
+                if (roleId != null) {
+                    System.out.println("Create role success! ID: " + roleId);
+                }
+            } catch (Exception e) {
+                System.out.println(e.getMessage());
+            }
+        }
+    }
 }
