@@ -37,7 +37,7 @@ public class GroupInfo {
 
     @ParseStatus(clazz = SimpleGroupStatus.class)
     private String status;
-    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
+    @JsonFormat(pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSZ", timezone = "GMT+8")
     private Date modifyTime;
 
 }
