@@ -39,6 +39,6 @@ public class SinkInfo {
 
     @ParseStatus(clazz = SimpleGroupStatus.class)
     private String status;
-    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
+    @JsonFormat(pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSZ", timezone = "GMT+8")
     private Date modifyTime;
 }
