@@ -33,6 +33,6 @@ public class UserInfo {
     private Integer accountType;
     private String status;
     private String creator;
-    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
+    @JsonFormat(pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSZ", timezone = "GMT+8")
     private Date createTime;
 }
