@@ -56,6 +56,7 @@ public class ClientFactory {
     private final InlongTenantClient inlongTenantClient;
     private final InlongTenantRoleClient inlongTenantRoleClient;
     private final InLongScheduleClient inLongScheduleClient;
+    private final AuditAlertRuleClient auditAlertRuleClient;
 
     public ClientFactory(ClientConfiguration configuration) {
         groupClient = new InlongGroupClient(configuration);
@@ -76,5 +77,6 @@ public class ClientFactory {
         inlongTenantClient = new InlongTenantClient(configuration);
         inlongTenantRoleClient = new InlongTenantRoleClient(configuration);
         inLongScheduleClient = new InLongScheduleClient(configuration);
+        auditAlertRuleClient = new AuditAlertRuleClient(configuration);
     }
-}
+}
\ No newline at end of file
