@@ -20,11 +20,13 @@ package org.apache.inlong.manager.client.api.inner.client;
 import org.apache.inlong.manager.client.api.ClientConfiguration;
 import org.apache.inlong.manager.client.api.service.DataNodeApi;
 import org.apache.inlong.manager.client.api.util.ClientUtils;
+import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.util.Preconditions;
 import org.apache.inlong.manager.pojo.common.PageResult;
 import org.apache.inlong.manager.pojo.common.Response;
 import org.apache.inlong.manager.pojo.common.UpdateResult;
 import org.apache.inlong.manager.pojo.node.DataNodeInfo;
+import org.apache.inlong.manager.pojo.node.DataNodePageRequest;
 import org.apache.inlong.manager.pojo.node.DataNodeRequest;
 
 /**
@@ -45,9 +47,11 @@ public class DataNodeClient {
      * @return cluster id after saving
      */
     public Integer save(DataNodeRequest request) {
-        Preconditions.checkNotNull(request, "request cannot be null");
-        Preconditions.checkNotEmpty(request.getName(), "data node name cannot be empty");
-        Preconditions.checkNotEmpty(request.getType(), "data node type cannot be empty");
+        Preconditions.expectNotNull(request, "request cannot be null");
+        Preconditions.expectNotBlank(request.getName(), ErrorCodeEnum.INVALID_PARAMETER,
+                "data node name cannot be empty");
+        Preconditions.expectNotBlank(request.getType(), ErrorCodeEnum.INVALID_PARAMETER,
+                "data node type cannot be empty");
         Response<Integer> response = ClientUtils.executeHttpCall(dataNodeApi.save(request));
         ClientUtils.assertRespSuccess(response);
         return response.getData();
@@ -60,7 +64,7 @@ public class DataNodeClient {
      * @return node info
      */
     public DataNodeInfo get(Integer id) {
-        Preconditions.checkNotNull(id, "data node id cannot be null");
+        Preconditions.expectNotNull(id, "data node id cannot be null");
         Response<DataNodeInfo> response = ClientUtils.executeHttpCall(dataNodeApi.get(id));
         ClientUtils.assertRespSuccess(response);
         return response.getData();
@@ -72,9 +76,9 @@ public class DataNodeClient {
      * @param request page request conditions
      * @return node list
      */
-    public PageResult<DataNodeInfo> list(DataNodeRequest request) {
-        Preconditions.checkNotNull(request, "request cannot be null");
-        Response<PageResult<DataNodeInfo>> response = ClientUtils.executeHttpCall(dataNodeApi.list(request));
+    public PageResult<DataNodeInfo> list(DataNodePageRequest pageRequest) {
+        Preconditions.expectNotNull(pageRequest, "request cannot be null");
+        Response<PageResult<DataNodeInfo>> response = ClientUtils.executeHttpCall(dataNodeApi.list(pageRequest));
         ClientUtils.assertRespSuccess(response);
         return response.getData();
     }
@@ -86,10 +90,12 @@ public class DataNodeClient {
      * @return whether succeed
      */
     public Boolean update(DataNodeRequest request) {
-        Preconditions.checkNotNull(request, "request cannot be null");
-        Preconditions.checkNotEmpty(request.getName(), "data node name cannot be empty");
-        Preconditions.checkNotEmpty(request.getType(), "data node type cannot be empty");
-        Preconditions.checkNotNull(request.getId(), "data node id cannot be null");
+        Preconditions.expectNotNull(request, "request cannot be null");
+        Preconditions.expectNotBlank(request.getName(), ErrorCodeEnum.INVALID_PARAMETER,
+                "data node name cannot be empty");
+        Preconditions.expectNotBlank(request.getType(), ErrorCodeEnum.INVALID_PARAMETER,
+                "data node type cannot be empty");
+        Preconditions.expectNotNull(request.getId(), "data node id cannot be null");
         Response<Boolean> response = ClientUtils.executeHttpCall(dataNodeApi.update(request));
         ClientUtils.assertRespSuccess(response);
         return response.getData();
@@ -102,9 +108,11 @@ public class DataNodeClient {
      * @return update result
      */
     public UpdateResult updateByKey(DataNodeRequest request) {
-        Preconditions.checkNotNull(request, "request cannot be null");
-        Preconditions.checkNotEmpty(request.getName(), "data node name cannot be empty");
-        Preconditions.checkNotEmpty(request.getType(), "data node type cannot be empty");
+        Preconditions.expectNotNull(request, "request cannot be null");
+        Preconditions.expectNotBlank(request.getName(), ErrorCodeEnum.INVALID_PARAMETER,
+                "data node name cannot be empty");
+        Preconditions.expectNotBlank(request.getType(), ErrorCodeEnum.INVALID_PARAMETER,
+                "data node type cannot be empty");
         Response<UpdateResult> response = ClientUtils.executeHttpCall(dataNodeApi.updateByKey(request));
         ClientUtils.assertRespSuccess(response);
         return response.getData();
@@ -117,7 +125,7 @@ public class DataNodeClient {
      * @return whether succeed
      */
     public Boolean delete(Integer id) {
-        Preconditions.checkNotNull(id, "data node id cannot be null");
+        Preconditions.expectNotNull(id, "data node id cannot be null");
         Response<Boolean> response = ClientUtils.executeHttpCall(dataNodeApi.delete(id));
         ClientUtils.assertRespSuccess(response);
         return response.getData();
@@ -131,8 +139,8 @@ public class DataNodeClient {
      * @return whether succeed
      */
     public Boolean deleteByKey(String name, String type) {
-        Preconditions.checkNotEmpty(name, "data node name cannot be empty or null");
-        Preconditions.checkNotEmpty(type, "data node type cannot be empty or null");
+        Preconditions.expectNotBlank(name, ErrorCodeEnum.INVALID_PARAMETER, "data node name cannot be empty or null");
+        Preconditions.expectNotBlank(type, ErrorCodeEnum.INVALID_PARAMETER, "data node type cannot be empty or null");
         Response<Boolean> response = ClientUtils.executeHttpCall(dataNodeApi.deleteByKey(name, type));
         ClientUtils.assertRespSuccess(response);
         return response.getData();
