@@ -17,12 +17,10 @@
 
 package org.apache.inlong.manager.client.api.inner.client;
 
-import com.fasterxml.jackson.core.type.TypeReference;
 import org.apache.inlong.manager.client.api.ClientConfiguration;
 import org.apache.inlong.manager.client.api.service.InlongConsumeApi;
 import org.apache.inlong.manager.client.api.util.ClientUtils;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
-import org.apache.inlong.manager.common.util.JsonUtils;
 import org.apache.inlong.manager.common.util.Preconditions;
 import org.apache.inlong.manager.pojo.common.PageResult;
 import org.apache.inlong.manager.pojo.common.Response;
@@ -33,8 +31,6 @@ import org.apache.inlong.manager.pojo.consume.InlongConsumePageRequest;
 import org.apache.inlong.manager.pojo.consume.InlongConsumeRequest;
 import org.apache.inlong.manager.pojo.workflow.WorkflowResult;
 
-import java.util.Map;
-
 /**
  * Client for {@link InlongConsumeApi}.
  */
@@ -96,12 +92,10 @@ public class InlongConsumeClient {
      * @return inlong consume list
      */
     public PageResult<InlongConsumeBriefInfo> list(InlongConsumePageRequest request) {
-        Map<String, Object> requestMap = JsonUtils.OBJECT_MAPPER.convertValue(request,
-                new TypeReference<Map<String, Object>>() {
-                });
+        Preconditions.expectNotNull(request, "inlong consume request cannot be null");
 
         Response<PageResult<InlongConsumeBriefInfo>> response = ClientUtils.executeHttpCall(
-                inlongConsumeApi.list(requestMap));
+                inlongConsumeApi.list(request));
         ClientUtils.assertRespSuccess(response);
         return response.getData();
     }
