@@ -18,10 +18,11 @@
 package org.apache.inlong.manager.client.api.inner;
 
 import org.apache.inlong.manager.client.api.inner.client.NoAuthClient;
-import org.apache.inlong.manager.common.enums.UserTypeEnum;
+import org.apache.inlong.manager.common.enums.TenantUserTypeEnum;
 import org.apache.inlong.manager.common.util.JsonUtils;
 import org.apache.inlong.manager.pojo.common.Response;
 import org.apache.inlong.manager.pojo.user.UserRequest;
+
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.Test;
 
@@ -48,7 +49,7 @@ public class NoAuthClientTest extends ClientFactoryTest {
         UserRequest request = UserRequest.builder()
                 .name("username")
                 .password("pwd")
-                .accountType(UserTypeEnum.ADMIN.getCode())
+                .accountType(TenantUserTypeEnum.TENANT_ADMIN.getCode())
                 .validDays(9999)
                 .build();
 
