@@ -34,6 +34,8 @@ public class WorkflowProcessEntity {
     private String title;
 
     private String inlongGroupId;
+    private String inlongStreamId;
+    private String tenant;
     private String applicant;
     private String status;
     private String formData;
