@@ -17,10 +17,14 @@
 
 package org.apache.inlong.manager.dao.mapper;
 
+import org.apache.inlong.manager.common.tenant.MultiTenantQuery;
 import org.apache.inlong.manager.dao.entity.ModuleConfigEntity;
 import org.apache.inlong.manager.pojo.module.ModulePageRequest;
 
+import org.apache.ibatis.annotations.Options;
 import org.apache.ibatis.annotations.Param;
+import org.apache.ibatis.cursor.Cursor;
+import org.apache.ibatis.mapping.ResultSetType;
 import org.springframework.stereotype.Repository;
 
 import java.util.List;
@@ -36,4 +40,8 @@ public interface ModuleConfigEntityMapper {
 
     List<ModuleConfigEntity> selectByCondition(@Param("request") ModulePageRequest request);
 
+    @MultiTenantQuery(with = false)
+    @Options(resultSetType = ResultSetType.FORWARD_ONLY, fetchSize = Integer.MIN_VALUE)
+    Cursor<ModuleConfigEntity> selectAllModuleConfigs();
+
 }
