@@ -18,7 +18,9 @@
 package org.apache.inlong.manager.dao.mapper;
 
 import org.apache.inlong.manager.dao.entity.OperationLogEntity;
+import org.apache.inlong.manager.pojo.operationLog.OperationLogRequest;
 
+import org.apache.ibatis.annotations.Param;
 import org.springframework.stereotype.Repository;
 
 import java.util.List;
@@ -36,6 +38,8 @@ public interface OperationLogEntityMapper {
 
     OperationLogEntity selectByPrimaryKey(Integer id);
 
+    List<OperationLogEntity> selectByCondition(@Param("request") OperationLogRequest operationLogRequest);
+
     int updateByPrimaryKeySelective(OperationLogEntity record);
 
     int updateByPrimaryKey(OperationLogEntity record);
