@@ -17,8 +17,10 @@
 
 package org.apache.inlong.manager.dao.mapper;
 
-import org.apache.ibatis.annotations.Param;
 import org.apache.inlong.manager.dao.entity.StreamTransformEntity;
+import org.apache.inlong.manager.pojo.transform.TransformPageRequest;
+
+import org.apache.ibatis.annotations.Param;
 import org.springframework.stereotype.Repository;
 
 import java.util.List;
@@ -35,6 +37,8 @@ public interface StreamTransformEntityMapper {
     List<StreamTransformEntity> selectByRelatedId(@Param("groupId") String groupId, @Param("streamId") String streamId,
             @Param("transformName") String transformName);
 
+    List<StreamTransformEntity> selectByCondition(@Param("request") TransformPageRequest request);
+
     int updateById(StreamTransformEntity record);
 
     int updateByIdSelective(StreamTransformEntity record);
