@@ -17,7 +17,11 @@
 
 package org.apache.inlong.manager.dao;
 
+import org.apache.inlong.manager.pojo.user.LoginUserUtils;
+import org.apache.inlong.manager.pojo.user.UserInfo;
 import org.apache.inlong.manager.test.BaseTest;
+
+import org.junit.jupiter.api.BeforeEach;
 import org.springframework.boot.autoconfigure.SpringBootApplication;
 import org.springframework.boot.test.context.SpringBootTest;
 import org.springframework.test.annotation.Rollback;
@@ -29,4 +33,26 @@ import org.springframework.transaction.annotation.Transactional;
 @SpringBootTest(classes = DaoBaseTest.class)
 public abstract class DaoBaseTest extends BaseTest {
 
+    public static final String PUBLIC_TENANT = "public";
+    public static final String ANOTHER_TENANT = "another";
+    public static final String ADMIN = "admin";
+
+    @BeforeEach
+    public void login() {
+        UserInfo userInfo = new UserInfo();
+        userInfo.setTenant(PUBLIC_TENANT);
+        userInfo.setName(ADMIN);
+        LoginUserUtils.setUserLoginInfo(userInfo);
+    }
+
+    public void setOtherUser(String newUser) {
+        UserInfo info = LoginUserUtils.getLoginUser();
+        info.setName(newUser);
+    }
+
+    public void setOtherTenant(String newTenant) {
+        UserInfo info = LoginUserUtils.getLoginUser();
+        info.setTenant(newTenant);
+    }
+
 }
