@@ -55,9 +55,6 @@ public class ClusterPageRequest extends PageRequest {
     @ApiModelProperty(value = "Parent cluster ID, used for cluster node")
     private Integer parentId;
 
-    @ApiModelProperty(value = "Inlong tenant of cluster", hidden = true)
-    private String tenant;
-
     @ApiModelProperty(value = "Keywords, name, url, cluster tag, etc.")
     private String keyword;
 
