@@ -20,13 +20,18 @@ package org.apache.inlong.manager.pojo.cluster.agent;
 import org.apache.inlong.manager.common.enums.ClusterType;
 import org.apache.inlong.manager.common.util.JsonTypeDefine;
 import org.apache.inlong.manager.pojo.cluster.ClusterNodeRequest;
+import org.apache.inlong.manager.pojo.module.ModuleHistory;
 
 import io.swagger.annotations.ApiModel;
 import io.swagger.annotations.ApiModelProperty;
+import lombok.Builder.Default;
 import lombok.Data;
 import lombok.EqualsAndHashCode;
 import lombok.ToString;
 
+import java.util.ArrayList;
+import java.util.List;
+
 /**
  * Inlong cluster node request for Agent
  */
@@ -40,6 +45,20 @@ public class AgentClusterNodeRequest extends ClusterNodeRequest {
     @ApiModelProperty(value = "Agent group name")
     private String agentGroup;
 
+    @ApiModelProperty(value = "Agent restart time")
+    private Integer agentRestartTime = 0;
+
+    @ApiModelProperty(value = "Install restart time")
+    private Integer installRestartTime = 0;
+
+    @ApiModelProperty(value = "Module id list")
+    @Default
+    private List<Integer> moduleIdList = new ArrayList<>();
+
+    @ApiModelProperty("History list of module")
+    @Default
+    private List<ModuleHistory> moduleHistoryList = new ArrayList<>();
+
     public AgentClusterNodeRequest() {
         this.setType(ClusterType.AGENT);
     }
