@@ -21,7 +21,9 @@ import org.apache.inlong.manager.common.enums.ClusterType;
 import org.apache.inlong.manager.common.util.JsonTypeDefine;
 import org.apache.inlong.manager.pojo.cluster.ClusterRequest;
 
+import com.fasterxml.jackson.annotation.JsonProperty;
 import io.swagger.annotations.ApiModel;
+import io.swagger.annotations.ApiModelProperty;
 import lombok.Data;
 import lombok.EqualsAndHashCode;
 import lombok.ToString;
@@ -36,6 +38,10 @@ import lombok.ToString;
 @ApiModel("Inlong cluster request for Kafka")
 public class KafkaClusterRequest extends ClusterRequest {
 
+    @JsonProperty("bootstrap.servers")
+    @ApiModelProperty(value = "Kafka bootstrap servers' URL")
+    private String bootstrapServers;
+
     public KafkaClusterRequest() {
         this.setType(ClusterType.KAFKA);
     }
