@@ -17,9 +17,6 @@
 
 package org.apache.inlong.manager.pojo.group.tubemq;
 
-import io.swagger.annotations.ApiModel;
-import lombok.Data;
-import lombok.NoArgsConstructor;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
 import org.apache.inlong.manager.common.util.CommonBeanUtils;
@@ -27,6 +24,11 @@ import org.apache.inlong.manager.common.util.JsonUtils;
 import org.apache.inlong.manager.pojo.group.BaseInlongGroup;
 import org.apache.inlong.manager.pojo.group.InlongGroupRequest;
 
+import io.swagger.annotations.ApiModel;
+import lombok.Data;
+import lombok.NoArgsConstructor;
+import org.apache.commons.lang3.StringUtils;
+
 import javax.validation.constraints.NotNull;
 
 /**
@@ -40,8 +42,11 @@ public class InlongTubeMQDTO extends BaseInlongGroup {
     /**
      * Get the dto instance from the request
      */
-    public static InlongTubeMQDTO getFromRequest(InlongGroupRequest request) {
-        return CommonBeanUtils.copyProperties(request, InlongTubeMQDTO::new, true);
+    public static InlongTubeMQDTO getFromRequest(InlongGroupRequest request, String extParams) {
+        InlongTubeMQDTO dto = StringUtils.isNotBlank(extParams)
+                ? InlongTubeMQDTO.getFromJson(extParams)
+                : new InlongTubeMQDTO();
+        return CommonBeanUtils.copyProperties(request, dto, true);
     }
 
     /**
