@@ -58,7 +58,7 @@ public class GroupHeartbeatResponse {
     @ApiModelProperty(value = "Report time of heartbeat")
     private Long reportTime;
 
-    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
+    @JsonFormat(pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSZ", timezone = "GMT+8")
     private Date modifyTime;
 
 }
