@@ -17,11 +17,12 @@
 
 package org.apache.inlong.manager.pojo.node;
 
+import org.apache.inlong.manager.pojo.common.PageRequest;
+
 import io.swagger.annotations.ApiModel;
 import io.swagger.annotations.ApiModelProperty;
 import lombok.Data;
 import lombok.EqualsAndHashCode;
-import org.apache.inlong.manager.pojo.common.PageRequest;
 import org.hibernate.validator.constraints.Length;
 
 import javax.validation.constraints.Pattern;
@@ -57,4 +58,7 @@ public class DataNodePageRequest extends PageRequest {
     @ApiModelProperty(value = "Whether the current user is in the administrator role", hidden = true)
     private Boolean isAdminRole;
 
+    @ApiModelProperty(value = "Inlong tenant to which the data node belongs", hidden = true)
+    private String tenant;
+
 }
