@@ -17,15 +17,18 @@
 
 package org.apache.inlong.manager.pojo.node.hive;
 
+import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
+import org.apache.inlong.manager.common.exceptions.BusinessException;
+import org.apache.inlong.manager.common.util.CommonBeanUtils;
+import org.apache.inlong.manager.common.util.JsonUtils;
+
 import io.swagger.annotations.ApiModel;
 import io.swagger.annotations.ApiModelProperty;
 import lombok.AllArgsConstructor;
 import lombok.Builder;
 import lombok.Data;
 import lombok.NoArgsConstructor;
-import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
-import org.apache.inlong.manager.common.exceptions.BusinessException;
-import org.apache.inlong.manager.common.util.JsonUtils;
+import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -61,14 +64,11 @@ public class HiveDataNodeDTO {
     /**
      * Get the dto instance from the request
      */
-    public static HiveDataNodeDTO getFromRequest(HiveDataNodeRequest request) throws Exception {
-        return HiveDataNodeDTO.builder()
-                .hiveVersion(request.getHiveVersion())
-                .hiveConfDir(request.getHiveConfDir())
-                .dataPath(request.getDataPath())
-                .warehouse(request.getWarehouse())
-                .hdfsUgi(request.getHdfsUgi())
-                .build();
+    public static HiveDataNodeDTO getFromRequest(HiveDataNodeRequest request, String extParams) {
+        HiveDataNodeDTO dto = StringUtils.isNotBlank(extParams)
+                ? HiveDataNodeDTO.getFromJson(extParams)
+                : new HiveDataNodeDTO();
+        return CommonBeanUtils.copyProperties(request, dto, true);
     }
 
     /**
