@@ -78,6 +78,15 @@ public class ClsSink extends StreamSink {
     @ApiModelProperty("Cloud log service topic storage duration")
     private Integer storageDuration;
 
+    @ApiModelProperty("contentOffset")
+    private Integer contentOffset = 0;
+
+    @ApiModelProperty("fieldOffset")
+    private Integer fieldOffset;
+
+    @ApiModelProperty("separator")
+    private String separator;
+
     public ClsSink() {
         this.setSinkType(SinkType.CLS);
     }
