@@ -17,6 +17,12 @@
 
 package org.apache.inlong.manager.pojo.sink.kafka;
 
+import org.apache.inlong.manager.common.consts.SinkType;
+import org.apache.inlong.manager.common.util.CommonBeanUtils;
+import org.apache.inlong.manager.common.util.JsonTypeDefine;
+import org.apache.inlong.manager.pojo.sink.SinkRequest;
+import org.apache.inlong.manager.pojo.sink.StreamSink;
+
 import io.swagger.annotations.ApiModel;
 import io.swagger.annotations.ApiModelProperty;
 import lombok.AllArgsConstructor;
@@ -24,11 +30,6 @@ import lombok.Data;
 import lombok.EqualsAndHashCode;
 import lombok.ToString;
 import lombok.experimental.SuperBuilder;
-import org.apache.inlong.manager.common.consts.SinkType;
-import org.apache.inlong.manager.common.util.CommonBeanUtils;
-import org.apache.inlong.manager.common.util.JsonTypeDefine;
-import org.apache.inlong.manager.pojo.sink.SinkRequest;
-import org.apache.inlong.manager.pojo.sink.StreamSink;
 
 /**
  * Kafka sink info
@@ -49,7 +50,7 @@ public class KafkaSink extends StreamSink {
     private String topicName;
 
     @ApiModelProperty("Partition number of the topic")
-    private String partitionNum;
+    private Integer partitionNum;
 
     @ApiModelProperty("Data Serialization, support: json, canal, avro")
     private String serializationType;
