@@ -19,6 +19,7 @@ package org.apache.inlong.manager.pojo.sort.node.base;
 
 import org.apache.inlong.common.enums.DataTypeEnum;
 import org.apache.inlong.common.enums.MessageWrapType;
+import org.apache.inlong.common.util.StringUtil;
 import org.apache.inlong.manager.common.fieldtype.strategy.FieldTypeMappingStrategy;
 import org.apache.inlong.manager.pojo.sort.util.FieldInfoUtils;
 import org.apache.inlong.manager.pojo.stream.StreamField;
@@ -32,10 +33,10 @@ import org.apache.inlong.sort.protocol.node.format.DebeziumJsonFormat;
 import org.apache.inlong.sort.protocol.node.format.Format;
 import org.apache.inlong.sort.protocol.node.format.InLongMsgFormat;
 import org.apache.inlong.sort.protocol.node.format.JsonFormat;
+import org.apache.inlong.sort.protocol.node.format.KvFormat;
 import org.apache.inlong.sort.protocol.node.format.RawFormat;
 
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.lang3.StringUtils;
 
 import java.util.List;
 import java.util.Objects;
@@ -90,8 +91,10 @@ public interface ExtractNodeProvider extends NodeProvider {
      * Parse format
      *
      * @param serializationType data serialization, support: csv, json, canal, avro, etc
-     * @param wrapWithInlongMsg whether wrap content with {@link InLongMsgFormat}
+     * @param wrapType whether wrap content with {@link InLongMsgFormat}
      * @param separatorStr the separator of data content
+     * @param kvSeparatorStr the kv separator
+     * @param escapeCharStr the escape char
      * @param ignoreParseErrors whether ignore deserialization error data
      * @return the format for serialized content
      */
@@ -99,15 +102,14 @@ public interface ExtractNodeProvider extends NodeProvider {
             String serializationType,
             String wrapType,
             String separatorStr,
+            String kvSeparatorStr,
+            String escapeCharStr,
             Boolean ignoreParseErrors) {
         Format format;
         DataTypeEnum dataType = DataTypeEnum.forType(serializationType);
         switch (dataType) {
             case CSV:
-                if (StringUtils.isNumeric(separatorStr)) {
-                    char dataSeparator = (char) Integer.parseInt(separatorStr);
-                    separatorStr = Character.toString(dataSeparator);
-                }
+                separatorStr = StringUtil.parseChar(separatorStr);
                 CsvFormat csvFormat = new CsvFormat(separatorStr);
                 csvFormat.setIgnoreParseErrors(ignoreParseErrors);
                 format = csvFormat;
@@ -131,6 +133,12 @@ public interface ExtractNodeProvider extends NodeProvider {
             case RAW:
                 format = new RawFormat();
                 break;
+            case KV:
+                separatorStr = StringUtil.parseChar(separatorStr);
+                kvSeparatorStr = StringUtil.parseChar(kvSeparatorStr);
+                escapeCharStr = StringUtil.parseChar(escapeCharStr);
+                format = new KvFormat(separatorStr, kvSeparatorStr, escapeCharStr, ignoreParseErrors, null, null, null);
+                break;
             default:
                 throw new IllegalArgumentException(String.format("Unsupported dataType=%s", dataType));
         }
