@@ -17,6 +17,7 @@
 
 package org.apache.inlong.manager.pojo.sort.node.provider;
 
+import org.apache.inlong.common.enums.MessageWrapType;
 import org.apache.inlong.common.enums.MetaField;
 import org.apache.inlong.common.pojo.sort.dataflow.field.format.LongFormatInfo;
 import org.apache.inlong.manager.common.consts.SourceType;
@@ -36,6 +37,7 @@ import org.springframework.stereotype.Service;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.stream.Collectors;
 
 /**
@@ -64,7 +66,9 @@ public class PulsarProvider implements ExtractNodeProvider {
                 pulsarSource.getDataEscapeChar(),
                 pulsarSource.getIgnoreParseError());
 
-        PulsarScanStartupMode startupMode = PulsarScanStartupMode.forName(pulsarSource.getScanStartupMode());
+        String startupMode =
+                StringUtils.isNotBlank(pulsarSource.getScanStartupMode()) ? PulsarScanStartupMode.forName(
+                        pulsarSource.getScanStartupMode()).getValue() : null;
         final String primaryKey = pulsarSource.getPrimaryKey();
         final String serviceUrl = pulsarSource.getServiceUrl();
         final String adminUrl = pulsarSource.getAdminUrl();
@@ -81,7 +85,7 @@ public class PulsarProvider implements ExtractNodeProvider {
                 adminUrl,
                 serviceUrl,
                 format,
-                startupMode.getValue(),
+                startupMode,
                 primaryKey,
                 pulsarSource.getSubscription(),
                 scanStartupSubStartOffset,
@@ -106,4 +110,24 @@ public class PulsarProvider implements ExtractNodeProvider {
         fieldInfos.add(0, new FieldInfo(MetaField.AUDIT_DATA_TIME.name(), new LongFormatInfo()));
         return fieldInfos;
     }
+
+    @Override
+    public boolean needInlongPropertiesField(StreamNode streamNode) {
+        if (streamNode instanceof PulsarSource) {
+            PulsarSource pulsarSource = (PulsarSource) streamNode;
+            return !Objects.equals(pulsarSource.getWrapType(), MessageWrapType.RAW.getName());
+        }
+        return true;
+    }
+
+    @Override
+    public List<StreamField> addInlongPropertiesFieldForStream(List<StreamField> streamFields) {
+        List<String> fieldNames = streamFields.stream().map(StreamField::getFieldName).collect(Collectors.toList());
+        if (!fieldNames.contains(MetaField.INLONG_PROPERTIES.name())) {
+            streamFields.add(0,
+                    new StreamField(0, "map", MetaField.INLONG_PROPERTIES.name(), "inlong properties", null, 1,
+                            MetaField.INLONG_PROPERTIES.name()));
+        }
+        return streamFields;
+    }
 }
\ No newline at end of file
