@@ -54,7 +54,7 @@ public class SortSourceGroupInfo {
                     JsonElement element = jo.get(k);
                     if (element.isJsonPrimitive()) {
                         extParamsMap.put(k, element.getAsString());
-                    } else {
+                    } else if (!element.isJsonNull()) {
                         extParamsMap.put(k, element.toString());
                     }
                 });
