@@ -24,6 +24,9 @@ import lombok.Data;
 import org.hibernate.validator.constraints.Length;
 
 import javax.validation.constraints.NotBlank;
+import javax.validation.constraints.NotNull;
+
+import java.util.List;
 
 /**
  * Data add task information
@@ -33,9 +36,16 @@ import javax.validation.constraints.NotBlank;
 @JsonTypeInfo(use = JsonTypeInfo.Id.NAME, visible = true, property = "sourceType")
 public class DataAddTaskRequest {
 
-    @ApiModelProperty(value = "Source ID")
+    @ApiModelProperty(value = "Group Id")
+    @NotBlank(message = "inlongGroupId cannot be blank")
+    private String groupId;
+
+    @ApiModelProperty(value = "Source ID, When the source ID is not null, data add task entries based on the source ID")
     private Integer sourceId;
 
+    @ApiModelProperty(value = "Agent ip List")
+    private List<String> agentIpList;
+
     @ApiModelProperty("Source type, including: FILE, KAFKA, etc.")
     @NotBlank(message = "sourceType cannot be blank")
     @Length(min = 1, max = 20, message = "length must be between 1 and 20")
@@ -44,4 +54,14 @@ public class DataAddTaskRequest {
     @ApiModelProperty(value = "Audit version", hidden = true)
     private String auditVersion;
 
+    @ApiModelProperty(value = "Data start time")
+    private String dataTimeFrom;
+
+    @ApiModelProperty(value = "Data end time")
+    private String dataTimeTo;
+
+    @ApiModelProperty(value = "Increase Audit Version")
+    @NotNull(message = "IncreaseAuditVersion cannot be null")
+    private Boolean increaseAuditVersion;
+
 }
