@@ -57,6 +57,9 @@ public class MongoDBSourceDTO {
     @ApiModelProperty("MongoDB collection name")
     private String collection;
 
+    @ApiModelProperty("Debezium snapshot mode. Available options are initial and never, default is initial")
+    private String snapshotMode;
+
     @ApiModelProperty("Primary key must be shared by all tables")
     private String primaryKey;
 
