@@ -33,5 +33,7 @@ public class BaseInlongStream {
 
     // you can add extend parameters in this class
     private String predefinedFields;
+    private String kvSeparator;
+    private String lineSeparator;
 
 }
