@@ -133,18 +133,18 @@ public class InlongStreamInfo extends BaseInlongStream {
     @ApiModelProperty(value = "The message body wrap type, including: RAW, INLONG_MSG_V0, INLONG_MSG_V1, etc")
     private String wrapType;
 
-    @ApiModelProperty(value = "The compression type used for dataproxy and sort side data transmission to reduce the network IO overhead")
-    private String inlongCompressType;
-
     @ApiModelProperty(value = "If use extended fields")
-    private Boolean useExtendedFields = false;
+    private Boolean useExtendedFields;
 
     @ApiModelProperty(value = "Extended field size")
-    private Integer extendedFieldSize = 0;
+    private Integer extendedFieldSize;
 
     @ApiModelProperty("The multiple enable of sink")
     private Boolean sinkMultipleEnable;
 
+    @ApiModelProperty("Whether to sync field")
+    private Boolean syncField = false;
+
     @ApiModelProperty(value = "Whether to ignore the parse errors of field value")
     private Boolean ignoreParseError;
 
