@@ -20,15 +20,22 @@ package org.apache.inlong.manager.service.cluster;
 import org.apache.inlong.manager.common.enums.ClusterType;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
+import org.apache.inlong.manager.common.util.CommonBeanUtils;
+import org.apache.inlong.manager.dao.entity.InlongClusterEntity;
+import org.apache.inlong.manager.dao.entity.InlongClusterNodeEntity;
 import org.apache.inlong.manager.pojo.cluster.ClusterInfo;
 import org.apache.inlong.manager.pojo.cluster.ClusterRequest;
 import org.apache.inlong.manager.pojo.cluster.dataproxy.DataProxyClusterInfo;
-import org.apache.inlong.manager.common.util.CommonBeanUtils;
-import org.apache.inlong.manager.dao.entity.InlongClusterEntity;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.stereotype.Service;
 
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
 /**
  * DataProxy cluster operator.
  */
@@ -60,4 +67,17 @@ public class DataProxyClusterOperator extends AbstractClusterOperator {
         return CommonBeanUtils.copyProperties(entity, DataProxyClusterInfo::new);
     }
 
+    @Override
+    public Object getClusterInfo(InlongClusterEntity entity) {
+        List<InlongClusterNodeEntity> clusterNodeEntityList =
+                clusterNodeEntityMapper.selectByParentId(entity.getId(), null);
+        Map<String, Object> map = new HashMap<>();
+        List<String> urlList = new ArrayList<>();
+        for (InlongClusterNodeEntity clusterNodeEntity : clusterNodeEntityList) {
+            urlList.add(clusterNodeEntity.getIp() + ":" + clusterNodeEntity.getPort());
+        }
+        map.put("urls", urlList);
+        return map;
+    }
+
 }
