@@ -62,6 +62,7 @@ import org.apache.inlong.manager.pojo.cluster.TenantClusterTagInfo;
 import org.apache.inlong.manager.pojo.cluster.TenantClusterTagPageRequest;
 import org.apache.inlong.manager.pojo.cluster.TenantClusterTagRequest;
 import org.apache.inlong.manager.pojo.cluster.agent.AgentClusterNodeRequest;
+import org.apache.inlong.manager.pojo.cluster.dataproxy.DataProxyClusterDTO;
 import org.apache.inlong.manager.pojo.cluster.dataproxy.DataProxyClusterNodeDTO;
 import org.apache.inlong.manager.pojo.cluster.pulsar.PulsarClusterDTO;
 import org.apache.inlong.manager.pojo.common.PageResult;
@@ -90,6 +91,7 @@ import com.github.pagehelper.PageHelper;
 import com.google.common.base.Joiner;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Sets;
+import com.google.common.util.concurrent.ThreadFactoryBuilder;
 import com.google.gson.Gson;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -101,6 +103,8 @@ import org.springframework.stereotype.Service;
 import org.springframework.transaction.annotation.Isolation;
 import org.springframework.transaction.annotation.Transactional;
 
+import javax.annotation.PostConstruct;
+
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
@@ -113,8 +117,19 @@ import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
 import java.util.UUID;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.Executors;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.ThreadPoolExecutor.CallerRunsPolicy;
+import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 
+import static org.apache.inlong.manager.common.consts.InlongConstants.ALIVE_TIME_MS;
+import static org.apache.inlong.manager.common.consts.InlongConstants.CORE_POOL_SIZE;
+import static org.apache.inlong.manager.common.consts.InlongConstants.MAX_POOL_SIZE;
+import static org.apache.inlong.manager.common.consts.InlongConstants.QUEUE_SIZE;
 import static org.apache.inlong.manager.pojo.cluster.InlongClusterTagExtParam.packExtParams;
 import static org.apache.inlong.manager.pojo.cluster.InlongClusterTagExtParam.unpackExtParams;
 
@@ -126,6 +141,15 @@ public class InlongClusterServiceImpl implements InlongClusterService {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(InlongClusterServiceImpl.class);
     private static final Gson GSON = new Gson();
+    private final ExecutorService executorService = new ThreadPoolExecutor(
+            CORE_POOL_SIZE,
+            MAX_POOL_SIZE,
+            ALIVE_TIME_MS,
+            TimeUnit.MILLISECONDS,
+            new LinkedBlockingQueue<>(QUEUE_SIZE),
+            new ThreadFactoryBuilder().setNameFormat("agent-install-%s").build(),
+            new CallerRunsPolicy());
+    private final LinkedBlockingQueue<ClusterNodeRequest> pendingInstallRequests = new LinkedBlockingQueue<>();
 
     @Autowired
     private InlongGroupEntityMapper groupMapper;
@@ -158,6 +182,20 @@ public class InlongClusterServiceImpl implements InlongClusterService {
     @Autowired
     private DataProxyConfigRepository proxyRepository;
 
+    @PostConstruct
+    private void startInstallTask() {
+        processInstall();
+        setReloadTimer();
+        LOGGER.info("install task started successfully");
+    }
+
+    private void setReloadTimer() {
+        ScheduledExecutorService executorService = Executors.newSingleThreadScheduledExecutor();
+        long reloadInterval = 60000L;
+        executorService.scheduleWithFixedDelay(this::processInstall, reloadInterval, reloadInterval,
+                TimeUnit.MILLISECONDS);
+    }
+
     @Override
     public Integer saveTag(ClusterTagRequest request, String operator) {
         LOGGER.debug("begin to save cluster tag {}", request);
@@ -688,12 +726,25 @@ public class InlongClusterServiceImpl implements InlongClusterService {
             LOGGER.error(errMsg);
             throw new BusinessException(errMsg);
         }
+
+        // check ip if belongs to two different clusters at the same time
+        List<InlongClusterNodeEntity> existList =
+                clusterNodeMapper.selectByIpAndType(request.getIp(), request.getType());
+        if (CollectionUtils.isNotEmpty(existList)) {
+            InlongClusterEntity currentCluster = clusterMapper.selectById(existList.get(0).getParentId());
+            InlongClusterEntity targetCluster = clusterMapper.selectById(request.getParentId());
+            if (!Objects.equals(currentCluster.getId(), targetCluster.getId())) {
+                throw new BusinessException(
+                        String.format("current ip can not belong to cluster %s and %s at the same time",
+                                currentCluster.getName(), targetCluster.getName()));
+            }
+        }
         InlongClusterNodeOperator instance = clusterNodeOperatorFactory.getInstance(request.getType());
         Integer id = instance.saveOpt(request, operator);
         if (request.getIsInstall()) {
-            InlongClusterNodeInstallOperator clusterNodeInstallOperator = clusterNodeInstallOperatorFactory.getInstance(
-                    request.getType());
-            clusterNodeInstallOperator.install(request, operator);
+            request.setId(id);
+            clusterNodeMapper.updateOperateLogById(id, NodeStatus.INSTALLING.getStatus(), "begin to install");
+            pendingInstallRequests.add(request);
         }
         return id;
     }
@@ -809,7 +860,6 @@ public class InlongClusterServiceImpl implements InlongClusterService {
     }
 
     @Override
-    @Transactional(rollbackFor = Throwable.class, isolation = Isolation.REPEATABLE_READ)
     public Boolean updateNode(ClusterNodeRequest request, String operator) {
         LOGGER.debug("begin to update inlong cluster node={}", request);
         Preconditions.expectNotNull(request, "inlong cluster node cannot be empty");
@@ -842,9 +892,11 @@ public class InlongClusterServiceImpl implements InlongClusterService {
         InlongClusterNodeOperator instance = clusterNodeOperatorFactory.getInstance(request.getType());
         instance.updateOpt(request, operator);
         if (request.getIsInstall()) {
-            InlongClusterNodeInstallOperator clusterNodeInstallOperator = clusterNodeInstallOperatorFactory.getInstance(
-                    request.getType());
-            clusterNodeInstallOperator.install(request, operator);
+            // when reinstall set install to false
+            request.setIsInstall(false);
+            clusterNodeMapper.updateOperateLogById(request.getId(), NodeStatus.INSTALLING.getStatus(),
+                    "begin to re install");
+            pendingInstallRequests.add(request);
         }
         return true;
     }
@@ -908,7 +960,12 @@ public class InlongClusterServiceImpl implements InlongClusterService {
     public DataProxyNodeResponse getDataProxyNodes(String groupId, String protocolType) {
         LOGGER.debug("begin to get data proxy nodes for groupId={}, protocol={}", groupId, protocolType);
 
-        InlongGroupEntity groupEntity = groupMapper.selectByGroupId(groupId);
+        InlongGroupEntity groupEntity = groupMapper.selectByGroupIdWithoutTenant(groupId);
+        if (groupEntity == null) {
+            String errMsg = String.format("group not found by groupId=%s", groupId);
+            LOGGER.error(errMsg);
+            throw new BusinessException(errMsg);
+        }
         GroupStatus groupStatus = GroupStatus.forCode(groupEntity.getStatus());
         if (!Objects.equals(groupStatus, GroupStatus.CONFIG_SUCCESSFUL)) {
             String errMsg =
@@ -924,7 +981,15 @@ public class InlongClusterServiceImpl implements InlongClusterService {
         }
 
         // all cluster nodes belong to the same clusterId
-        response.setClusterId(nodeEntities.get(0).getParentId());
+        Integer clusterId = nodeEntities.get(0).getParentId();
+        Integer maxPacketLength = null;
+        response.setClusterId(clusterId);
+        InlongClusterEntity dataProxyCluster = clusterMapper.selectById(clusterId);
+        if (dataProxyCluster != null && StringUtils.isNotBlank(dataProxyCluster.getExtParams())) {
+            DataProxyClusterDTO dataProxyClusterDTO = DataProxyClusterDTO.getFromJson(dataProxyCluster.getExtParams());
+            maxPacketLength = dataProxyClusterDTO.getMaxPacketLength();
+            response.setMaxPacketLength(maxPacketLength);
+        }
 
         // TODO consider the data proxy load and re-balance
         List<DataProxyNodeInfo> nodeList = new ArrayList<>();
@@ -963,6 +1028,12 @@ public class InlongClusterServiceImpl implements InlongClusterService {
             LOGGER.debug("not any dataproxy cluster for clusterName={}, protocol={}", clusterName, protocolType);
             return response;
         }
+        Integer maxPacketLength = null;
+        if (StringUtils.isNotBlank(clusterEntity.getExtParams())) {
+            DataProxyClusterDTO dataProxyClusterDTO = DataProxyClusterDTO.getFromJson(clusterEntity.getExtParams());
+            maxPacketLength = dataProxyClusterDTO.getMaxPacketLength();
+            response.setMaxPacketLength(maxPacketLength);
+        }
         List<InlongClusterNodeEntity> nodeEntities =
                 clusterNodeMapper.selectByParentId(clusterEntity.getId(), protocolType);
         if (CollectionUtils.isEmpty(nodeEntities)) {
@@ -1011,7 +1082,7 @@ public class InlongClusterServiceImpl implements InlongClusterService {
     }
 
     private List<InlongClusterNodeEntity> getClusterNodes(String groupId, String clusterType, String protocolType) {
-        InlongGroupEntity groupEntity = groupMapper.selectByGroupId(groupId);
+        InlongGroupEntity groupEntity = groupMapper.selectByGroupIdWithoutTenant(groupId);
         if (groupEntity == null) {
             LOGGER.warn("inlong group not exists for groupId={}", groupId);
             return Lists.newArrayList();
@@ -1375,4 +1446,38 @@ public class InlongClusterServiceImpl implements InlongClusterService {
             request.setClusterTags(entity.getClusterTags());
         }
     }
+
+    private class InstallTaskRunnable implements Runnable {
+
+        private ClusterNodeRequest request;
+
+        public InstallTaskRunnable(ClusterNodeRequest request) {
+            this.request = request;
+        }
+
+        @Override
+        public void run() {
+            if (request == null) {
+                return;
+            }
+            InlongClusterNodeInstallOperator clusterNodeInstallOperator =
+                    clusterNodeInstallOperatorFactory.getInstance(request.getType());
+            if (request.getIsInstall()) {
+                clusterNodeInstallOperator.install(request, request.getCurrentUser());
+            } else {
+                clusterNodeInstallOperator.reInstall(request, request.getCurrentUser());
+            }
+        }
+    }
+
+    @Transactional(rollbackFor = Throwable.class)
+    public void processInstall() {
+        LOGGER.info("begin to process install task");
+        while (!pendingInstallRequests.isEmpty()) {
+            ClusterNodeRequest request = pendingInstallRequests.poll();
+            InstallTaskRunnable installTaskRunnable = new InstallTaskRunnable(request);
+            executorService.execute(installTaskRunnable);
+        }
+        LOGGER.info("success to process install task");
+    }
 }
