@@ -27,6 +27,7 @@ import org.apache.inlong.manager.pojo.cluster.ClusterInfo;
 import org.apache.inlong.manager.pojo.cluster.ClusterRequest;
 import org.apache.inlong.manager.pojo.cluster.sort.cls.SortClsClusterInfo;
 import org.apache.inlong.manager.pojo.cluster.sort.es.SortEsClusterInfo;
+import org.apache.inlong.manager.pojo.cluster.sort.http.SortHttpClusterInfo;
 import org.apache.inlong.manager.pojo.cluster.sort.kafka.SortKafkaClusterInfo;
 import org.apache.inlong.manager.pojo.cluster.sort.pulsar.SortPulsarClusterInfo;
 import org.apache.inlong.manager.pojo.sort.BaseSortClusterDTO;
@@ -50,6 +51,7 @@ public class SortClusterOperator extends AbstractClusterOperator {
     private static final Set<String> SORT_CLUSTER_SET = new HashSet<String>() {
 
         {
+            add(ClusterType.SORT_HTTP);
             add(ClusterType.SORT_CLS);
             add(ClusterType.SORT_PULSAR);
             add(ClusterType.SORT_ES);
@@ -84,6 +86,9 @@ public class SortClusterOperator extends AbstractClusterOperator {
 
         ClusterInfo sortClusterInfo;
         switch (entity.getType()) {
+            case ClusterType.SORT_HTTP:
+                sortClusterInfo = new SortHttpClusterInfo();
+                break;
             case ClusterType.SORT_CLS:
                 sortClusterInfo = new SortClsClusterInfo();
                 break;
