@@ -17,19 +17,22 @@
 
 package org.apache.inlong.manager.service.group;
 
-import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.common.constant.MQType;
+import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
+import org.apache.inlong.manager.common.util.CommonBeanUtils;
+import org.apache.inlong.manager.dao.entity.InlongGroupEntity;
 import org.apache.inlong.manager.pojo.group.InlongGroupInfo;
 import org.apache.inlong.manager.pojo.group.InlongGroupRequest;
 import org.apache.inlong.manager.pojo.group.InlongGroupTopicInfo;
 import org.apache.inlong.manager.pojo.group.none.InlongNoneMqInfo;
-import org.apache.inlong.manager.common.util.CommonBeanUtils;
-import org.apache.inlong.manager.dao.entity.InlongGroupEntity;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.stereotype.Service;
 
+import java.util.Map;
+
 /**
  * Inlong group operator without MQ.
  */
@@ -70,4 +73,10 @@ public class InlongGroupOperator4NoneMQ extends AbstractGroupOperator {
         return null;
     }
 
+    @Override
+    public Map<String, String> getMqInfo(InlongGroupInfo groupInfo) {
+        LOGGER.info("return null for inlong group without MQ");
+        return null;
+    }
+
 }
