@@ -352,9 +352,9 @@ public class InlongGroupServiceImpl implements InlongGroupService {
     }
 
     @Override
-    public InlongGroupCountResponse countGroupByUser(String operator, Integer inlongGroupMode) {
+    public InlongGroupCountResponse countGroupByUser(String operator, Integer inlongGroupMode, String mqType) {
         InlongGroupCountResponse countVO = new InlongGroupCountResponse();
-        List<Map<String, Object>> statusCount = groupMapper.countGroupByUser(operator, inlongGroupMode);
+        List<Map<String, Object>> statusCount = groupMapper.countGroupByUser(operator, inlongGroupMode, mqType);
         for (Map<String, Object> map : statusCount) {
             int status = (Integer) map.get("status");
             long count = (Long) map.get("count");
@@ -648,9 +648,11 @@ public class InlongGroupServiceImpl implements InlongGroupService {
                     String.format("current group status=%s was not allowed to delete", curState));
         }
 
-        // If the status not allowed deleting directly, you need to delete the related "inlong_stream" first,
+        // If the status does not allow deleting directly, and the group mode is STANDARD,
+        // you need to delete the related "inlong_stream" first.
         // otherwise, all associated info will be logically deleted.
-        if (GroupStatus.deleteStreamFirst(curState)) {
+        if (GroupStatus.deleteStreamFirst(curState)
+                && InlongConstants.STANDARD_MODE.equals(groupInfo.getInlongGroupMode())) {
             int count = streamService.selectCountByGroupId(groupId);
             if (count >= 1) {
                 throw new BusinessException(ErrorCodeEnum.GROUP_DELETE_HAS_STREAM,
