@@ -17,6 +17,7 @@
 
 package org.apache.inlong.manager.service.node;
 
+import org.apache.inlong.common.pojo.sort.node.NodeConfig;
 import org.apache.inlong.manager.common.consts.InlongConstants;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.enums.SourceStatus;
@@ -137,4 +138,9 @@ public abstract class AbstractDataNodeOperator implements DataNodeOperator {
                     dataNodeName, status, operator, e);
         }
     }
+
+    @Override
+    public NodeConfig getNodeConfig(DataNodeEntity dataNodeEntity) {
+        return null;
+    }
 }
