@@ -17,6 +17,8 @@
 
 package org.apache.inlong.manager.service.node.cls;
 
+import org.apache.inlong.common.pojo.sort.node.ClsNodeConfig;
+import org.apache.inlong.common.pojo.sort.node.NodeConfig;
 import org.apache.inlong.manager.common.consts.DataNodeType;
 import org.apache.inlong.manager.common.enums.ErrorCodeEnum;
 import org.apache.inlong.manager.common.exceptions.BusinessException;
@@ -107,4 +109,14 @@ public class ClsDataNodeOperator extends AbstractDataNodeOperator {
         }
         return true;
     }
+
+    @Override
+    public NodeConfig getNodeConfig(DataNodeEntity dataNodeEntity) {
+        DataNodeInfo dataNodeInfo = this.getFromEntity(dataNodeEntity);
+        ClsNodeConfig clsNodeConfig = CommonBeanUtils.copyProperties(dataNodeInfo, ClsNodeConfig::new);
+        ClsDataNodeDTO dto = ClsDataNodeDTO.getFromJson(dataNodeEntity.getExtParams());
+        CommonBeanUtils.copyProperties(dto, clsNodeConfig);
+        clsNodeConfig.setNodeName(dataNodeInfo.getName());
+        return clsNodeConfig;
+    }
 }
