@@ -17,6 +17,7 @@
 
 package org.apache.inlong.manager.service.operationlog;
 
+import org.apache.inlong.manager.common.enums.OperationTarget;
 import org.apache.inlong.manager.common.enums.OperationType;
 
 import java.lang.annotation.ElementType;
@@ -36,6 +37,11 @@ public @interface OperationLog {
      */
     OperationType operation();
 
+    /**
+     * Operation target
+     */
+    OperationTarget operationTarget();
+
     /**
      * Whether to store in the database
      */
