@@ -17,12 +17,11 @@
 
 package org.apache.inlong.manager.service.resource.sort;
 
-import org.apache.inlong.manager.common.exceptions.BusinessException;
-
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 
 import java.util.List;
+import java.util.stream.Collectors;
 
 /**
  * Factory for {@link SortConfigOperator}.
@@ -36,14 +35,10 @@ public class SortConfigOperatorFactory {
     /**
      * Get a Sort config operator instance.
      *
-     * @param enableZk is the inlong group enable the ZooKeeper, 1: enable, 0: disable
+     * @param sinkTypeList sink type
      */
-    public SortConfigOperator getInstance(Integer enableZk) {
-        return operatorList.stream()
-                .filter(inst -> inst.accept(enableZk))
-                .findFirst()
-                .orElseThrow(() -> new BusinessException("not found any instance of SortConfigOperator when enableZk="
-                        + enableZk));
+    public List<SortConfigOperator> getInstance(List<String> sinkTypeList) {
+        return operatorList.stream().filter(inst -> inst.accept(sinkTypeList)).collect(Collectors.toList());
     }
 
 }
