@@ -17,6 +17,8 @@
 
 package org.apache.inlong.manager.service.source;
 
+import org.apache.inlong.common.pojo.agent.DataConfig;
+import org.apache.inlong.manager.dao.entity.InlongStreamEntity;
 import org.apache.inlong.manager.dao.entity.StreamSourceEntity;
 import org.apache.inlong.manager.pojo.common.PageResult;
 import org.apache.inlong.manager.pojo.group.InlongGroupInfo;
@@ -144,4 +146,8 @@ public interface StreamSourceOperator {
      */
     void updateAgentTaskConfig(SourceRequest request, String operator);
 
+    default String updateDataConfig(String extParams, InlongStreamEntity streamEntity, DataConfig dataConfig) {
+        return extParams;
+    }
+
 }
