@@ -211,15 +211,6 @@ public interface StreamSourceService {
      * @param operator Operator's name.
      * @return source id after saving.
      */
-    Integer addDataAddTask(DataAddTaskRequest request, String operator);
+    List<Integer> addDataAddTask(DataAddTaskRequest request, String operator);
 
-    /**
-     * Batch Save the data add task information
-     *
-     * @param requestList Source request list.
-     * @param operator Operator's name.
-     * @return source id list after saving.
-     */
-    List<Integer> batchAddDataAddTask(String groupId, String streamId, List<DataAddTaskRequest> requestList,
-            String operator);
 }
