@@ -17,15 +17,14 @@
 
 package org.apache.inlong.manager.service.user;
 
+import org.apache.inlong.manager.pojo.common.PageResult;
 import org.apache.inlong.manager.pojo.user.InlongRoleInfo;
 import org.apache.inlong.manager.pojo.user.InlongRolePageRequest;
 import org.apache.inlong.manager.pojo.user.InlongRoleRequest;
 
-import com.github.pagehelper.PageInfo;
-
 public interface InlongRoleService {
 
-    PageInfo<InlongRoleInfo> listByCondition(InlongRolePageRequest request);
+    PageResult<InlongRoleInfo> listByCondition(InlongRolePageRequest request);
 
     int save(InlongRoleRequest request, String operator);
 
