@@ -17,20 +17,31 @@
 
 package org.apache.inlong.manager.web.controller.openapi;
 
+import org.apache.inlong.audit.entity.AuditProxy;
 import org.apache.inlong.common.pojo.audit.AuditConfig;
 import org.apache.inlong.common.pojo.audit.AuditConfigRequest;
+import org.apache.inlong.manager.pojo.audit.AuditRequest;
+import org.apache.inlong.manager.pojo.audit.AuditVO;
 import org.apache.inlong.manager.pojo.common.Response;
 import org.apache.inlong.manager.service.cluster.InlongClusterService;
+import org.apache.inlong.manager.service.core.AuditService;
 
 import io.swagger.annotations.Api;
+import io.swagger.annotations.ApiImplicitParam;
 import io.swagger.annotations.ApiOperation;
 import org.apache.commons.collections.CollectionUtils;
 import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.bind.annotation.PostMapping;
 import org.springframework.web.bind.annotation.RequestBody;
 import org.springframework.web.bind.annotation.RequestMapping;
+import org.springframework.web.bind.annotation.RequestParam;
 import org.springframework.web.bind.annotation.RestController;
 
+import javax.validation.Valid;
+
+import java.util.List;
+
 /**
  * Audit controller.
  */
@@ -41,6 +52,8 @@ public class AuditController {
 
     @Autowired
     private InlongClusterService clusterService;
+    @Autowired
+    private AuditService auditService;
 
     @PostMapping("/audit/getConfig")
     @ApiOperation(value = "Get mq config list")
@@ -51,4 +64,23 @@ public class AuditController {
         }
         return Response.success(auditConfig);
     }
+
+    @PostMapping(value = "/audit/list")
+    @ApiOperation(value = "Query audit list according to conditions")
+    public Response<List<AuditVO>> listByCondition(@Valid @RequestBody AuditRequest request) throws Exception {
+        return Response.success(auditService.listByCondition(request));
+    }
+
+    @PostMapping(value = "/audit/listAll")
+    @ApiOperation(value = "Query all audit list according to conditions")
+    public Response<List<AuditVO>> listAll(@Valid @RequestBody AuditRequest request) throws Exception {
+        return Response.success(auditService.listAll(request));
+    }
+
+    @GetMapping(value = "/audit/getAuditProxy")
+    @ApiOperation(value = "Get audit proxy url")
+    @ApiImplicitParam(name = "component", dataTypeClass = String.class, required = true)
+    public Response<List<AuditProxy>> getAuditProxy(@RequestParam String component) throws Exception {
+        return Response.success(auditService.getAuditProxy(component));
+    }
 }
