@@ -1,3 +1,4 @@
+#!/bin/bash
 #
 # Licensed to the Apache Software Foundation (ASF) under one or more
 # contributor license agreements.  See the NOTICE file distributed with
@@ -16,12 +17,26 @@
 # Initialize the configuration files of inlong components
 #
 
-#!/bin/bash
-
 set -e
 
-BASE_DIR=`dirname "$0"`
-PY_SDK_DIR=`cd "$BASE_DIR";pwd`
+# Parse command line arguments
+TARGET_DIR=""
+if [ $# -eq 1 ]; then
+    TARGET_DIR="$1"
+    echo "Using user-specified target directory: $TARGET_DIR"
+    # Check if the target directory exists early to avoid wasting compilation time
+    if [ ! -d "$TARGET_DIR" ]; then
+        echo "Error: Target directory '$TARGET_DIR' does not exist!"
+        exit 1
+    fi
+elif [ $# -gt 1 ]; then
+    echo "Usage: $0 [target_directory]"
+    echo "  target_directory: Optional. Directory to install .so files. If not provided, will use system site-packages directories."
+    exit 1
+fi
+
+BASE_DIR=$(dirname "$0")
+PY_SDK_DIR=$(cd "$BASE_DIR"; pwd)
 
 echo "The python sdk directory is: $PY_SDK_DIR"
 
@@ -31,7 +46,7 @@ if [ ! -d "$PY_SDK_DIR/../dataproxy-sdk-cpp" ]; then
     exit 1
 fi
 
-CPP_SDK_DIR=`cd "$PY_SDK_DIR/../dataproxy-sdk-cpp";pwd`
+CPP_SDK_DIR=$(cd "$PY_SDK_DIR/../dataproxy-sdk-cpp"; pwd)
 
 echo "The cpp sdk directory is: $CPP_SDK_DIR"
 
@@ -52,9 +67,9 @@ if [ "$(printf '%s\n' "$PYTHON_REQUIRED" "$PYTHON_VERSION" | sort -V | head -n1)
 fi
 
 # Install Python packages from requirements.txt
-if [ -f $PY_SDK_DIR/requirements.txt ]; then
+if [ -f "$PY_SDK_DIR/requirements.txt" ]; then
     echo "Installing Python packages from requirements.txt..."
-    pip install -r $PY_SDK_DIR/requirements.txt
+    pip install -r "$PY_SDK_DIR/requirements.txt"
 else
     echo "Error: cannot find requirements.txt!"
     exit 1
@@ -63,17 +78,18 @@ fi
 # Build pybind11(If the pybind11 has been compiled, this step will be skipped)
 if [ ! -d "$PY_SDK_DIR/pybind11/build" ]; then
     if [ -d "$PY_SDK_DIR/pybind11" ]; then
-        rm -r $PY_SDK_DIR/pybind11
+        rm -r "$PY_SDK_DIR/pybind11"
     fi
-    git clone https://github.com/pybind/pybind11.git $PY_SDK_DIR/pybind11
-    mkdir $PY_SDK_DIR/pybind11/build && cd $PY_SDK_DIR/pybind11/build
+    PYBIND11_VERSION="v2.13.0"
+    git clone --branch $PYBIND11_VERSION --depth 1 https://github.com/pybind/pybind11.git "$PY_SDK_DIR/pybind11"
+    mkdir "$PY_SDK_DIR/pybind11/build" && cd "$PY_SDK_DIR/pybind11/build"
 
     # Add a trap command to delete the pybind11 folder if an error occurs
     trap 'echo "Error occurred during pybind11 build. Deleting pybind11 folder..."; cd $PY_SDK_DIR; rm -r pybind11; exit 1' ERR
 
-    cmake $PY_SDK_DIR/pybind11
-    cmake --build $PY_SDK_DIR/pybind11/build --config Release --target check
-    make -j 4
+    cmake "$PY_SDK_DIR/pybind11"
+    cmake --build "$PY_SDK_DIR/pybind11/build" --config Release
+    make -j"$(nproc)"
 
     # Remove the trap command if the build is successful
     trap - ERR
@@ -92,36 +108,46 @@ if [ ! -e "$CPP_SDK_DIR/release/lib/dataproxy_sdk.a" ]; then
     exit 1
 else
     if [ -d "$PY_SDK_DIR/dataproxy-sdk-cpp" ]; then
-        rm -r $PY_SDK_DIR/dataproxy-sdk-cpp
+        rm -r "$PY_SDK_DIR/dataproxy-sdk-cpp"
     fi
-    cp -r $CPP_SDK_DIR $PY_SDK_DIR
+    cp -r "$CPP_SDK_DIR" "$PY_SDK_DIR"
     echo "Copied the dataproxy-sdk-cpp directory to the current directory"
 fi
 
 # Build Python SDK
 if [ -d "$PY_SDK_DIR/build" ]; then
-    rm -r $PY_SDK_DIR/build
+    rm -r "$PY_SDK_DIR/build"
 fi
-mkdir $PY_SDK_DIR/build && cd $PY_SDK_DIR/build
-cmake $PY_SDK_DIR
-make -j 4
+mkdir "$PY_SDK_DIR/build" && cd "$PY_SDK_DIR/build"
+cmake "$PY_SDK_DIR"
+make -j"$(nproc)"
 
-# Get Python site-packages directory
-SITE_PACKAGES_DIR=$(python -c "import site; print(site.getsitepackages()[0])")
-
-# Prompt user for target directory
-echo "Your system's Python site-packages directory is: $SITE_PACKAGES_DIR"
-read -p "Enter the target directory for the .so files (Press Enter to use the default site-packages directory): " target_dir
-
-# Use default site-packages directory if user input is empty
-if [ -z "$target_dir" ]; then
-    target_dir=$SITE_PACKAGES_DIR
+# Handle installation based on command line arguments
+if [ -n "$TARGET_DIR" ]; then
+    # User specified a target directory via command line argument
+    echo "Copying .so files to user-specified directory: $TARGET_DIR"
+    find "$PY_SDK_DIR/build" -name "*.so" -print0 | xargs -0 -I {} cp {} "$TARGET_DIR"
+else
+    # No command line argument provided, use system site-packages directories
+    # Get all existing Python site-packages directories
+    SITE_PACKAGES_DIRS=($(python -c "import site,os; print(' '.join([p for p in site.getsitepackages() if os.path.isdir(p)]))"))
+    if [ ${#SITE_PACKAGES_DIRS[@]} -ne 0 ]; then
+        echo "No target directory specified, using system site-packages directories:"
+        for dir in "${SITE_PACKAGES_DIRS[@]}"; do
+            echo "  $dir"
+        done
+        for dir in "${SITE_PACKAGES_DIRS[@]}"; do
+            echo "Copying .so files to $dir"
+            # Find all .so files in $PY_SDK_DIR/build and copy them to the current site-packages directory
+            find "$PY_SDK_DIR/build" -name "*.so" -print0 | xargs -0 -I {} cp {} "$dir"
+        done
+    else
+        echo "Error: No system site-packages directories found and no target directory specified!"
+        echo "The .so file is located in $PY_SDK_DIR/build, you can copy it manually to your project"
+    fi
 fi
 
-# Copy the generated .so file to target directory
-find $PY_SDK_DIR/build -name "*.so" -print0 | xargs -0 -I {} bash -c 'rm -f $0/$1; cp $1 $0' $target_dir {}
-
-# Clean
-rm -r $PY_SDK_DIR/dataproxy-sdk-cpp
+# Clean the cpp dataproxy directory
+rm -r "$PY_SDK_DIR/dataproxy-sdk-cpp"
 
 echo "Build Python SDK successfully"
\ No newline at end of file
