@@ -24,16 +24,11 @@ public class SequentialID {
 
     private static final SecureRandom sRandom = new SecureRandom(
             Long.toString(System.nanoTime()).getBytes());
-    private final String ip = IpUtils.getLocalIp();
     private final AtomicInteger id = new AtomicInteger(sRandom.nextInt());
 
     public SequentialID() {
     }
 
-    public String getNextId() {
-        return ip + "#" + id.incrementAndGet() + "#" + System.currentTimeMillis();
-    }
-
     public int getNextInt() {
         return id.incrementAndGet();
     }
