@@ -23,8 +23,10 @@ package org.apache.inlong.sdk.commons.protocol;
  */
 public interface EventConstants {
 
+    @Deprecated // replace by ConfigConstants.MSG_ENCODE_VER
     String HEADER_KEY_VERSION = "version";
     String HEADER_SDK_VERSION_1 = "1";
+    @Deprecated // replace by DataProxyMsgEncType.MSG_ENCODE_VER_PB
     String HEADER_CACHE_VERSION_1 = "1";
     // sdk
     String INLONG_GROUP_ID = "inlongGroupId";
