@@ -17,6 +17,8 @@
 
 package org.apache.inlong.sdk.transform.decode;
 
+import org.apache.inlong.sdk.transform.process.Context;
+
 import com.google.gson.JsonArray;
 import com.google.gson.JsonObject;
 
@@ -25,7 +27,7 @@ import com.google.gson.JsonObject;
  */
 public class BsonSourceData extends JsonSourceData {
 
-    public BsonSourceData(JsonObject root, JsonArray childRoot) {
-        super(root, childRoot);
+    public BsonSourceData(JsonObject root, JsonArray childRoot, Context context) {
+        super(root, childRoot, context);
     }
 }
