@@ -19,6 +19,10 @@ package org.apache.inlong.sdk.transform.encode;
 
 import org.apache.inlong.sdk.transform.pojo.CsvSinkInfo;
 import org.apache.inlong.sdk.transform.pojo.KvSinkInfo;
+import org.apache.inlong.sdk.transform.pojo.MapSinkInfo;
+import org.apache.inlong.sdk.transform.pojo.ParquetSinkInfo;
+import org.apache.inlong.sdk.transform.pojo.PbSinkInfo;
+import org.apache.inlong.sdk.transform.pojo.RowDataSinkInfo;
 
 public class SinkEncoderFactory {
 
@@ -29,4 +33,21 @@ public class SinkEncoderFactory {
     public static KvSinkEncoder createKvEncoder(KvSinkInfo kvSinkInfo) {
         return new KvSinkEncoder(kvSinkInfo);
     }
+
+    public static MapSinkEncoder createMapEncoder(MapSinkInfo mapSinkInfo) {
+        return new MapSinkEncoder(mapSinkInfo);
+    }
+
+    public static ParquetSinkEncoder createParquetEncoder(ParquetSinkInfo parquetSinkInfo) {
+        return new ParquetSinkEncoder(parquetSinkInfo);
+    }
+
+    public static PbSinkEncoder createPbEncoder(PbSinkInfo pbSinkInfo) {
+        return new PbSinkEncoder(pbSinkInfo);
+    }
+
+    public static RowDataSinkEncoder createRowEncoder(RowDataSinkInfo rowDataSinkInfo) {
+        return new RowDataSinkEncoder(rowDataSinkInfo);
+    }
+
 }
