@@ -27,7 +27,8 @@ import java.util.List;
 
 public interface IEvent2HttpRequestHandler {
 
-    HttpRequest parse(HttpSinkContext context, ProfileEvent event) throws URISyntaxException, JsonProcessingException;
+    List<HttpRequest> parse(HttpSinkContext context, ProfileEvent event)
+            throws URISyntaxException, JsonProcessingException;
 
     List<HttpRequest> parse(HttpSinkContext context, DispatchProfile dispatchProfile)
             throws URISyntaxException, JsonProcessingException;
