@@ -17,12 +17,13 @@
 
 package org.apache.inlong.sort.standalone.sink.pulsar;
 
+import org.apache.inlong.common.pojo.sort.node.PulsarNodeConfig;
 import org.apache.inlong.sort.standalone.channel.ProfileEvent;
+import org.apache.inlong.sort.standalone.config.holder.CommonPropertiesHolder;
 import org.apache.inlong.sort.standalone.config.pojo.CacheClusterConfig;
 import org.apache.inlong.sort.standalone.utils.Constants;
 import org.apache.inlong.sort.standalone.utils.InlongLoggerFactory;
 
-import org.apache.commons.lang.math.NumberUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.flume.Context;
 import org.apache.flume.Transaction;
@@ -41,6 +42,7 @@ import org.apache.pulsar.client.api.PulsarClientException;
 import org.slf4j.Logger;
 
 import java.io.IOException;
+import java.util.HashMap;
 import java.util.Map;
 import java.util.Map.Entry;
 import java.util.concurrent.CompletableFuture;
@@ -73,35 +75,33 @@ public class PulsarProducerCluster implements LifecycleAware {
             + "BatchingPartitionSwitchFrequency";
 
     private final String workerName;
-    private final CacheClusterConfig config;
     private final PulsarFederationSinkContext sinkContext;
-    private final Context context;
-    private final String cacheClusterName;
+    private final PulsarNodeConfig nodeConfig;
+    private final CacheClusterConfig cacheClusterConfig;
+    private String cacheClusterName;
+    private Context context;
     private LifecycleState state;
     private IEvent2PulsarRecordHandler handler;
 
     /**
      * pulsar client
      */
+    private ClientBuilder clientBuilder;
     private PulsarClient client;
     private ProducerBuilder<byte[]> baseBuilder;
 
     private Map<String, Producer<byte[]>> producerMap = new ConcurrentHashMap<>();
 
-    /**
-     * Constructor
-     *
-     * @param workerName
-     * @param config
-     * @param context
-     */
-    public PulsarProducerCluster(String workerName, CacheClusterConfig config, PulsarFederationSinkContext context) {
+    public PulsarProducerCluster(
+            String workerName,
+            CacheClusterConfig cacheClusterConfig,
+            PulsarNodeConfig nodeConfig,
+            PulsarFederationSinkContext context) {
         this.workerName = workerName;
-        this.config = config;
         this.sinkContext = context;
-        this.context = context.getProducerContext();
+        this.nodeConfig = nodeConfig;
+        this.cacheClusterConfig = cacheClusterConfig;
         this.state = LifecycleState.IDLE;
-        this.cacheClusterName = config.getClusterName();
         this.handler = sinkContext.createEventHandler();
     }
 
@@ -113,21 +113,14 @@ public class PulsarProducerCluster implements LifecycleAware {
         this.state = LifecycleState.START;
         try {
             // create pulsar client
-            ClientBuilder clientBuilder = PulsarClient.builder();
-            String serviceUrl = config.getParams().get(KEY_SERVICE_URL);
-            if (StringUtils.isBlank(serviceUrl)) {
-                throw new IllegalArgumentException("service url should not be null");
-            }
-
-            clientBuilder.serviceUrl(serviceUrl);
-            String authentication = config.getParams().get(KEY_AUTHENTICATION);
-            if (StringUtils.isNoneBlank(authentication)) {
-                clientBuilder.authentication(AuthenticationFactory.token(authentication));
+            if (CommonPropertiesHolder.useUnifiedConfiguration()) {
+                initBuilderByNodeConfig(nodeConfig);
+            } else {
+                initBuilderByCacheCluster(cacheClusterConfig);
             }
 
             this.client = clientBuilder
-                    .statsInterval(NumberUtils.toLong(config.getParams().get(KEY_STATS_INTERVAL_SECONDS), -1),
-                            TimeUnit.SECONDS)
+                    .statsInterval(context.getLong(KEY_STATS_INTERVAL_SECONDS, -1L), TimeUnit.SECONDS)
                     .build();
 
             // create producer template
@@ -143,7 +136,7 @@ public class PulsarProducerCluster implements LifecycleAware {
                     .maxPendingMessagesAcrossPartitions(
                             context.getInteger(KEY_MAXPENDINGMESSAGESACROSSPARTITIONS, 50000))
                     .sendTimeout(context.getInteger(KEY_SENDTIMEOUT, 0), TimeUnit.MILLISECONDS)
-                    .compressionType(this.getPulsarCompressionType())
+                    .compressionType(this.getPulsarCompressionType(context.getString(KEY_COMPRESSIONTYPE, "ZLIB")))
                     .blockIfQueueFull(context.getBoolean(KEY_BLOCKIFQUEUEFULL, true))
                     .roundRobinRouterBatchingPartitionSwitchFrequency(
                             context.getInteger(KEY_ROUNDROBINROUTERBATCHINGPARTITIONSWITCHFREQUENCY, 10))
@@ -153,14 +146,50 @@ public class PulsarProducerCluster implements LifecycleAware {
         }
     }
 
+    private void initBuilderByCacheCluster(CacheClusterConfig cacheClusterConfig) {
+        this.cacheClusterName = cacheClusterConfig.getClusterName();
+        this.context = new Context(cacheClusterConfig.getParams());
+        clientBuilder = PulsarClient.builder();
+        String serviceUrl = cacheClusterConfig.getParams().get(KEY_SERVICE_URL);
+        if (StringUtils.isBlank(serviceUrl)) {
+            throw new IllegalArgumentException("service url should not be null");
+        }
+
+        clientBuilder.serviceUrl(serviceUrl);
+        String authentication = cacheClusterConfig.getParams().get(KEY_AUTHENTICATION);
+        if (StringUtils.isNoneBlank(authentication)) {
+            clientBuilder.authentication(AuthenticationFactory.token(authentication));
+        }
+    }
+
+    private void initBuilderByNodeConfig(PulsarNodeConfig nodeConfig) {
+        this.cacheClusterName = nodeConfig.getNodeName();
+        this.context = new Context(nodeConfig.getProperties() == null ? new HashMap<>() : nodeConfig.getProperties());
+
+        clientBuilder = PulsarClient.builder();
+        String serviceUrl = nodeConfig.getServiceUrl();
+        if (StringUtils.isBlank(serviceUrl)) {
+            throw new IllegalArgumentException("service url should not be null");
+        }
+
+        clientBuilder.serviceUrl(serviceUrl);
+        String authentication = nodeConfig.getToken();
+        if (StringUtils.isNoneBlank(authentication)) {
+            clientBuilder.authentication(AuthenticationFactory.token(authentication));
+        }
+    }
+
     /**
      * getPulsarCompressionType
      *
      * @return CompressionType
      */
-    private CompressionType getPulsarCompressionType() {
-        String type = this.context.getString(KEY_COMPRESSIONTYPE, DEFAULT_COMPRESS_TYPE);
-        switch (type) {
+    private CompressionType getPulsarCompressionType(String type) {
+        if (type == null) {
+            return CompressionType.ZLIB;
+        }
+
+        switch (type.toUpperCase()) {
             case "LZ4":
                 return CompressionType.LZ4;
             case "NONE":
@@ -279,13 +308,4 @@ public class PulsarProducerCluster implements LifecycleAware {
         return true;
     }
 
-    /**
-     * get cacheClusterName
-     *
-     * @return the cacheClusterName
-     */
-    public String getCacheClusterName() {
-        return cacheClusterName;
-    }
-
 }
