@@ -26,6 +26,9 @@ import javax.annotation.Nullable;
 
 import java.util.Objects;
 
+import static org.apache.inlong.sort.protocol.constant.Constant.AUTO_APPEND_ESCAPE_CHAR_AFTER_DESERIALIZE_DEFAULT;
+import static org.apache.inlong.sort.protocol.constant.Constant.DELETE_ESCAPE_CHAR_WHILE_DESERIALIZE_DEFAULT;
+
 /**
  * Csv deserialization info
  */
@@ -41,27 +44,43 @@ public class CsvDeserializationInfo extends InLongMsgDeserializationInfo {
 
     private final String streamId;
 
+    @JsonProperty("delete_escape_char_while_deserialize")
+    @Nullable
+    private final Boolean deleteEscapeCharWhileDes;
+
+    @JsonProperty("auto_append_escape_char_after_deserialize")
+    @Nullable
+    private final Boolean autoAppendEscapeCharAfterDes;
+
     // TODO: support mapping index to field
     public CsvDeserializationInfo(
             @JsonProperty("splitter") char splitter) {
-        this(STREAM_ID_DEFAULT_VALUE, splitter, null);
+        this(STREAM_ID_DEFAULT_VALUE, splitter, null,
+                DELETE_ESCAPE_CHAR_WHILE_DESERIALIZE_DEFAULT,
+                AUTO_APPEND_ESCAPE_CHAR_AFTER_DESERIALIZE_DEFAULT);
     }
 
     public CsvDeserializationInfo(
             @JsonProperty("splitter") char splitter,
             @JsonProperty("escape_char") @Nullable Character escapeChar) {
-        this(STREAM_ID_DEFAULT_VALUE, splitter, escapeChar);
+        this(STREAM_ID_DEFAULT_VALUE, splitter, escapeChar,
+                DELETE_ESCAPE_CHAR_WHILE_DESERIALIZE_DEFAULT,
+                AUTO_APPEND_ESCAPE_CHAR_AFTER_DESERIALIZE_DEFAULT);
     }
 
     @JsonCreator
     public CsvDeserializationInfo(
             @JsonProperty("streamId") String streamId,
             @JsonProperty("splitter") char splitter,
-            @JsonProperty("escape_char") @Nullable Character escapeChar) {
+            @JsonProperty("escape_char") @Nullable Character escapeChar,
+            @JsonProperty("delete_escape_char_while_deserialize") @Nullable Boolean deleteEscapeCharWhileDes,
+            @JsonProperty("auto_append_escape_char_after_deserialize") @Nullable Boolean autoAppendEscapeCharAfterDes) {
         super(streamId);
         this.streamId = (StringUtils.isEmpty(streamId) ? STREAM_ID_DEFAULT_VALUE : streamId);
         this.splitter = splitter;
         this.escapeChar = escapeChar;
+        this.deleteEscapeCharWhileDes = deleteEscapeCharWhileDes;
+        this.autoAppendEscapeCharAfterDes = autoAppendEscapeCharAfterDes;
     }
 
     @JsonProperty("splitter")
@@ -80,6 +99,24 @@ public class CsvDeserializationInfo extends InLongMsgDeserializationInfo {
         return streamId;
     }
 
+    @JsonProperty("delete_escape_char_while_deserialize")
+    @Nullable
+    public Boolean getDeleteEscapeCharWhileDes() {
+        if (deleteEscapeCharWhileDes != null) {
+            return deleteEscapeCharWhileDes;
+        }
+        return DELETE_ESCAPE_CHAR_WHILE_DESERIALIZE_DEFAULT;
+    }
+
+    @JsonProperty("auto_append_escape_char_after_deserialize")
+    @Nullable
+    public Boolean getAutoAppendEscapeCharAfterDes() {
+        if (autoAppendEscapeCharAfterDes != null) {
+            return autoAppendEscapeCharAfterDes;
+        }
+        return AUTO_APPEND_ESCAPE_CHAR_AFTER_DESERIALIZE_DEFAULT;
+    }
+
     @Override
     public boolean equals(Object o) {
         if (this == o) {
@@ -92,7 +129,9 @@ public class CsvDeserializationInfo extends InLongMsgDeserializationInfo {
 
         CsvDeserializationInfo other = (CsvDeserializationInfo) o;
         return Objects.equals(streamId, other.getStreamId()) && splitter == other.splitter
-                && Objects.equals(escapeChar, other.escapeChar);
+                && Objects.equals(escapeChar, other.escapeChar)
+                && Objects.equals(deleteEscapeCharWhileDes, other.deleteEscapeCharWhileDes)
+                && Objects.equals(autoAppendEscapeCharAfterDes, other.autoAppendEscapeCharAfterDes);
     }
 
 }
