@@ -28,6 +28,9 @@ import javax.annotation.Nullable;
 
 import java.util.Objects;
 
+import static org.apache.inlong.sort.protocol.constant.Constant.AUTO_APPEND_ESCAPE_CHAR_AFTER_DESERIALIZE_DEFAULT;
+import static org.apache.inlong.sort.protocol.constant.Constant.DELETE_ESCAPE_CHAR_WHILE_DESERIALIZE_DEFAULT;
+
 /**
  * Kv deserialization info
  */
@@ -46,6 +49,14 @@ public class KvDeserializationInfo extends InLongMsgDeserializationInfo {
     @Nullable
     private final Character escapeChar;
 
+    @JsonProperty("delete_escape_char_while_deserialize")
+    @Nullable
+    private final Boolean deleteEscapeCharWhileDes;
+
+    @JsonProperty("auto_append_escape_char_after_deserialize")
+    @Nullable
+    private final Boolean autoAppendEscapeCharAfterDes;
+
     public KvDeserializationInfo(
             @JsonProperty("entry_splitter") char entrySplitter,
             @JsonProperty("kv_splitter") char kvSplitter) {
@@ -65,11 +76,26 @@ public class KvDeserializationInfo extends InLongMsgDeserializationInfo {
             @JsonProperty("entry_splitter") char entrySplitter,
             @JsonProperty("kv_splitter") char kvSplitter,
             @JsonProperty("escape_char") @Nullable Character escapeChar) {
+        this(streamId, entrySplitter, kvSplitter, escapeChar,
+                DELETE_ESCAPE_CHAR_WHILE_DESERIALIZE_DEFAULT,
+                AUTO_APPEND_ESCAPE_CHAR_AFTER_DESERIALIZE_DEFAULT);
+    }
+
+    @JsonCreator
+    public KvDeserializationInfo(
+            @JsonProperty("streamId") @JsonAlias(value = {"tid"}) String streamId,
+            @JsonProperty("entry_splitter") char entrySplitter,
+            @JsonProperty("kv_splitter") char kvSplitter,
+            @JsonProperty("escape_char") @Nullable Character escapeChar,
+            @JsonProperty("delete_escape_char_while_deserialize") @Nullable Boolean deleteEscapeCharWhileDes,
+            @JsonProperty("auto_append_escape_char_after_deserialize") @Nullable Boolean autoAppendEscapeCharAfterDes) {
         super(streamId);
         this.streamId = (StringUtils.isEmpty(streamId) ? STREAM_ID_DEFAULT_VALUE : streamId);
         this.entrySplitter = entrySplitter;
         this.kvSplitter = kvSplitter;
         this.escapeChar = escapeChar;
+        this.deleteEscapeCharWhileDes = deleteEscapeCharWhileDes;
+        this.autoAppendEscapeCharAfterDes = autoAppendEscapeCharAfterDes;
     }
 
     @JsonProperty("entry_splitter")
@@ -93,6 +119,24 @@ public class KvDeserializationInfo extends InLongMsgDeserializationInfo {
         return streamId;
     }
 
+    @JsonProperty("delete_escape_char_while_deserialize")
+    @Nullable
+    public Boolean getDeleteEscapeCharWhileDes() {
+        if (deleteEscapeCharWhileDes != null) {
+            return deleteEscapeCharWhileDes;
+        }
+        return DELETE_ESCAPE_CHAR_WHILE_DESERIALIZE_DEFAULT;
+    }
+
+    @JsonProperty("auto_append_escape_char_after_deserialize")
+    @Nullable
+    public Boolean getAutoAppendEscapeCharAfterDes() {
+        if (autoAppendEscapeCharAfterDes != null) {
+            return autoAppendEscapeCharAfterDes;
+        }
+        return AUTO_APPEND_ESCAPE_CHAR_AFTER_DESERIALIZE_DEFAULT;
+    }
+
     @Override
     public boolean equals(Object o) {
         if (this == o) {
@@ -106,6 +150,8 @@ public class KvDeserializationInfo extends InLongMsgDeserializationInfo {
         KvDeserializationInfo other = (KvDeserializationInfo) o;
         return Objects.equals(streamId, other.getStreamId()) && entrySplitter == other.entrySplitter
                 && kvSplitter == other.kvSplitter
-                && Objects.equals(escapeChar, other.escapeChar);
+                && Objects.equals(escapeChar, other.escapeChar)
+                && Objects.equals(deleteEscapeCharWhileDes, other.deleteEscapeCharWhileDes)
+                && Objects.equals(autoAppendEscapeCharAfterDes, other.autoAppendEscapeCharAfterDes);
     }
 }
