@@ -52,6 +52,7 @@ import org.slf4j.LoggerFactory;
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.List;
@@ -59,6 +60,7 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.StringJoiner;
+import java.util.stream.Collectors;
 
 /**
  * Schema change helper
@@ -143,7 +145,7 @@ public class SchemaChangeHelper {
             JsonNode operationNode = Preconditions.checkNotNull(data.get("operation"),
                     "Operation node is null");
             operation = Preconditions.checkNotNull(
-                    dynamicSchemaFormat.objectMapper.convertValue(operationNode, new TypeReference<Operation>() {
+                    JsonDynamicSchemaFormat.OBJECT_MAPPER.convertValue(operationNode, new TypeReference<Operation>() {
                     }), "Operation is null");
         } catch (Exception e) {
             if (exceptionPolicy == SchemaUpdateExceptionPolicy.THROW_WITH_STOP) {
@@ -415,12 +417,22 @@ public class SchemaChangeHelper {
     private boolean executeStatement(String database, String stmt) throws IOException {
         Map<String, String> param = new HashMap<>();
         param.put("stmt", stmt);
-        String requestUrl = String.format(SCHEMA_CHANGE_API, options.getFenodes(), database);
-        HttpPost httpPost = new HttpPost(requestUrl);
-        httpPost.setHeader(HttpHeaders.AUTHORIZATION, authHeader());
-        httpPost.setHeader(HttpHeaders.CONTENT_TYPE, CONTENT_TYPE_JSON);
-        httpPost.setEntity(new StringEntity(dynamicSchemaFormat.objectMapper.writeValueAsString(param)));
-        return sendRequest(httpPost);
+        List<String> fenodes = Arrays.asList(options.getFenodes().split(","));
+        List<String> uris = fenodes.stream()
+                .map(fenode -> String.format(SCHEMA_CHANGE_API, fenode, database))
+                .collect(Collectors.toList());
+
+        for (String requestUrl : uris) {
+            HttpPost httpPost = new HttpPost(requestUrl);
+            httpPost.setHeader(HttpHeaders.AUTHORIZATION, authHeader());
+            httpPost.setHeader(HttpHeaders.CONTENT_TYPE, CONTENT_TYPE_JSON);
+            httpPost.setEntity(new StringEntity(JsonDynamicSchemaFormat.OBJECT_MAPPER.writeValueAsString(param)));
+            // if any fenode succeeds, return true, else keep trying
+            if (sendRequest(httpPost)) {
+                return true;
+            }
+        }
+        return false;
     }
 
     private boolean checkLightSchemaChange(String database, String table, String column, boolean dropColumn)
@@ -429,7 +441,7 @@ public class SchemaChangeHelper {
         Map<String, Object> param = buildRequestParam(column, dropColumn);
         HttpGetEntity httpGet = new HttpGetEntity(url);
         httpGet.setHeader(HttpHeaders.AUTHORIZATION, authHeader());
-        httpGet.setEntity(new StringEntity(dynamicSchemaFormat.objectMapper.writeValueAsString(param)));
+        httpGet.setEntity(new StringEntity(JsonDynamicSchemaFormat.OBJECT_MAPPER.writeValueAsString(param)));
         boolean success = sendRequest(httpGet);
         if (!success) {
             LOGGER.warn("schema change can not do table {}.{}", database, table);
@@ -446,7 +458,7 @@ public class SchemaChangeHelper {
                     final int statusCode = response.getStatusLine().getStatusCode();
                     if (statusCode == HttpStatus.SC_OK && response.getEntity() != null) {
                         String loadResult = EntityUtils.toString(response.getEntity());
-                        Map<String, Object> responseMap = dynamicSchemaFormat.objectMapper
+                        Map<String, Object> responseMap = JsonDynamicSchemaFormat.OBJECT_MAPPER
                                 .readValue(loadResult, Map.class);
                         String code = responseMap.getOrDefault("code", "-1").toString();
                         if (DORIS_HTTP_CALL_SUCCESS.equals(code)) {
