@@ -17,21 +17,20 @@
 
 package org.apache.inlong.sort.elasticsearch.table;
 
-import org.apache.flink.annotation.Internal;
 import org.apache.flink.table.data.RowData;
 import org.apache.flink.types.Row;
 
 import java.io.Serializable;
 
 /** This interface is responsible to generate index name from given {@link Row} record. */
-@Internal
-interface IndexGenerator extends Serializable {
+public interface IndexGenerator extends Serializable {
 
     /**
      * Initialize the index generator, this will be called only once before {@link
      * #generate(RowData)} is called.
      */
     default void open() {
+
     }
 
     /** Generate index name according the the given row. */
