@@ -62,7 +62,6 @@ import org.apache.iceberg.flink.FlinkSchemaUtil;
 import org.apache.iceberg.flink.FlinkWriteConf;
 import org.apache.iceberg.flink.FlinkWriteOptions;
 import org.apache.iceberg.flink.TableLoader;
-import org.apache.iceberg.flink.sink.TaskWriterFactory;
 import org.apache.iceberg.flink.util.FlinkCompatibilityUtil;
 import org.apache.iceberg.io.WriteResult;
 import org.apache.iceberg.relocated.com.google.common.annotations.VisibleForTesting;
@@ -71,6 +70,7 @@ import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
 import org.apache.iceberg.relocated.com.google.common.collect.Sets;
 import org.apache.iceberg.types.TypeUtil;
+import org.apache.iceberg.types.Types.NestedField;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -78,6 +78,7 @@ import javax.annotation.Nullable;
 
 import java.io.IOException;
 import java.io.UncheckedIOException;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -86,10 +87,13 @@ import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 
 import static org.apache.iceberg.TableProperties.WRITE_DISTRIBUTION_MODE;
+import static org.apache.inlong.sort.base.Constants.META_INCREMENTAL;
 import static org.apache.inlong.sort.iceberg.FlinkDynamicTableFactory.WRITE_MINI_BATCH_BUFFER_TYPE;
 import static org.apache.inlong.sort.iceberg.FlinkDynamicTableFactory.WRITE_MINI_BATCH_ENABLE;
 import static org.apache.inlong.sort.iceberg.FlinkDynamicTableFactory.WRITE_MINI_BATCH_PRE_AGG_ENABLE;
 import static org.apache.inlong.sort.iceberg.FlinkDynamicTableFactory.WRITE_RATE_LIMIT;
+import static org.apache.inlong.sort.iceberg.schema.IcebergModeSwitchHelper.filterOutMetaField;
+import static org.apache.inlong.sort.iceberg.schema.IcebergModeSwitchHelper.getMetaFieldIndex;
 
 /**
  * Copy from iceberg-flink:iceberg-flink-1.13:0.13.2
@@ -176,6 +180,7 @@ public class FlinkSink {
         private FlinkWriteConf flinkWriteConf = null;
         private String inlongMetric = null;
         private String auditHostAndPorts = null;
+        private String auditKeys;
         private CatalogLoader catalogLoader = null;
         private boolean multipleSink = false;
         private MultipleSinkOption multipleSinkOption = null;
@@ -184,6 +189,8 @@ public class FlinkSink {
         private ReadableConfig tableOptions = new Configuration();
         private boolean enableSchemaChange;
         private String schemaChangePolicies;
+        private boolean switchAppendUpsertEnable = false;
+        private boolean autoCreateTableWhenSnapshot;
 
         private Builder() {
         }
@@ -257,6 +264,11 @@ public class FlinkSink {
             return this;
         }
 
+        public Builder switchAppendUpsertEnable(boolean switchAppendUpsertEnable) {
+            this.switchAppendUpsertEnable = switchAppendUpsertEnable;
+            return this;
+        }
+
         public Builder multipleSinkOption(MultipleSinkOption multipleSinkOption) {
             this.multipleSinkOption = multipleSinkOption;
             return this;
@@ -273,6 +285,11 @@ public class FlinkSink {
             return this;
         }
 
+        public Builder autoCreateTableWhenSnapshot(boolean autoCreateTableWhenSnapshot) {
+            this.autoCreateTableWhenSnapshot = autoCreateTableWhenSnapshot;
+            return this;
+        }
+
         public Builder schemaChangePolicies(String schemaChangePolicies) {
             this.schemaChangePolicies = schemaChangePolicies;
             return this;
@@ -311,9 +328,10 @@ public class FlinkSink {
          * @param auditHostAndPorts
          * @return
          */
-        public Builder metric(String inlongMetric, String auditHostAndPorts) {
+        public Builder metric(String inlongMetric, String auditHostAndPorts, String auditKeys) {
             this.inlongMetric = inlongMetric;
             this.auditHostAndPorts = auditHostAndPorts;
+            this.auditKeys = auditKeys;
             return this;
         }
 
@@ -526,6 +544,7 @@ public class FlinkSink {
                 }
                 equalityFieldIds = Lists.newArrayList(equalityFieldSet);
             }
+            LOG.info("equalityFieldIds in iceberg: {}", equalityFieldIds);
             return equalityFieldIds;
         }
 
@@ -642,7 +661,9 @@ public class FlinkSink {
             // Only if not appendMode, upsert can be valid.
             boolean upsertMode = flinkWriteConf.upsertMode() && !appendMode;
 
+            LOG.info("The iceberg sink is using {} mode.", upsertMode ? "upsert" : "append");
             // Validate the equality fields and partition fields if we enable the upsert mode.
+
             if (upsertMode) {
                 Preconditions.checkState(!flinkWriteConf.overwriteMode(),
                         "OVERWRITE mode shouldn't be enable when configuring to use UPSERT data stream.");
@@ -660,11 +681,12 @@ public class FlinkSink {
             // Add rate limit if necessary
             DataStream<RowData> inputWithRateLimit = appendWithRateLimit(input);
             DataStream<RowData> inputWithMiniBatch = appendWithMiniBatchGroup(
-                    inputWithRateLimit, flinkRowType, equalityFieldIds.stream().collect(Collectors.toSet()));
+                    inputWithRateLimit, flinkRowType, new HashSet<>(equalityFieldIds));
 
             IcebergProcessOperator<RowData, WriteResult> streamWriter = createStreamWriter(
                     table, flinkRowType, equalityFieldIds, flinkWriteConf, appendMode, inlongMetric,
-                    auditHostAndPorts, dirtyOptions, dirtySink, tableOptions.get(WRITE_MINI_BATCH_ENABLE));
+                    auditHostAndPorts, dirtyOptions, dirtySink, tableSchema,
+                    switchAppendUpsertEnable, tableOptions.get(WRITE_MINI_BATCH_ENABLE), auditKeys);
 
             int parallelism = writeParallelism == null ? input.getParallelism() : writeParallelism;
             SingleOutputStreamOperator<WriteResult> writerStream = inputWithMiniBatch
@@ -685,17 +707,19 @@ public class FlinkSink {
             int parallelism = writeParallelism == null ? input.getParallelism() : writeParallelism;
             DynamicSchemaHandleOperator routeOperator = new DynamicSchemaHandleOperator(
                     catalogLoader, multipleSinkOption, dirtyOptions, dirtySink, inlongMetric, auditHostAndPorts,
-                    enableSchemaChange, schemaChangePolicies);
+                    enableSchemaChange, schemaChangePolicies, autoCreateTableWhenSnapshot, auditKeys);
             SingleOutputStreamOperator<RecordWithSchema> routeStream = input
                     .transform(operatorName(ICEBERG_WHOLE_DATABASE_MIGRATION_NAME),
                             TypeInformation.of(RecordWithSchema.class),
                             routeOperator)
                     .setParallelism(parallelism);
-
+            RowType tableSchemaRowType = (RowType) tableSchema.toRowDataType().getLogicalType();
             IcebergProcessOperator streamWriter =
                     new IcebergProcessOperator(new IcebergMultipleStreamWriter(
                             appendMode, catalogLoader, inlongMetric, auditHostAndPorts,
-                            multipleSinkOption, dirtyOptions, dirtySink));
+                            multipleSinkOption, dirtyOptions, dirtySink, tableSchemaRowType,
+                            getMetaFieldIndex(tableSchema),
+                            switchAppendUpsertEnable, auditKeys));
             SingleOutputStreamOperator<MultipleWriteResult> writerStream = routeStream
                     .transform(operatorName(ICEBERG_MULTIPLE_STREAM_WRITER_NAME),
                             TypeInformation.of(IcebergProcessOperator.class),
@@ -782,14 +806,19 @@ public class FlinkSink {
         if (requestedSchema != null) {
             // Convert the flink schema to iceberg schema firstly, then reassign ids to match the existing iceberg
             // schema.
-            Schema writeSchema = TypeUtil.reassignIds(FlinkSchemaUtil.convert(requestedSchema), schema);
+            List<NestedField> filteredFields = FlinkSchemaUtil.convert(requestedSchema)
+                    .columns()
+                    .stream()
+                    .filter(nestedField -> !META_INCREMENTAL.equals(nestedField.name()))
+                    .collect(Collectors.toList());
+            Schema writeSchema = TypeUtil.reassignIds(new Schema(filteredFields), schema);
             TypeUtil.validateWriteSchema(schema, writeSchema, true, true);
 
             // We use this flink schema to read values from RowData. The flink's TINYINT and SMALLINT will be promoted
             // to iceberg INTEGER, that means if we use iceberg's table schema to read TINYINT (backend by 1 'byte'),
             // we will read 4 bytes rather than 1 byte, it will mess up the byte array in BinaryRowData. So here we must
             // use flink schema.
-            return (RowType) requestedSchema.toRowDataType().getLogicalType();
+            return (RowType) filterOutMetaField(requestedSchema).getLogicalType();
         } else {
             return FlinkSchemaUtil.convert(schema);
         }
@@ -804,12 +833,15 @@ public class FlinkSink {
             String auditHostAndPorts,
             DirtyOptions dirtyOptions,
             @Nullable DirtySink<Object> dirtySink,
-            boolean miniBatchMode) {
+            TableSchema tableSchema,
+            boolean switchAppendUpsertEnable,
+            boolean miniBatchMode,
+            String auditKeys) {
         // flink A, iceberg a
         Preconditions.checkArgument(table != null, "Iceberg table should't be null");
 
         Table serializableTable = SerializableTable.copyOf(table);
-        TaskWriterFactory<RowData> taskWriterFactory =
+        RowDataTaskWriterFactory taskWriterFactory =
                 new RowDataTaskWriterFactory(
                         serializableTable,
                         serializableTable.schema(),
@@ -821,9 +853,11 @@ public class FlinkSink {
                         appendMode,
                         miniBatchMode);
 
+        RowType tableSchemaRowType = (RowType) tableSchema.toRowDataType().getLogicalType();
         return new IcebergProcessOperator<>(new IcebergSingleStreamWriter<>(
                 table.name(), taskWriterFactory, inlongMetric, auditHostAndPorts,
-                null, dirtyOptions, dirtySink, false));
+                flinkRowType, dirtyOptions, dirtySink, false,
+                tableSchemaRowType, getMetaFieldIndex(tableSchema), switchAppendUpsertEnable, auditKeys));
     }
 
 }
