@@ -50,7 +50,6 @@ import org.apache.iceberg.catalog.Catalog;
 import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.flink.CatalogLoader;
 import org.apache.iceberg.flink.FlinkSchemaUtil;
-import org.apache.iceberg.flink.sink.TaskWriterFactory;
 import org.apache.iceberg.types.Types.NestedField;
 import org.apache.iceberg.util.PropertyUtil;
 import org.slf4j.Logger;
@@ -103,6 +102,7 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
     // metric
     private final String inlongMetric;
     private final String auditHostAndPorts;
+    private final String auditKeys;
     private final DirtyOptions dirtyOptions;
     private @Nullable final DirtySink<Object> dirtySink;
 
@@ -110,6 +110,9 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
     private transient MetricState metricState;
     private transient ListState<MetricState> metricStateListState;
     private transient RuntimeContext runtimeContext;
+    private final RowType tableSchemaRowType;
+    private final int metaFieldIndex;
+    private final boolean switchAppendUpsertEnable;
 
     public IcebergMultipleStreamWriter(
             boolean appendMode,
@@ -118,7 +121,11 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
             String auditHostAndPorts,
             MultipleSinkOption multipleSinkOption,
             DirtyOptions dirtyOptions,
-            @Nullable DirtySink<Object> dirtySink) {
+            @Nullable DirtySink<Object> dirtySink,
+            RowType tableSchemaRowType,
+            int metaFieldIndex,
+            boolean switchAppendUpsertEnable,
+            String auditKeys) {
         this.appendMode = appendMode;
         this.catalogLoader = catalogLoader;
         this.inlongMetric = inlongMetric;
@@ -126,6 +133,10 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
         this.multipleSinkOption = multipleSinkOption;
         this.dirtyOptions = dirtyOptions;
         this.dirtySink = dirtySink;
+        this.tableSchemaRowType = tableSchemaRowType;
+        this.metaFieldIndex = metaFieldIndex;
+        this.switchAppendUpsertEnable = switchAppendUpsertEnable;
+        this.auditKeys = auditKeys;
     }
 
     @Override
@@ -144,6 +155,7 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
                 .withInitDirtyRecords(metricState != null ? metricState.getMetricValue(DIRTY_RECORDS_OUT) : 0L)
                 .withInitDirtyBytes(metricState != null ? metricState.getMetricValue(DIRTY_BYTES_OUT) : 0L)
                 .withRegisterMetric(MetricOption.RegisteredMetric.ALL)
+                .withAuditKeys(auditKeys)
                 .build();
         if (metricOption != null) {
             sinkMetricData = new SinkTableMetricData(metricOption, runtimeContext.getMetricGroup());
@@ -187,7 +199,13 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
     @Override
     public void processElement(RecordWithSchema recordWithSchema) throws Exception {
         TableIdentifier tableId = recordWithSchema.getTableId();
-
+        if (recordWithSchema.isDDL()) {
+            // just record node metrics for ddl
+            if (sinkMetricData != null) {
+                sinkMetricData.outputMetricsWithEstimate(1);
+            }
+            return;
+        }
         if (isSchemaUpdate(recordWithSchema)) {
             if (multipleTables.get(tableId) == null) {
                 Table table = catalog.loadTable(recordWithSchema.getTableId());
@@ -213,7 +231,7 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
                         .collect(Collectors.toList());
             }
             RowType flinkRowType = FlinkSchemaUtil.convert(recordWithSchema.getSchema());
-            TaskWriterFactory<RowData> taskWriterFactory = new RowDataTaskWriterFactory(
+            RowDataTaskWriterFactory taskWriterFactory = new RowDataTaskWriterFactory(
                     table,
                     recordWithSchema.getSchema(),
                     flinkRowType,
@@ -225,14 +243,14 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
                     false);
 
             if (multipleWriters.get(tableId) == null) {
-                StringBuilder subWriterInlongMetric = new StringBuilder(inlongMetric);
-                subWriterInlongMetric.append(DELIMITER)
-                        .append(Constants.DATABASE_NAME).append("=").append(tableId.namespace().toString())
-                        .append(DELIMITER)
-                        .append(Constants.TABLE_NAME).append("=").append(tableId.name());
+                String subWriterInlongMetric = inlongMetric + DELIMITER
+                        + Constants.DATABASE_NAME + "=" + tableId.namespace().toString()
+                        + DELIMITER
+                        + Constants.TABLE_NAME + "=" + tableId.name();
                 IcebergSingleStreamWriter<RowData> writer = new IcebergSingleStreamWriter<>(
-                        tableId.toString(), taskWriterFactory, subWriterInlongMetric.toString(),
-                        auditHostAndPorts, flinkRowType, dirtyOptions, dirtySink, true);
+                        tableId.toString(), taskWriterFactory, subWriterInlongMetric,
+                        auditHostAndPorts, flinkRowType, dirtyOptions, dirtySink, true,
+                        tableSchemaRowType, metaFieldIndex, switchAppendUpsertEnable, auditKeys);
                 writer.setup(getRuntimeContext(),
                         new CallbackCollector<>(
                                 writeResult -> collector.collect(new MultipleWriteResult(tableId, writeResult))),
@@ -263,6 +281,9 @@ public class IcebergMultipleStreamWriter extends IcebergProcessFunction<RecordWi
                     long size = CalculateObjectSizeUtils.getDataSize(data);
 
                     try {
+                        if (switchAppendUpsertEnable && recordWithSchema.isIncremental()) {
+                            multipleWriters.get(tableId).switchToUpsert();
+                        }
                         multipleWriters.get(tableId).processElement(data);
                     } catch (Exception e) {
                         LOG.error(String.format("write error, raw data: %s", data), e);
