@@ -25,6 +25,7 @@ import org.apache.inlong.sort.base.format.DynamicSchemaFormatFactory;
 import org.apache.inlong.sort.base.format.JsonDynamicSchemaFormat;
 import org.apache.inlong.sort.base.metric.sub.SinkTopicMetricData;
 import org.apache.inlong.sort.kafka.KafkaDynamicSink.WritableMetadata;
+import org.apache.inlong.sort.kafka.partitioner.SingleTableCustomFieldsPartitioner;
 import org.apache.inlong.sort.protocol.ddl.operations.Operation;
 import org.apache.inlong.sort.protocol.enums.SchemaChangePolicy;
 import org.apache.inlong.sort.protocol.enums.SchemaChangeType;
@@ -93,17 +94,15 @@ class DynamicKafkaSerializationSchema implements KafkaSerializationSchema<RowDat
      */
     private final int[] metadataPositions;
     private final String sinkMultipleFormat;
-    private boolean multipleSink;
-    private JsonDynamicSchemaFormat jsonDynamicSchemaFormat;
     private final DirtyOptions dirtyOptions;
     private final @Nullable DirtySink<Object> dirtySink;
+    final private Map<SchemaChangeType, SchemaChangePolicy> policyMap;
+    private boolean multipleSink;
+    private JsonDynamicSchemaFormat jsonDynamicSchemaFormat;
     private int[] partitions;
-
     private int parallelInstanceId;
-
     private int numParallelInstances;
     private SinkTopicMetricData metricData;
-    final private Map<SchemaChangeType, SchemaChangePolicy> policyMap;
 
     DynamicKafkaSerializationSchema(
             String topic,
@@ -141,10 +140,6 @@ class DynamicKafkaSerializationSchema implements KafkaSerializationSchema<RowDat
         this.policyMap = policyMap;
     }
 
-    public void setMetricData(SinkTopicMetricData metricData) {
-        this.metricData = metricData;
-    }
-
     static RowData createProjectedRow(
             RowData consumedRow, RowKind kind, RowData.FieldGetter[] fieldGetters) {
         final int arity = fieldGetters.length;
@@ -155,6 +150,10 @@ class DynamicKafkaSerializationSchema implements KafkaSerializationSchema<RowDat
         return genericRowData;
     }
 
+    public void setMetricData(SinkTopicMetricData metricData) {
+        this.metricData = metricData;
+    }
+
     @Override
     public void open(SerializationSchema.InitializationContext context) throws Exception {
         if (keySerialization != null) {
@@ -174,6 +173,10 @@ class DynamicKafkaSerializationSchema implements KafkaSerializationSchema<RowDat
             jsonDynamicSchemaFormat =
                     (JsonDynamicSchemaFormat) DynamicSchemaFormatFactory.getFormat(sinkMultipleFormat);
         }
+
+        if (partitioner instanceof SingleTableCustomFieldsPartitioner) {
+            ((SingleTableCustomFieldsPartitioner<?>) partitioner).setValueFieldGetters(valueFieldGetters);
+        }
     }
 
     @Override
@@ -267,7 +270,7 @@ class DynamicKafkaSerializationSchema implements KafkaSerializationSchema<RowDat
             JsonNode dataNode, List<ProducerRecord<byte[], byte[]>> values) {
         String topic = null;
         try {
-            byte[] data = jsonDynamicSchemaFormat.objectMapper.writeValueAsBytes(baseMap);
+            byte[] data = JsonDynamicSchemaFormat.OBJECT_MAPPER.writeValueAsBytes(baseMap);
             topic = jsonDynamicSchemaFormat.parse(rootNode, topicPattern);
             values.add(new ProducerRecord<>(topic,
                     extractPartition(null, null, data), null, data));
@@ -303,7 +306,7 @@ class DynamicKafkaSerializationSchema implements KafkaSerializationSchema<RowDat
             JsonNode operationNode = Preconditions.checkNotNull(rootNode.get("operation"),
                     "Operation node is null");
             operation = Preconditions.checkNotNull(
-                    jsonDynamicSchemaFormat.objectMapper.convertValue(operationNode, new TypeReference<Operation>() {
+                    JsonDynamicSchemaFormat.OBJECT_MAPPER.convertValue(operationNode, new TypeReference<Operation>() {
                     }), "Operation is null");
         } catch (Exception e) {
             LOG.error("Extract Operation from origin data failed", e);
