@@ -37,6 +37,7 @@ import io.debezium.time.NanoTime;
 import io.debezium.time.NanoTimestamp;
 import io.debezium.time.Timestamp;
 import io.debezium.time.ZonedTimestamp;
+import org.apache.commons.lang.StringUtils;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.table.data.DecimalData;
 import org.apache.flink.table.data.GenericRowData;
@@ -292,7 +293,7 @@ public final class RowDataDebeziumDeserializeSchema
 
             @Override
             public Object convert(Object dbzObj, Schema schema) {
-                if (dbzObj instanceof Long) {
+                if (dbzObj instanceof Long && StringUtils.isNotBlank(schema.name())) {
                     // Because Oracle CDC has been shaded, the schema will have the prefix
                     // 'org.apache.inlong.sort.cdc.oracle.shaded' added,
                     // so we need to use `schemaName.endsWith()` to determine the Schema type.
@@ -327,7 +328,7 @@ public final class RowDataDebeziumDeserializeSchema
 
             @Override
             public Object convert(Object dbzObj, Schema schema) {
-                if (dbzObj instanceof Long) {
+                if (dbzObj instanceof Long && StringUtils.isNotBlank(schema.name())) {
                     // Because Oracle CDC has been shaded, the schema will have the prefix
                     // 'org.apache.inlong.sort.cdc.oracle.shaded' added,
                     // so we need to use `schemaName.endsWith()` to determine the Schema type.
@@ -462,7 +463,8 @@ public final class RowDataDebeziumDeserializeSchema
                     // Because Oracle CDC has been shaded, the schema will have the prefix
                     // 'org.apache.inlong.sort.cdc.oracle.shaded' added,
                     // so we need to use `schemaName.endsWith()` to determine the Schema type.
-                    if (schema.name().endsWith(VariableScaleDecimal.LOGICAL_NAME)) {
+                    if (StringUtils.isNotBlank(schema.name())
+                            && schema.name().endsWith(VariableScaleDecimal.LOGICAL_NAME)) {
                         SpecialValueDecimal decimal =
                                 VariableScaleDecimal.toLogical((Struct) dbzObj);
                         bigDecimal = decimal.getDecimalValue().orElse(BigDecimal.ZERO);
@@ -768,8 +770,8 @@ public final class RowDataDebeziumDeserializeSchema
      * @return the extracted data with schema
      */
     private Object getValueWithSchema(Object fieldValue, String schemaName) {
-        if (fieldValue == null) {
-            return null;
+        if (fieldValue == null || StringUtils.isBlank(schemaName)) {
+            return fieldValue;
         }
         // Because Oracle CDC has been shaded, the schema will have the prefix
         // 'org.apache.inlong.sort.cdc.oracle.shaded' added,
@@ -795,13 +797,18 @@ public final class RowDataDebeziumDeserializeSchema
 
     @Override
     public void deserialize(SourceRecord record, Collector<RowData> out) throws Exception {
-        deserialize(record, out);
+        extractRowAndEmitRecord(record, out, null);
     }
 
     @Override
     public void deserialize(SourceRecord record, Collector<RowData> out,
             TableChange tableSchema)
             throws Exception {
+        extractRowAndEmitRecord(record, out, tableSchema);
+    }
+
+    private void extractRowAndEmitRecord(SourceRecord record, Collector<RowData> out, TableChange tableSchema)
+            throws Exception {
         Envelope.Operation op = Envelope.operationFor(record);
         Struct value = (Struct) record.value();
         Schema valueSchema = record.valueSchema();
