@@ -464,9 +464,9 @@ public class FlinkPulsarSource<T>
         }
 
         if (this.deserializer != null) {
-            DynamicPulsarDeserializationSchema dynamicKafkaDeserializationSchema =
+            DynamicPulsarDeserializationSchema dynamicPulsarDeserializationSchema =
                     (DynamicPulsarDeserializationSchema) deserializer;
-            dynamicKafkaDeserializationSchema.setMetricData(sourceMetricData);
+            dynamicPulsarDeserializationSchema.setMetricData(sourceMetricData);
 
             this.deserializer.open(
                     RuntimeContextInitializationContextAdapters.deserializationAdapter(
