@@ -17,13 +17,10 @@
 
 package org.apache.inlong.sort.elasticsearch.table;
 
-import org.apache.flink.annotation.Internal;
-
 import java.time.format.DateTimeFormatter;
 
 /** Abstract class for time related {@link IndexGenerator}. */
-@Internal
-abstract class AbstractTimeIndexGenerator extends IndexGeneratorBase {
+public abstract class AbstractTimeIndexGenerator extends IndexGeneratorBase {
 
     private final String dateTimeFormat;
     protected transient DateTimeFormatter dateTimeFormatter;
