@@ -44,6 +44,7 @@ import org.apache.flink.util.StringUtils;
 import org.apache.iceberg.CachingCatalog;
 import org.apache.iceberg.DataFile;
 import org.apache.iceberg.FileScanTask;
+import org.apache.iceberg.MetadataTableType;
 import org.apache.iceberg.PartitionField;
 import org.apache.iceberg.PartitionSpec;
 import org.apache.iceberg.Schema;
@@ -58,11 +59,14 @@ import org.apache.iceberg.catalog.TableIdentifier;
 import org.apache.iceberg.exceptions.AlreadyExistsException;
 import org.apache.iceberg.exceptions.NamespaceNotEmptyException;
 import org.apache.iceberg.exceptions.NoSuchNamespaceException;
+import org.apache.iceberg.exceptions.NoSuchTableException;
 import org.apache.iceberg.flink.CatalogLoader;
 import org.apache.iceberg.flink.FlinkSchemaUtil;
 import org.apache.iceberg.flink.util.FlinkCompatibilityUtil;
 import org.apache.iceberg.io.CloseableIterable;
 import org.apache.iceberg.relocated.com.google.common.base.Preconditions;
+import org.apache.iceberg.relocated.com.google.common.base.Splitter;
+import org.apache.iceberg.relocated.com.google.common.collect.ImmutableList;
 import org.apache.iceberg.relocated.com.google.common.collect.ImmutableMap;
 import org.apache.iceberg.relocated.com.google.common.collect.Lists;
 import org.apache.iceberg.relocated.com.google.common.collect.Maps;
@@ -80,15 +84,16 @@ import java.util.stream.Collectors;
 
 /**
  * A Flink Catalog implementation that wraps an Iceberg {@link Catalog}.
- * <p>
- * The mapping between Flink database and Iceberg namespace:
- * Supplying a base namespace for a given catalog, so if you have a catalog that supports a 2-level namespace, you
- * would supply the first level in the catalog configuration and the second level would be exposed as Flink databases.
- * </p>
- * The Iceberg table manages its partitions by itself. The partition of the Iceberg table is independent of the
- * partition of Flink.
  *
- * Copy from iceberg-flink:iceberg-flink-1.13:0.13.2
+ * <p>The mapping between Flink database and Iceberg namespace: Supplying a base namespace for a
+ * given catalog, so if you have a catalog that supports a 2-level namespace, you would supply the
+ * first level in the catalog configuration and the second level would be exposed as Flink
+ * databases.
+ *
+ * <p>The Iceberg table manages its partitions by itself. The partition of the Iceberg table is
+ * independent of the partition of Flink.
+ *
+ * Copy from iceberg-flink:iceberg-flink-1.15:1.3.1
  */
 public class FlinkCatalog extends AbstractCatalog {
 
@@ -104,116 +109,27 @@ public class FlinkCatalog extends AbstractCatalog {
             String defaultDatabase,
             Namespace baseNamespace,
             CatalogLoader catalogLoader,
-            boolean cacheEnabled) {
+            boolean cacheEnabled,
+            long cacheExpirationIntervalMs) {
         super(catalogName, defaultDatabase);
         this.catalogLoader = catalogLoader;
         this.baseNamespace = baseNamespace;
         this.cacheEnabled = cacheEnabled;
 
         Catalog originalCatalog = catalogLoader.loadCatalog();
-        icebergCatalog = cacheEnabled ? CachingCatalog.wrap(originalCatalog) : originalCatalog;
+        icebergCatalog =
+                cacheEnabled
+                        ? CachingCatalog.wrap(originalCatalog, cacheExpirationIntervalMs)
+                        : originalCatalog;
         asNamespaceCatalog =
                 originalCatalog instanceof SupportsNamespaces ? (SupportsNamespaces) originalCatalog : null;
         closeable = originalCatalog instanceof Closeable ? (Closeable) originalCatalog : null;
-    }
 
-    private static void validateFlinkTable(CatalogBaseTable table) {
-        Preconditions.checkArgument(table instanceof CatalogTable, "The Table should be a CatalogTable.");
-
-        TableSchema schema = table.getSchema();
-        schema.getTableColumns().forEach(column -> {
-            if (!FlinkCompatibilityUtil.isPhysicalColumn(column)) {
-                throw new UnsupportedOperationException("Creating table with computed columns is not supported yet.");
-            }
-        });
-
-        if (!schema.getWatermarkSpecs().isEmpty()) {
-            throw new UnsupportedOperationException("Creating table with watermark specs is not supported yet.");
-        }
-    }
-
-    private static PartitionSpec toPartitionSpec(List<String> partitionKeys, Schema icebergSchema) {
-        PartitionSpec.Builder builder = PartitionSpec.builderFor(icebergSchema);
-        partitionKeys.forEach(builder::identity);
-        return builder.build();
-    }
-
-    private static List<String> toPartitionKeys(PartitionSpec spec, Schema icebergSchema) {
-        List<String> partitionKeys = Lists.newArrayList();
-        for (PartitionField field : spec.fields()) {
-            if (field.transform().isIdentity()) {
-                partitionKeys.add(icebergSchema.findColumnName(field.sourceId()));
-            } else {
-                // Not created by Flink SQL.
-                // For compatibility with iceberg tables, return empty.
-                // TODO modify this after Flink support partition transform.
-                return Collections.emptyList();
-            }
-        }
-        return partitionKeys;
-    }
-
-    private static void commitChanges(Table table, String setLocation, String setSnapshotId,
-            String pickSnapshotId, Map<String, String> setProperties) {
-        // don't allow setting the snapshot and picking a commit
-        // at the same time because order is ambiguous and choosing
-        // one order leads to different results
-        Preconditions.checkArgument(setSnapshotId == null || pickSnapshotId == null,
-                "Cannot set the current snapshot ID and cherry-pick snapshot changes");
-
-        if (setSnapshotId != null) {
-            long newSnapshotId = Long.parseLong(setSnapshotId);
-            table.manageSnapshots().setCurrentSnapshot(newSnapshotId).commit();
-        }
-
-        // if updating the table snapshot, perform that update first in case it fails
-        if (pickSnapshotId != null) {
-            long newSnapshotId = Long.parseLong(pickSnapshotId);
-            table.manageSnapshots().cherrypick(newSnapshotId).commit();
-        }
-
-        Transaction transaction = table.newTransaction();
-
-        if (setLocation != null) {
-            transaction.updateLocation()
-                    .setLocation(setLocation)
-                    .commit();
-        }
-
-        if (!setProperties.isEmpty()) {
-            UpdateProperties updateProperties = transaction.updateProperties();
-            setProperties.forEach((k, v) -> {
-                if (v == null) {
-                    updateProperties.remove(k);
-                } else {
-                    updateProperties.set(k, v);
-                }
-            });
-            updateProperties.commit();
-        }
-
-        transaction.commitTransaction();
-    }
-
-    static CatalogTable toCatalogTable(Table table) {
-        TableSchema schema = FlinkSchemaUtil.toSchema(table.schema());
-        List<String> partitionKeys = toPartitionKeys(table.spec(), table.schema());
-
-        // NOTE: We can not create a IcebergCatalogTable extends CatalogTable, because Flink optimizer may use
-        // CatalogTableImpl to copy a new catalog table.
-        // Let's re-loading table from Iceberg catalog when creating source/sink operators.
-        // Iceberg does not have Table comment, so pass a null (Default comment value in Flink).
-        return new CatalogTableImpl(schema, partitionKeys, table.properties(), null);
+        FlinkEnvironmentContext.init();
     }
 
     @Override
     public void open() throws CatalogException {
-        // Create the default database if it does not exist.
-        try {
-            createDatabase(getDefaultDatabase(), ImmutableMap.of(), true);
-        } catch (DatabaseAlreadyExistException e) {
-            // Ignore the exception if it's already exist.
-        }
     }
 
     @Override
@@ -231,15 +147,28 @@ public class FlinkCatalog extends AbstractCatalog {
         return icebergCatalog;
     }
 
-    private Namespace toNamespace(String database) {
+    /** Append a new level to the base namespace */
+    private static Namespace appendLevel(Namespace baseNamespace, String newLevel) {
         String[] namespace = new String[baseNamespace.levels().length + 1];
         System.arraycopy(baseNamespace.levels(), 0, namespace, 0, baseNamespace.levels().length);
-        namespace[baseNamespace.levels().length] = database;
+        namespace[baseNamespace.levels().length] = newLevel;
         return Namespace.of(namespace);
     }
 
     TableIdentifier toIdentifier(ObjectPath path) {
-        return TableIdentifier.of(toNamespace(path.getDatabaseName()), path.getObjectName());
+        String objectName = path.getObjectName();
+        List<String> tableName = Splitter.on('$').splitToList(objectName);
+
+        if (tableName.size() == 1) {
+            return TableIdentifier.of(
+                    appendLevel(baseNamespace, path.getDatabaseName()), path.getObjectName());
+        } else if (tableName.size() == 2 && MetadataTableType.from(tableName.get(1)) != null) {
+            return TableIdentifier.of(
+                    appendLevel(appendLevel(baseNamespace, path.getDatabaseName()), tableName.get(0)),
+                    tableName.get(1));
+        } else {
+            throw new IllegalArgumentException("Illegal table name:" + objectName);
+        }
     }
 
     @Override
@@ -254,7 +183,8 @@ public class FlinkCatalog extends AbstractCatalog {
     }
 
     @Override
-    public CatalogDatabase getDatabase(String databaseName) throws DatabaseNotExistException, CatalogException {
+    public CatalogDatabase getDatabase(String databaseName)
+            throws DatabaseNotExistException, CatalogException {
         if (asNamespaceCatalog == null) {
             if (!getDefaultDatabase().equals(databaseName)) {
                 throw new DatabaseNotExistException(getName(), databaseName);
@@ -264,7 +194,8 @@ public class FlinkCatalog extends AbstractCatalog {
         } else {
             try {
                 Map<String, String> metadata =
-                        Maps.newHashMap(asNamespaceCatalog.loadNamespaceMetadata(toNamespace(databaseName)));
+                        Maps.newHashMap(
+                                asNamespaceCatalog.loadNamespaceMetadata(appendLevel(baseNamespace, databaseName)));
                 String comment = metadata.remove("comment");
                 return new CatalogDatabaseImpl(metadata, comment);
             } catch (NoSuchNamespaceException e) {
@@ -286,21 +217,24 @@ public class FlinkCatalog extends AbstractCatalog {
     @Override
     public void createDatabase(String name, CatalogDatabase database, boolean ignoreIfExists)
             throws DatabaseAlreadyExistException, CatalogException {
-        createDatabase(name, mergeComment(database.getProperties(), database.getComment()), ignoreIfExists);
+        createDatabase(
+                name, mergeComment(database.getProperties(), database.getComment()), ignoreIfExists);
     }
 
-    private void createDatabase(String databaseName, Map<String, String> metadata, boolean ignoreIfExists)
+    private void createDatabase(
+            String databaseName, Map<String, String> metadata, boolean ignoreIfExists)
             throws DatabaseAlreadyExistException, CatalogException {
         if (asNamespaceCatalog != null) {
             try {
-                asNamespaceCatalog.createNamespace(toNamespace(databaseName), metadata);
+                asNamespaceCatalog.createNamespace(appendLevel(baseNamespace, databaseName), metadata);
             } catch (AlreadyExistsException e) {
                 if (!ignoreIfExists) {
                     throw new DatabaseAlreadyExistException(getName(), databaseName, e);
                 }
             }
         } else {
-            throw new UnsupportedOperationException("Namespaces are not supported by catalog: " + getName());
+            throw new UnsupportedOperationException(
+                    "Namespaces are not supported by catalog: " + getName());
         }
     }
 
@@ -321,7 +255,7 @@ public class FlinkCatalog extends AbstractCatalog {
             throws DatabaseNotExistException, DatabaseNotEmptyException, CatalogException {
         if (asNamespaceCatalog != null) {
             try {
-                boolean success = asNamespaceCatalog.dropNamespace(toNamespace(name));
+                boolean success = asNamespaceCatalog.dropNamespace(appendLevel(baseNamespace, name));
                 if (!success && !ignoreIfNotExists) {
                     throw new DatabaseNotExistException(getName(), name);
                 }
@@ -343,13 +277,14 @@ public class FlinkCatalog extends AbstractCatalog {
     public void alterDatabase(String name, CatalogDatabase newDatabase, boolean ignoreIfNotExists)
             throws DatabaseNotExistException, CatalogException {
         if (asNamespaceCatalog != null) {
-            Namespace namespace = toNamespace(name);
+            Namespace namespace = appendLevel(baseNamespace, name);
             Map<String, String> updates = Maps.newHashMap();
             Set<String> removals = Sets.newHashSet();
 
             try {
                 Map<String, String> oldProperties = asNamespaceCatalog.loadNamespaceMetadata(namespace);
-                Map<String, String> newProperties = mergeComment(newDatabase.getProperties(), newDatabase.getComment());
+                Map<String, String> newProperties =
+                        mergeComment(newDatabase.getProperties(), newDatabase.getComment());
 
                 for (String key : oldProperties.keySet()) {
                     if (!newProperties.containsKey(key)) {
@@ -388,9 +323,10 @@ public class FlinkCatalog extends AbstractCatalog {
     }
 
     @Override
-    public List<String> listTables(String databaseName) throws DatabaseNotExistException, CatalogException {
+    public List<String> listTables(String databaseName)
+            throws DatabaseNotExistException, CatalogException {
         try {
-            return icebergCatalog.listTables(toNamespace(databaseName)).stream()
+            return icebergCatalog.listTables(appendLevel(baseNamespace, databaseName)).stream()
                     .map(TableIdentifier::name)
                     .collect(Collectors.toList());
         } catch (NoSuchNamespaceException e) {
@@ -399,7 +335,8 @@ public class FlinkCatalog extends AbstractCatalog {
     }
 
     @Override
-    public CatalogTable getTable(ObjectPath tablePath) throws TableNotExistException, CatalogException {
+    public CatalogTable getTable(ObjectPath tablePath)
+            throws TableNotExistException, CatalogException {
         Table table = loadIcebergTable(tablePath);
         return toCatalogTable(table);
     }
@@ -441,7 +378,7 @@ public class FlinkCatalog extends AbstractCatalog {
             icebergCatalog.renameTable(
                     toIdentifier(tablePath),
                     toIdentifier(new ObjectPath(tablePath.getDatabaseName(), newTableName)));
-        } catch (org.apache.iceberg.exceptions.NoSuchTableException e) {
+        } catch (NoSuchTableException e) {
             if (!ignoreIfNotExists) {
                 throw new TableNotExistException(getName(), tablePath, e);
             }
@@ -453,11 +390,12 @@ public class FlinkCatalog extends AbstractCatalog {
     @Override
     public void createTable(ObjectPath tablePath, CatalogBaseTable table, boolean ignoreIfExists)
             throws CatalogException, TableAlreadyExistException {
-        if (Objects.equals(table.getOptions().get("connector"), FlinkDynamicTableFactory.FACTORY_IDENTIFIER)) {
-            throw new IllegalArgumentException("Cannot create the table with 'connector'='iceberg' table property in "
-                    + "an iceberg catalog, Please create table with 'connector'='iceberg' "
-                    + "property in a non-iceberg catalog "
-                    + "or create table without 'connector'='iceberg' related properties in an iceberg table.");
+        if (Objects.equals(
+                table.getOptions().get("connector"), FlinkDynamicTableFactory.FACTORY_IDENTIFIER)) {
+            throw new IllegalArgumentException(
+                    "Cannot create the table with 'connector'='iceberg' table property in "
+                            + "an iceberg catalog, Please create table with 'connector'='iceberg' property in a non-iceberg catalog or "
+                            + "create table without 'connector'='iceberg' related properties in an iceberg table.");
         }
 
         createIcebergTable(tablePath, table, ignoreIfExists);
@@ -482,11 +420,7 @@ public class FlinkCatalog extends AbstractCatalog {
 
         try {
             icebergCatalog.createTable(
-                    toIdentifier(tablePath),
-                    icebergSchema,
-                    spec,
-                    location,
-                    properties.build());
+                    toIdentifier(tablePath), icebergSchema, spec, location, properties.build());
         } catch (AlreadyExistsException e) {
             if (!ignoreIfExists) {
                 throw new TableAlreadyExistException(getName(), tablePath, e);
@@ -494,6 +428,31 @@ public class FlinkCatalog extends AbstractCatalog {
         }
     }
 
+    private static void validateTableSchemaAndPartition(CatalogTable ct1, CatalogTable ct2) {
+        TableSchema ts1 = ct1.getSchema();
+        TableSchema ts2 = ct2.getSchema();
+        boolean equalsPrimary = false;
+
+        if (ts1.getPrimaryKey().isPresent() && ts2.getPrimaryKey().isPresent()) {
+            equalsPrimary =
+                    Objects.equals(ts1.getPrimaryKey().get().getType(), ts2.getPrimaryKey().get().getType())
+                            && Objects.equals(
+                                    ts1.getPrimaryKey().get().getColumns(), ts2.getPrimaryKey().get().getColumns());
+        } else if (!ts1.getPrimaryKey().isPresent() && !ts2.getPrimaryKey().isPresent()) {
+            equalsPrimary = true;
+        }
+
+        if (!(Objects.equals(ts1.getTableColumns(), ts2.getTableColumns())
+                && Objects.equals(ts1.getWatermarkSpecs(), ts2.getWatermarkSpecs())
+                && equalsPrimary)) {
+            throw new UnsupportedOperationException("Altering schema is not supported yet.");
+        }
+
+        if (!ct1.getPartitionKeys().equals(ct2.getPartitionKeys())) {
+            throw new UnsupportedOperationException("Altering partition keys is not supported yet.");
+        }
+    }
+
     @Override
     public void alterTable(ObjectPath tablePath, CatalogBaseTable newTable, boolean ignoreIfNotExists)
             throws CatalogException, TableNotExistException {
@@ -514,15 +473,10 @@ public class FlinkCatalog extends AbstractCatalog {
 
         // Currently, Flink SQL only support altering table properties.
 
-        // For current Flink Catalog API, support for adding/removing/renaming columns cannot be done by comparing
+        // For current Flink Catalog API, support for adding/removing/renaming columns cannot be done by
+        // comparing
         // CatalogTable instances, unless the Flink schema contains Iceberg column IDs.
-        if (!table.getSchema().equals(newTable.getSchema())) {
-            throw new UnsupportedOperationException("Altering schema is not supported yet.");
-        }
-
-        if (!table.getPartitionKeys().equals(((CatalogTable) newTable).getPartitionKeys())) {
-            throw new UnsupportedOperationException("Altering partition keys is not supported yet.");
-        }
+        validateTableSchemaAndPartition(table, (CatalogTable) newTable);
 
         Map<String, String> oldProperties = table.getOptions();
         Map<String, String> setProperties = Maps.newHashMap();
@@ -550,15 +504,118 @@ public class FlinkCatalog extends AbstractCatalog {
             }
         }
 
-        oldProperties.keySet().forEach(k -> {
-            if (!newTable.getOptions().containsKey(k)) {
-                setProperties.put(k, null);
-            }
-        });
+        oldProperties
+                .keySet()
+                .forEach(
+                        k -> {
+                            if (!newTable.getOptions().containsKey(k)) {
+                                setProperties.put(k, null);
+                            }
+                        });
 
         commitChanges(icebergTable, setLocation, setSnapshotId, pickSnapshotId, setProperties);
     }
 
+    private static void validateFlinkTable(CatalogBaseTable table) {
+        Preconditions.checkArgument(
+                table instanceof CatalogTable, "The Table should be a CatalogTable.");
+
+        TableSchema schema = table.getSchema();
+        schema
+                .getTableColumns()
+                .forEach(
+                        column -> {
+                            if (!FlinkCompatibilityUtil.isPhysicalColumn(column)) {
+                                throw new UnsupportedOperationException(
+                                        "Creating table with computed columns is not supported yet.");
+                            }
+                        });
+
+        if (!schema.getWatermarkSpecs().isEmpty()) {
+            throw new UnsupportedOperationException(
+                    "Creating table with watermark specs is not supported yet.");
+        }
+    }
+
+    private static PartitionSpec toPartitionSpec(List<String> partitionKeys, Schema icebergSchema) {
+        PartitionSpec.Builder builder = PartitionSpec.builderFor(icebergSchema);
+        partitionKeys.forEach(builder::identity);
+        return builder.build();
+    }
+
+    private static List<String> toPartitionKeys(PartitionSpec spec, Schema icebergSchema) {
+        ImmutableList.Builder<String> partitionKeysBuilder = ImmutableList.builder();
+        for (PartitionField field : spec.fields()) {
+            if (field.transform().isIdentity()) {
+                partitionKeysBuilder.add(icebergSchema.findColumnName(field.sourceId()));
+            } else {
+                // Not created by Flink SQL.
+                // For compatibility with iceberg tables, return empty.
+                // TODO modify this after Flink support partition transform.
+                return Collections.emptyList();
+            }
+        }
+        return partitionKeysBuilder.build();
+    }
+
+    private static void commitChanges(
+            Table table,
+            String setLocation,
+            String setSnapshotId,
+            String pickSnapshotId,
+            Map<String, String> setProperties) {
+        // don't allow setting the snapshot and picking a commit at the same time because order is
+        // ambiguous and choosing
+        // one order leads to different results
+        Preconditions.checkArgument(
+                setSnapshotId == null || pickSnapshotId == null,
+                "Cannot set the current snapshot ID and cherry-pick snapshot changes");
+
+        if (setSnapshotId != null) {
+            long newSnapshotId = Long.parseLong(setSnapshotId);
+            table.manageSnapshots().setCurrentSnapshot(newSnapshotId).commit();
+        }
+
+        // if updating the table snapshot, perform that update first in case it fails
+        if (pickSnapshotId != null) {
+            long newSnapshotId = Long.parseLong(pickSnapshotId);
+            table.manageSnapshots().cherrypick(newSnapshotId).commit();
+        }
+
+        Transaction transaction = table.newTransaction();
+
+        if (setLocation != null) {
+            transaction.updateLocation().setLocation(setLocation).commit();
+        }
+
+        if (!setProperties.isEmpty()) {
+            UpdateProperties updateProperties = transaction.updateProperties();
+            setProperties.forEach(
+                    (k, v) -> {
+                        if (v == null) {
+                            updateProperties.remove(k);
+                        } else {
+                            updateProperties.set(k, v);
+                        }
+                    });
+            updateProperties.commit();
+        }
+
+        transaction.commitTransaction();
+    }
+
+    static CatalogTable toCatalogTable(Table table) {
+        TableSchema schema = FlinkSchemaUtil.toSchema(table.schema());
+        List<String> partitionKeys = toPartitionKeys(table.spec(), table.schema());
+
+        // NOTE: We can not create a IcebergCatalogTable extends CatalogTable, because Flink optimizer
+        // may use
+        // CatalogTableImpl to copy a new catalog table.
+        // Let's re-loading table from Iceberg catalog when creating source/sink operators.
+        // Iceberg does not have Table comment, so pass a null (Default comment value in Flink).
+        return new CatalogTableImpl(schema, partitionKeys, table.properties(), null);
+    }
+
     @Override
     public Optional<Factory> getFactory() {
         return Optional.of(new FlinkDynamicTableFactory(this));
@@ -568,7 +625,8 @@ public class FlinkCatalog extends AbstractCatalog {
         return catalogLoader;
     }
 
-    // ------------------------------ Unsupported methods ---------------------------------------------
+    // ------------------------------ Unsupported methods
+    // ---------------------------------------------
 
     @Override
     public List<String> listViews(String databaseName) throws CatalogException {
@@ -582,25 +640,35 @@ public class FlinkCatalog extends AbstractCatalog {
     }
 
     @Override
-    public boolean partitionExists(ObjectPath tablePath, CatalogPartitionSpec partitionSpec) throws CatalogException {
-        throw new UnsupportedOperationException();
-    }
-
-    @Override
-    public void createPartition(ObjectPath tablePath, CatalogPartitionSpec partitionSpec, CatalogPartition partition,
-            boolean ignoreIfExists) throws CatalogException {
-        throw new UnsupportedOperationException();
-    }
-
-    @Override
-    public void dropPartition(ObjectPath tablePath, CatalogPartitionSpec partitionSpec, boolean ignoreIfNotExists)
+    public boolean partitionExists(ObjectPath tablePath, CatalogPartitionSpec partitionSpec)
             throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
     @Override
-    public void alterPartition(ObjectPath tablePath, CatalogPartitionSpec partitionSpec, CatalogPartition newPartition,
-            boolean ignoreIfNotExists) throws CatalogException {
+    public void createPartition(
+            ObjectPath tablePath,
+            CatalogPartitionSpec partitionSpec,
+            CatalogPartition partition,
+            boolean ignoreIfExists)
+            throws CatalogException {
+        throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public void dropPartition(
+            ObjectPath tablePath, CatalogPartitionSpec partitionSpec, boolean ignoreIfNotExists)
+            throws CatalogException {
+        throw new UnsupportedOperationException();
+    }
+
+    @Override
+    public void alterPartition(
+            ObjectPath tablePath,
+            CatalogPartitionSpec partitionSpec,
+            CatalogPartition newPartition,
+            boolean ignoreIfNotExists)
+            throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
@@ -610,7 +678,8 @@ public class FlinkCatalog extends AbstractCatalog {
     }
 
     @Override
-    public CatalogFunction getFunction(ObjectPath functionPath) throws FunctionNotExistException, CatalogException {
+    public CatalogFunction getFunction(ObjectPath functionPath)
+            throws FunctionNotExistException, CatalogException {
         throw new FunctionNotExistException(getName(), functionPath);
     }
 
@@ -620,13 +689,15 @@ public class FlinkCatalog extends AbstractCatalog {
     }
 
     @Override
-    public void createFunction(ObjectPath functionPath, CatalogFunction function, boolean ignoreIfExists)
+    public void createFunction(
+            ObjectPath functionPath, CatalogFunction function, boolean ignoreIfExists)
             throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
     @Override
-    public void alterFunction(ObjectPath functionPath, CatalogFunction newFunction, boolean ignoreIfNotExists)
+    public void alterFunction(
+            ObjectPath functionPath, CatalogFunction newFunction, boolean ignoreIfNotExists)
             throws CatalogException {
         throw new UnsupportedOperationException();
     }
@@ -638,26 +709,36 @@ public class FlinkCatalog extends AbstractCatalog {
     }
 
     @Override
-    public void alterTableStatistics(ObjectPath tablePath, CatalogTableStatistics tableStatistics,
-            boolean ignoreIfNotExists) throws CatalogException {
+    public void alterTableStatistics(
+            ObjectPath tablePath, CatalogTableStatistics tableStatistics, boolean ignoreIfNotExists)
+            throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
     @Override
-    public void alterTableColumnStatistics(ObjectPath tablePath, CatalogColumnStatistics columnStatistics,
-            boolean ignoreIfNotExists) throws CatalogException {
+    public void alterTableColumnStatistics(
+            ObjectPath tablePath, CatalogColumnStatistics columnStatistics, boolean ignoreIfNotExists)
+            throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
     @Override
-    public void alterPartitionStatistics(ObjectPath tablePath, CatalogPartitionSpec partitionSpec,
-            CatalogTableStatistics partitionStatistics, boolean ignoreIfNotExists) throws CatalogException {
+    public void alterPartitionStatistics(
+            ObjectPath tablePath,
+            CatalogPartitionSpec partitionSpec,
+            CatalogTableStatistics partitionStatistics,
+            boolean ignoreIfNotExists)
+            throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
     @Override
-    public void alterPartitionColumnStatistics(ObjectPath tablePath, CatalogPartitionSpec partitionSpec,
-            CatalogColumnStatistics columnStatistics, boolean ignoreIfNotExists) throws CatalogException {
+    public void alterPartitionColumnStatistics(
+            ObjectPath tablePath,
+            CatalogPartitionSpec partitionSpec,
+            CatalogColumnStatistics columnStatistics,
+            boolean ignoreIfNotExists)
+            throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
@@ -682,31 +763,32 @@ public class FlinkCatalog extends AbstractCatalog {
                 set.add(new CatalogPartitionSpec(map));
             }
         } catch (IOException e) {
-            throw new CatalogException(String.format("Failed to list partitions of table %s", tablePath), e);
+            throw new CatalogException(
+                    String.format("Failed to list partitions of table %s", tablePath), e);
         }
 
         return Lists.newArrayList(set);
     }
 
     @Override
-    public List<CatalogPartitionSpec> listPartitions(ObjectPath tablePath, CatalogPartitionSpec partitionSpec)
-            throws CatalogException {
+    public List<CatalogPartitionSpec> listPartitions(
+            ObjectPath tablePath, CatalogPartitionSpec partitionSpec) throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
     @Override
-    public List<CatalogPartitionSpec> listPartitionsByFilter(ObjectPath tablePath, List<Expression> filters)
-            throws CatalogException {
+    public List<CatalogPartitionSpec> listPartitionsByFilter(
+            ObjectPath tablePath, List<Expression> filters) throws CatalogException {
         throw new UnsupportedOperationException();
     }
 
-    // After partition pruning and filter push down, the statistics have become very inaccurate, so the statistics from
+    // After partition pruning and filter push down, the statistics have become very inaccurate, so
+    // the statistics from
     // here are of little significance.
     // Flink will support something like SupportsReportStatistics in future.
 
     @Override
-    public CatalogTableStatistics getTableStatistics(ObjectPath tablePath)
-            throws CatalogException {
+    public CatalogTableStatistics getTableStatistics(ObjectPath tablePath) throws CatalogException {
         return CatalogTableStatistics.UNKNOWN;
     }
 
@@ -717,15 +799,14 @@ public class FlinkCatalog extends AbstractCatalog {
     }
 
     @Override
-    public CatalogTableStatistics getPartitionStatistics(ObjectPath tablePath, CatalogPartitionSpec partitionSpec)
-            throws CatalogException {
+    public CatalogTableStatistics getPartitionStatistics(
+            ObjectPath tablePath, CatalogPartitionSpec partitionSpec) throws CatalogException {
         return CatalogTableStatistics.UNKNOWN;
     }
 
     @Override
-    public CatalogColumnStatistics getPartitionColumnStatistics(ObjectPath tablePath,
-            CatalogPartitionSpec partitionSpec)
-            throws CatalogException {
+    public CatalogColumnStatistics getPartitionColumnStatistics(
+            ObjectPath tablePath, CatalogPartitionSpec partitionSpec) throws CatalogException {
         return CatalogColumnStatistics.UNKNOWN;
     }
 }
