@@ -17,8 +17,7 @@
 
 package org.apache.inlong.sort.jdbc.converter.clickhouse;
 
-import org.apache.inlong.sort.jdbc.converter.AbstractJdbcRowConverter;
-
+import org.apache.flink.connector.jdbc.converter.AbstractJdbcRowConverter;
 import org.apache.flink.table.types.logical.RowType;
 
 /**
