@@ -17,30 +17,22 @@
 
 package org.apache.inlong.sort.kafka.table;
 
-import org.apache.inlong.sort.base.dirty.DirtyOptions;
-import org.apache.inlong.sort.base.dirty.sink.DirtySink;
-import org.apache.inlong.sort.base.dirty.utils.DirtySinkFactoryUtils;
-import org.apache.inlong.sort.kafka.KafkaDynamicSink;
-import org.apache.inlong.sort.kafka.partitioner.SingleTableCustomFieldsPartitioner;
-import org.apache.inlong.sort.protocol.enums.SchemaChangePolicy;
-import org.apache.inlong.sort.protocol.enums.SchemaChangeType;
-import org.apache.inlong.sort.util.SchemaChangeUtils;
+import org.apache.inlong.sort.base.Constants;
+import org.apache.inlong.sort.base.metric.MetricOption;
 
 import org.apache.flink.api.common.serialization.DeserializationSchema;
 import org.apache.flink.api.common.serialization.SerializationSchema;
 import org.apache.flink.api.java.tuple.Tuple2;
 import org.apache.flink.configuration.ConfigOption;
-import org.apache.flink.configuration.ConfigOptions;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.configuration.ReadableConfig;
+import org.apache.flink.connector.base.DeliveryGuarantee;
 import org.apache.flink.streaming.connectors.kafka.config.StartupMode;
-import org.apache.flink.streaming.connectors.kafka.partitioner.FlinkKafkaPartitioner;
-import org.apache.flink.streaming.connectors.kafka.table.KafkaOptions;
-import org.apache.flink.streaming.connectors.kafka.table.KafkaSinkSemantic;
+import org.apache.flink.streaming.connectors.kafka.table.KafkaConnectorOptions;
 import org.apache.flink.streaming.connectors.kafka.table.SinkBufferFlushMode;
-import org.apache.flink.table.api.TableSchema;
 import org.apache.flink.table.api.ValidationException;
-import org.apache.flink.table.catalog.CatalogTable;
+import org.apache.flink.table.catalog.ResolvedCatalogTable;
+import org.apache.flink.table.catalog.ResolvedSchema;
 import org.apache.flink.table.connector.ChangelogMode;
 import org.apache.flink.table.connector.format.DecodingFormat;
 import org.apache.flink.table.connector.format.EncodingFormat;
@@ -60,72 +52,214 @@ import java.time.Duration;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Objects;
-import java.util.Optional;
 import java.util.Properties;
 import java.util.Set;
 
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.KEY_FIELDS;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.KEY_FIELDS_PREFIX;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.KEY_FORMAT;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.PROPS_BOOTSTRAP_SERVERS;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.SINK_BUFFER_FLUSH_INTERVAL;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.SINK_BUFFER_FLUSH_MAX_ROWS;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.SINK_PARTITIONER;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.TOPIC;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.VALUE_FIELDS_INCLUDE;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.VALUE_FORMAT;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.autoCompleteSchemaRegistrySubject;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.createKeyFormatProjection;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.createValueFormatProjection;
-import static org.apache.flink.streaming.connectors.kafka.table.KafkaOptions.getKafkaProperties;
-import static org.apache.inlong.sort.base.Constants.AUDIT_KEYS;
-import static org.apache.inlong.sort.base.Constants.DIRTY_PREFIX;
-import static org.apache.inlong.sort.base.Constants.INLONG_AUDIT;
-import static org.apache.inlong.sort.base.Constants.INLONG_METRIC;
-import static org.apache.inlong.sort.base.Constants.SINK_MULTIPLE_FORMAT;
-import static org.apache.inlong.sort.base.Constants.SINK_SCHEMA_CHANGE_ENABLE;
-import static org.apache.inlong.sort.base.Constants.SINK_SCHEMA_CHANGE_POLICIES;
-import static org.apache.inlong.sort.kafka.table.KafkaDynamicTableFactory.SINK_PARTITIONER_VALUE_PRIMARY_KEY;
-import static org.apache.inlong.sort.kafka.table.KafkaOptions.KAFKA_IGNORE_ALL_CHANGELOG;
+import static org.apache.flink.streaming.connectors.kafka.table.KafkaConnectorOptions.*;
+import static org.apache.inlong.sort.base.Constants.*;
+import static org.apache.inlong.sort.kafka.table.KafkaConnectorOptionsUtil.PROPERTIES_PREFIX;
+import static org.apache.inlong.sort.kafka.table.KafkaConnectorOptionsUtil.autoCompleteSchemaRegistrySubject;
+import static org.apache.inlong.sort.kafka.table.KafkaConnectorOptionsUtil.createKeyFormatProjection;
+import static org.apache.inlong.sort.kafka.table.KafkaConnectorOptionsUtil.createValueFormatProjection;
+import static org.apache.inlong.sort.kafka.table.KafkaConnectorOptionsUtil.getKafkaProperties;
+import static org.apache.inlong.sort.kafka.table.KafkaConnectorOptionsUtil.getSourceTopicPattern;
+import static org.apache.inlong.sort.kafka.table.KafkaConnectorOptionsUtil.getSourceTopics;
 
-/**
- * Copy from org.apache.flink:flink-connector-kafka_2.11:1.13.5
- *
- * Upsert-Kafka factory.
- * Add an option `inlong.metric` to support metrics.
- */
-public class UpsertKafkaDynamicTableFactory
-        implements
-            DynamicTableSourceFactory,
-            DynamicTableSinkFactory {
+/** Upsert-Kafka factory.
+ * <p>
+ * Copy from org.apache.flink:flink-connector-kafka:1.15.4
+ * */
+public class UpsertKafkaDynamicTableFactory implements DynamicTableSourceFactory, DynamicTableSinkFactory {
 
     public static final String IDENTIFIER = "upsert-kafka-inlong";
-    public static final ConfigOption<String> SINK_MULTIPLE_PARTITION_PATTERN =
-            ConfigOptions.key("sink.multiple.partition-pattern")
-                    .stringType()
-                    .noDefaultValue()
-                    .withDescription(
-                            "option 'sink.multiple.partition-pattern' used either when the partitioner is raw-hash, or when passing in designated partition field names for custom field partitions");
 
-    public static final ConfigOption<String> SINK_FIXED_IDENTIFIER =
-            ConfigOptions.key("sink.fixed.identifier")
-                    .stringType()
-                    .defaultValue("-1");
+    @Override
+    public String factoryIdentifier() {
+        return IDENTIFIER;
+    }
+
+    @Override
+    public Set<ConfigOption<?>> requiredOptions() {
+        final Set<ConfigOption<?>> options = new HashSet<>();
+        options.add(PROPS_BOOTSTRAP_SERVERS);
+        options.add(TOPIC);
+        options.add(KEY_FORMAT);
+        options.add(VALUE_FORMAT);
+        return options;
+    }
+
+    @Override
+    public Set<ConfigOption<?>> optionalOptions() {
+        final Set<ConfigOption<?>> options = new HashSet<>();
+        options.add(KEY_FIELDS_PREFIX);
+        options.add(VALUE_FIELDS_INCLUDE);
+        options.add(SINK_PARALLELISM);
+        options.add(SINK_BUFFER_FLUSH_INTERVAL);
+        options.add(SINK_BUFFER_FLUSH_MAX_ROWS);
+        options.add(Constants.INLONG_METRIC);
+        options.add(KafkaOptions.KAFKA_IGNORE_ALL_CHANGELOG);
+        options.add(KafkaOptions.SINK_MULTIPLE_PARTITION_PATTERN);
+        options.add(KafkaOptions.SINK_FIXED_IDENTIFIER);
+        options.add(KafkaConnectorOptions.SINK_PARTITIONER);
+        return options;
+    }
+
+    @Override
+    public DynamicTableSource createDynamicTableSource(Context context) {
+        FactoryUtil.TableFactoryHelper helper = FactoryUtil.createTableFactoryHelper(this, context);
+
+        ReadableConfig tableOptions = helper.getOptions();
+        DecodingFormat<DeserializationSchema<RowData>> keyDecodingFormat =
+                helper.discoverDecodingFormat(DeserializationFormatFactory.class, KEY_FORMAT);
+        DecodingFormat<DeserializationSchema<RowData>> valueDecodingFormat =
+                helper.discoverDecodingFormat(DeserializationFormatFactory.class, VALUE_FORMAT);
+
+        // Validate the option data type.
+        helper.validateExcept(PROPERTIES_PREFIX, Constants.DIRTY_PREFIX);
+        validateSource(
+                tableOptions,
+                keyDecodingFormat,
+                valueDecodingFormat,
+                context.getPrimaryKeyIndexes());
+
+        Tuple2<int[], int[]> keyValueProjections =
+                createKeyValueProjections(context.getCatalogTable());
+        String keyPrefix = tableOptions.getOptional(KEY_FIELDS_PREFIX).orElse(null);
+        Properties properties = getKafkaProperties(context.getCatalogTable().getOptions());
+        // always use earliest to keep data integrity
+        StartupMode earliest = StartupMode.EARLIEST;
+
+        String inlongMetric = tableOptions.getOptional(INLONG_METRIC).orElse(null);
+        String auditHostAndPorts = tableOptions.get(INLONG_AUDIT);
+        String auditKeys = tableOptions.get(AUDIT_KEYS);
+        Boolean enableLogReport = context.getConfiguration().get(ENABLE_LOG_REPORT);
+        MetricOption metricOption = MetricOption.builder()
+                .withInlongLabels(inlongMetric)
+                .withAuditAddress(auditHostAndPorts)
+                .withAuditKeys(auditKeys)
+                .build();
+
+        return new KafkaDynamicSource(
+                context.getPhysicalRowDataType(),
+                keyDecodingFormat,
+                new DecodingFormatWrapper(valueDecodingFormat),
+                keyValueProjections.f0,
+                keyValueProjections.f1,
+                keyPrefix,
+                getSourceTopics(tableOptions),
+                getSourceTopicPattern(tableOptions),
+                properties,
+                earliest,
+                Collections.emptyMap(),
+                0,
+                true,
+                context.getObjectIdentifier().asSummaryString(),
+                metricOption,
+                enableLogReport);
+    }
+
+    @Override
+    public DynamicTableSink createDynamicTableSink(Context context) {
+        FactoryUtil.TableFactoryHelper helper =
+                FactoryUtil.createTableFactoryHelper(
+                        this, autoCompleteSchemaRegistrySubject(context));
+
+        final ReadableConfig tableOptions = helper.getOptions();
+
+        EncodingFormat<SerializationSchema<RowData>> keyEncodingFormat =
+                helper.discoverEncodingFormat(SerializationFormatFactory.class, KEY_FORMAT);
+        EncodingFormat<SerializationSchema<RowData>> valueEncodingFormat =
+                helper.discoverEncodingFormat(SerializationFormatFactory.class, VALUE_FORMAT);
+
+        // Validate the option data type.
+        helper.validateExcept(PROPERTIES_PREFIX);
+        validateSink(
+                tableOptions,
+                keyEncodingFormat,
+                valueEncodingFormat,
+                context.getPrimaryKeyIndexes());
+
+        Tuple2<int[], int[]> keyValueProjections =
+                createKeyValueProjections(context.getCatalogTable());
+        final String keyPrefix = tableOptions.getOptional(KEY_FIELDS_PREFIX).orElse(null);
+        final Properties properties = getKafkaProperties(context.getCatalogTable().getOptions());
+
+        Integer parallelism = tableOptions.get(SINK_PARALLELISM);
+
+        int batchSize = tableOptions.get(SINK_BUFFER_FLUSH_MAX_ROWS);
+        Duration batchInterval = tableOptions.get(SINK_BUFFER_FLUSH_INTERVAL);
+        SinkBufferFlushMode flushMode =
+                new SinkBufferFlushMode(batchSize, batchInterval.toMillis());
+
+        String inlongMetric = tableOptions.getOptional(INLONG_METRIC).orElse(null);
+        String auditHostAndPorts = tableOptions.get(INLONG_AUDIT);
+        String auditKeys = tableOptions.get(AUDIT_KEYS);
+
+        MetricOption metricOption = MetricOption.builder()
+                .withInlongLabels(inlongMetric)
+                .withAuditAddress(auditHostAndPorts)
+                .withAuditKeys(auditKeys)
+                .build();
+        // use {@link org.apache.kafka.clients.producer.internals.DefaultPartitioner}.
+        // it will use hash partition if key is set else in round-robin behaviour.
+        return new KafkaDynamicSink(
+                context.getPhysicalRowDataType(),
+                context.getPhysicalRowDataType(),
+                keyEncodingFormat,
+                new EncodingFormatWrapper(valueEncodingFormat),
+                keyValueProjections.f0,
+                keyValueProjections.f1,
+                keyPrefix,
+                tableOptions.get(TOPIC).get(0),
+                properties,
+                null,
+                DeliveryGuarantee.AT_LEAST_ONCE,
+                true,
+                flushMode,
+                parallelism,
+                tableOptions.get(TRANSACTIONAL_ID_PREFIX),
+                metricOption);
+    }
+
+    private Tuple2<int[], int[]> createKeyValueProjections(ResolvedCatalogTable catalogTable) {
+        ResolvedSchema schema = catalogTable.getResolvedSchema();
+        // primary key should validated earlier
+        List<String> keyFields = schema.getPrimaryKey().get().getColumns();
+        DataType physicalDataType = schema.toPhysicalRowDataType();
+
+        Configuration tableOptions = Configuration.fromMap(catalogTable.getOptions());
+        // upsert-kafka will set key.fields to primary key fields by default
+        tableOptions.set(KEY_FIELDS, keyFields);
+
+        int[] keyProjection = createKeyFormatProjection(tableOptions, physicalDataType);
+        int[] valueProjection = createValueFormatProjection(tableOptions, physicalDataType);
+
+        return Tuple2.of(keyProjection, valueProjection);
+    }
+
+    // --------------------------------------------------------------------------------------------
+    // Validation
+    // --------------------------------------------------------------------------------------------
 
     private static void validateSource(
-            ReadableConfig tableOptions, Format keyFormat, Format valueFormat, TableSchema schema) {
+            ReadableConfig tableOptions,
+            Format keyFormat,
+            Format valueFormat,
+            int[] primaryKeyIndexes) {
         validateTopic(tableOptions);
         validateFormat(keyFormat, valueFormat, tableOptions);
-        validatePKConstraints(schema);
+        validatePKConstraints(primaryKeyIndexes);
     }
 
     private static void validateSink(
-            ReadableConfig tableOptions, Format keyFormat, Format valueFormat, TableSchema schema) {
+            ReadableConfig tableOptions,
+            Format keyFormat,
+            Format valueFormat,
+            int[] primaryKeyIndexes) {
         validateTopic(tableOptions);
         validateFormat(keyFormat, valueFormat, tableOptions);
-        validatePKConstraints(schema);
+        validatePKConstraints(primaryKeyIndexes);
         validateSinkBufferFlush(tableOptions);
     }
 
@@ -158,14 +292,12 @@ public class UpsertKafkaDynamicTableFactory
         }
     }
 
-    private static void validatePKConstraints(TableSchema schema) {
-        if (!schema.getPrimaryKey().isPresent()) {
+    private static void validatePKConstraints(int[] schema) {
+        if (schema.length == 0) {
             throw new ValidationException(
                     "'upsert-kafka' tables require to define a PRIMARY KEY constraint. "
-                            + "The PRIMARY KEY specifies which columns should be read from "
-                            + "or write to the Kafka message key. "
-                            + "The PRIMARY KEY also defines records in the 'upsert-kafka' table "
-                            + "should update or delete on which keys.");
+                            + "The PRIMARY KEY specifies which columns should be read from or write to the Kafka message key. "
+                            + "The PRIMARY KEY also defines records in the 'upsert-kafka' table should update or delete on which keys.");
         }
     }
 
@@ -187,193 +319,6 @@ public class UpsertKafkaDynamicTableFactory
                         SINK_BUFFER_FLUSH_MAX_ROWS.key(), SINK_BUFFER_FLUSH_INTERVAL.key()));
     }
 
-    // --------------------------------------------------------------------------------------------
-    // Validation
-    // --------------------------------------------------------------------------------------------
-
-    @Override
-    public String factoryIdentifier() {
-        return IDENTIFIER;
-    }
-
-    @Override
-    public Set<ConfigOption<?>> requiredOptions() {
-        final Set<ConfigOption<?>> options = new HashSet<>();
-        options.add(PROPS_BOOTSTRAP_SERVERS);
-        options.add(TOPIC);
-        options.add(KEY_FORMAT);
-        options.add(VALUE_FORMAT);
-        return options;
-    }
-
-    @Override
-    public Set<ConfigOption<?>> optionalOptions() {
-        final Set<ConfigOption<?>> options = new HashSet<>();
-        options.add(KEY_FIELDS_PREFIX);
-        options.add(VALUE_FIELDS_INCLUDE);
-        options.add(FactoryUtil.SINK_PARALLELISM);
-        options.add(SINK_BUFFER_FLUSH_INTERVAL);
-        options.add(SINK_BUFFER_FLUSH_MAX_ROWS);
-        options.add(KAFKA_IGNORE_ALL_CHANGELOG);
-        options.add(INLONG_METRIC);
-        options.add(SINK_PARTITIONER);
-        options.add(SINK_MULTIPLE_PARTITION_PATTERN);
-        options.add(SINK_FIXED_IDENTIFIER);
-        return options;
-    }
-
-    @Override
-    public DynamicTableSource createDynamicTableSource(Context context) {
-        FactoryUtil.TableFactoryHelper helper = FactoryUtil.createTableFactoryHelper(this, context);
-
-        ReadableConfig tableOptions = helper.getOptions();
-        DecodingFormat<DeserializationSchema<RowData>> keyDecodingFormat =
-                helper.discoverDecodingFormat(DeserializationFormatFactory.class, KEY_FORMAT);
-        DecodingFormat<DeserializationSchema<RowData>> valueDecodingFormat =
-                helper.discoverDecodingFormat(DeserializationFormatFactory.class, VALUE_FORMAT);
-
-        // Validate the option data type.
-        helper.validateExcept(KafkaOptions.PROPERTIES_PREFIX, DIRTY_PREFIX);
-        TableSchema schema = context.getCatalogTable().getSchema();
-        validateSource(tableOptions, keyDecodingFormat, valueDecodingFormat, schema);
-
-        Tuple2<int[], int[]> keyValueProjections =
-                createKeyValueProjections(context.getCatalogTable());
-        String keyPrefix = tableOptions.getOptional(KEY_FIELDS_PREFIX).orElse(null);
-        Properties properties = getKafkaProperties(context.getCatalogTable().getOptions());
-        // always use earliest to keep data integrity
-        StartupMode earliest = StartupMode.EARLIEST;
-        // Build the dirty data side-output
-        final DirtyOptions dirtyOptions = DirtyOptions.fromConfig(tableOptions);
-        final DirtySink<String> dirtySink = DirtySinkFactoryUtils.createDirtySink(context, dirtyOptions);
-        final String inlongMetric = tableOptions.getOptional(INLONG_METRIC).orElse(null);
-        final String auditHostAndPorts = tableOptions.getOptional(INLONG_AUDIT).orElse(null);
-        final String auditKeys = tableOptions.getOptional(AUDIT_KEYS).orElse(null);
-        return new KafkaDynamicSource(
-                schema.toPhysicalRowDataType(),
-                keyDecodingFormat,
-                new DecodingFormatWrapper(valueDecodingFormat),
-                keyValueProjections.f0,
-                keyValueProjections.f1,
-                keyPrefix,
-                KafkaOptions.getSourceTopics(tableOptions),
-                KafkaOptions.getSourceTopicPattern(tableOptions),
-                properties,
-                earliest,
-                Collections.emptyMap(),
-                0,
-                true,
-                inlongMetric,
-                auditHostAndPorts,
-                dirtyOptions,
-                dirtySink,
-                auditKeys);
-    }
-
-    private Optional<FlinkKafkaPartitioner<RowData>> getFlinkKafkaPartitioner(
-            ReadableConfig tableOptions, ClassLoader classLoader, TableSchema schema) {
-        if (tableOptions.getOptional(SINK_PARTITIONER).isPresent()
-                && SINK_PARTITIONER_VALUE_PRIMARY_KEY.equals(tableOptions.getOptional(SINK_PARTITIONER).get())) {
-            SingleTableCustomFieldsPartitioner<RowData> customFieldsPartitioner =
-                    new SingleTableCustomFieldsPartitioner<>();
-            customFieldsPartitioner.setPartitionNumber(tableOptions.getOptional(SINK_FIXED_IDENTIFIER).orElse(null));
-            customFieldsPartitioner.setPartitionKey(tableOptions.getOptional(SINK_MULTIPLE_PARTITION_PATTERN)
-                    .orElse(null));
-            customFieldsPartitioner.setSchema(schema);
-            return Optional.of(customFieldsPartitioner);
-        }
-        Optional<FlinkKafkaPartitioner<RowData>> partitioner = KafkaOptions
-                .getFlinkKafkaPartitioner(tableOptions, classLoader);
-        return partitioner;
-    }
-
-    @Override
-    public DynamicTableSink createDynamicTableSink(Context context) {
-        FactoryUtil.TableFactoryHelper helper =
-                FactoryUtil.createTableFactoryHelper(
-                        this, autoCompleteSchemaRegistrySubject(context));
-
-        final ReadableConfig tableOptions = helper.getOptions();
-
-        EncodingFormat<SerializationSchema<RowData>> keyEncodingFormat =
-                helper.discoverEncodingFormat(SerializationFormatFactory.class, KEY_FORMAT);
-        EncodingFormat<SerializationSchema<RowData>> valueEncodingFormat =
-                helper.discoverEncodingFormat(SerializationFormatFactory.class, VALUE_FORMAT);
-
-        // Validate the option data type.
-        helper.validateExcept(KafkaOptions.PROPERTIES_PREFIX, DIRTY_PREFIX);
-        TableSchema schema = context.getCatalogTable().getSchema();
-        validateSink(tableOptions, keyEncodingFormat, valueEncodingFormat, schema);
-
-        Tuple2<int[], int[]> keyValueProjections =
-                createKeyValueProjections(context.getCatalogTable());
-        final String keyPrefix = tableOptions.getOptional(KEY_FIELDS_PREFIX).orElse(null);
-        final Properties properties = getKafkaProperties(context.getCatalogTable().getOptions());
-
-        Integer parallelism = tableOptions.get(FactoryUtil.SINK_PARALLELISM);
-
-        int batchSize = tableOptions.get(SINK_BUFFER_FLUSH_MAX_ROWS);
-        Duration batchInterval = tableOptions.get(SINK_BUFFER_FLUSH_INTERVAL);
-        SinkBufferFlushMode flushMode =
-                new SinkBufferFlushMode(batchSize, batchInterval.toMillis());
-        String inlongMetric = tableOptions.getOptional(INLONG_METRIC).orElse(null);
-        final String auditHostAndPorts = tableOptions.getOptional(INLONG_AUDIT).orElse(null);
-        // Build the dirty data side-output
-        final DirtyOptions dirtyOptions = DirtyOptions.fromConfig(tableOptions);
-        final DirtySink<Object> dirtySink = DirtySinkFactoryUtils.createDirtySink(context, dirtyOptions);
-        final boolean multipleSink = tableOptions.getOptional(SINK_MULTIPLE_FORMAT).isPresent();
-        final String schemaChangePolicies = tableOptions.getOptional(SINK_SCHEMA_CHANGE_POLICIES).orElse(null);
-        final boolean enableSchemaChange = tableOptions.get(SINK_SCHEMA_CHANGE_ENABLE);
-        final Map<SchemaChangeType, SchemaChangePolicy> policyMap =
-                enableSchemaChange ? SchemaChangeUtils.deserialize(schemaChangePolicies) : Collections.emptyMap();
-        final FlinkKafkaPartitioner<RowData> partitioner =
-                getFlinkKafkaPartitioner(tableOptions, context.getClassLoader(),
-                        context.getCatalogTable().getSchema()).orElse(null);
-
-        // use {@link org.apache.kafka.clients.producer.internals.DefaultPartitioner}.
-        // it will use hash partition if key is set else in round-robin behaviour.
-        return new KafkaDynamicSink(
-                schema.toPhysicalRowDataType(),
-                schema.toPhysicalRowDataType(),
-                keyEncodingFormat,
-                new EncodingFormatWrapper(valueEncodingFormat),
-                keyValueProjections.f0,
-                keyValueProjections.f1,
-                keyPrefix,
-                tableOptions.get(TOPIC).get(0),
-                properties,
-                context.getCatalogTable(),
-                partitioner,
-                KafkaSinkSemantic.AT_LEAST_ONCE,
-                true,
-                flushMode,
-                parallelism,
-                inlongMetric,
-                auditHostAndPorts,
-                null,
-                null,
-                dirtyOptions,
-                dirtySink,
-                multipleSink,
-                policyMap);
-    }
-
-    private Tuple2<int[], int[]> createKeyValueProjections(CatalogTable catalogTable) {
-        TableSchema schema = catalogTable.getSchema();
-        // primary key should validated earlier
-        List<String> keyFields = schema.getPrimaryKey().get().getColumns();
-        DataType physicalDataType = schema.toPhysicalRowDataType();
-
-        Configuration tableOptions = Configuration.fromMap(catalogTable.getOptions());
-        // upsert-kafka will set key.fields to primary key fields by default
-        tableOptions.set(KEY_FIELDS, keyFields);
-
-        int[] keyProjection = createKeyFormatProjection(tableOptions, physicalDataType);
-        int[] valueProjection = createValueFormatProjection(tableOptions, physicalDataType);
-
-        return Tuple2.of(keyProjection, valueProjection);
-    }
-
     // --------------------------------------------------------------------------------------------
     // Format wrapper
     // --------------------------------------------------------------------------------------------
@@ -386,12 +331,13 @@ public class UpsertKafkaDynamicTableFactory
             implements
                 DecodingFormat<DeserializationSchema<RowData>> {
 
+        private final DecodingFormat<DeserializationSchema<RowData>> innerDecodingFormat;
+
         private static final ChangelogMode SOURCE_CHANGELOG_MODE =
                 ChangelogMode.newBuilder()
                         .addContainedKind(RowKind.UPDATE_AFTER)
                         .addContainedKind(RowKind.DELETE)
                         .build();
-        private final DecodingFormat<DeserializationSchema<RowData>> innerDecodingFormat;
 
         public DecodingFormatWrapper(
                 DecodingFormat<DeserializationSchema<RowData>> innerDecodingFormat) {
@@ -437,13 +383,14 @@ public class UpsertKafkaDynamicTableFactory
             implements
                 EncodingFormat<SerializationSchema<RowData>> {
 
+        private final EncodingFormat<SerializationSchema<RowData>> innerEncodingFormat;
+
         public static final ChangelogMode SINK_CHANGELOG_MODE =
                 ChangelogMode.newBuilder()
                         .addContainedKind(RowKind.INSERT)
                         .addContainedKind(RowKind.UPDATE_AFTER)
                         .addContainedKind(RowKind.DELETE)
                         .build();
-        private final EncodingFormat<SerializationSchema<RowData>> innerEncodingFormat;
 
         public EncodingFormatWrapper(
                 EncodingFormat<SerializationSchema<RowData>> innerEncodingFormat) {
