@@ -17,9 +17,9 @@
 
 package org.apache.inlong.sort.mysql;
 
+import org.apache.inlong.sort.base.metric.CdcExactlyMetric;
 import org.apache.inlong.sort.base.metric.MetricOption;
 import org.apache.inlong.sort.base.metric.MetricsCollector;
-import org.apache.inlong.sort.base.metric.SourceExactlyMetric;
 
 import com.ververica.cdc.debezium.DebeziumDeserializationSchema;
 import com.ververica.cdc.debezium.table.AppendMetadataCollector;
@@ -102,7 +102,7 @@ public final class RowDataDebeziumDeserializeSchema implements DebeziumDeseriali
 
     /** Changelog Mode to use for encoding changes in Flink internal data structure. */
     private final DebeziumChangelogMode changelogMode;
-    private SourceExactlyMetric sourceExactlyMetric;
+    private CdcExactlyMetric cdcExactlyMetric;
     private final MetricOption metricOption;
 
     /** Returns a builder to build {@link RowDataDebeziumDeserializeSchema}. */
@@ -137,21 +137,19 @@ public final class RowDataDebeziumDeserializeSchema implements DebeziumDeseriali
         Envelope.Operation op = Envelope.operationFor(record);
         Struct value = (Struct) record.value();
         Schema valueSchema = record.valueSchema();
+        if (cdcExactlyMetric != null) {
+            out = createMetricsCollector(record, out);
+        }
+
         if (op == Envelope.Operation.CREATE || op == Envelope.Operation.READ) {
             GenericRowData insert = extractAfterRow(value, valueSchema);
             validator.validate(insert, RowKind.INSERT);
             insert.setRowKind(RowKind.INSERT);
-            if (sourceExactlyMetric != null) {
-                out = createMetricsCollector(record, out);
-            }
             emit(record, insert, out);
         } else if (op == Envelope.Operation.DELETE) {
             GenericRowData delete = extractBeforeRow(value, valueSchema);
             validator.validate(delete, RowKind.DELETE);
             delete.setRowKind(RowKind.DELETE);
-            if (sourceExactlyMetric != null) {
-                out = createMetricsCollector(record, out);
-            }
             emit(record, delete, out);
         } else {
             if (changelogMode == DebeziumChangelogMode.ALL) {
@@ -164,9 +162,6 @@ public final class RowDataDebeziumDeserializeSchema implements DebeziumDeseriali
             GenericRowData after = extractAfterRow(value, valueSchema);
             validator.validate(after, RowKind.UPDATE_AFTER);
             after.setRowKind(RowKind.UPDATE_AFTER);
-            if (sourceExactlyMetric != null) {
-                out = createMetricsCollector(record, out);
-            }
             emit(record, after, out);
         }
     }
@@ -178,7 +173,7 @@ public final class RowDataDebeziumDeserializeSchema implements DebeziumDeseriali
      * @return metrics collector
      */
     private Collector<RowData> createMetricsCollector(SourceRecord record, Collector<RowData> out) {
-        MetricsCollector<RowData> collector = new MetricsCollector<>(out, sourceExactlyMetric);
+        MetricsCollector<RowData> collector = new MetricsCollector<>(out, cdcExactlyMetric);
         collector.resetTimestamp((Long) ((Struct) record.value()).get(FieldName.TIMESTAMP));
         return collector;
     }
@@ -190,7 +185,7 @@ public final class RowDataDebeziumDeserializeSchema implements DebeziumDeseriali
      */
     public void initSourceMetricData() {
         if (metricOption != null) {
-            this.sourceExactlyMetric = new SourceExactlyMetric(metricOption);
+            this.cdcExactlyMetric = new CdcExactlyMetric(metricOption);
         }
     }
 
@@ -222,20 +217,20 @@ public final class RowDataDebeziumDeserializeSchema implements DebeziumDeseriali
     }
 
     public void flushAudit() {
-        if (sourceExactlyMetric != null) {
-            sourceExactlyMetric.flushAudit();
+        if (cdcExactlyMetric != null) {
+            cdcExactlyMetric.flushAudit();
         }
     }
 
     public void updateCurrentCheckpointId(long checkpointId) {
-        if (sourceExactlyMetric != null) {
-            sourceExactlyMetric.updateCurrentCheckpointId(checkpointId);
+        if (cdcExactlyMetric != null) {
+            cdcExactlyMetric.updateCurrentCheckpointId(checkpointId);
         }
     }
 
     public void updateLastCheckpointId(long checkpointId) {
-        if (sourceExactlyMetric != null) {
-            sourceExactlyMetric.updateLastCheckpointId(checkpointId);
+        if (cdcExactlyMetric != null) {
+            cdcExactlyMetric.updateLastCheckpointId(checkpointId);
         }
     }
     // -------------------------------------------------------------------------------------
