@@ -17,23 +17,21 @@
 
 package org.apache.inlong.sort.kafka.table;
 
-import org.apache.inlong.sort.base.metric.MetricOption;
 import org.apache.inlong.sort.kafka.source.KafkaSource;
 import org.apache.inlong.sort.kafka.source.KafkaSourceBuilder;
-import org.apache.inlong.sort.kafka.table.DynamicKafkaDeserializationSchema.MetadataConverter;
-import org.apache.inlong.sort.protocol.node.ExtractNode;
 
-import org.apache.flink.annotation.Internal;
 import org.apache.flink.api.common.eventtime.WatermarkStrategy;
 import org.apache.flink.api.common.serialization.DeserializationSchema;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.connector.source.Boundedness;
+import org.apache.flink.connector.kafka.source.enumerator.initializer.NoStoppingOffsetsInitializer;
 import org.apache.flink.connector.kafka.source.enumerator.initializer.OffsetsInitializer;
 import org.apache.flink.connector.kafka.source.reader.deserializer.KafkaRecordDeserializationSchema;
 import org.apache.flink.streaming.api.datastream.DataStream;
 import org.apache.flink.streaming.api.datastream.DataStreamSource;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
 import org.apache.flink.streaming.connectors.kafka.KafkaDeserializationSchema;
+import org.apache.flink.streaming.connectors.kafka.config.BoundedMode;
 import org.apache.flink.streaming.connectors.kafka.config.StartupMode;
 import org.apache.flink.streaming.connectors.kafka.internals.KafkaTopicPartition;
 import org.apache.flink.table.api.DataTypes;
@@ -76,11 +74,10 @@ import java.util.stream.Collectors;
 import java.util.stream.IntStream;
 import java.util.stream.Stream;
 
-/** A version-agnostic Kafka {@link ScanTableSource}.
- * <p>
- * Copy from org.apache.flink:flink-connector-kafka:1.15.4
- * */
-@Internal
+/**
+ * A version-agnostic Kafka {@link ScanTableSource}.
+ * org.apache.flink:flink-connector-kafka:3.2.0
+ */
 public class KafkaDynamicSource
         implements
             ScanTableSource,
@@ -93,13 +90,19 @@ public class KafkaDynamicSource
     // Mutable attributes
     // --------------------------------------------------------------------------------------------
 
-    /** Data type that describes the final output of the source. */
+    /**
+     * Data type that describes the final output of the source.
+     */
     protected DataType producedDataType;
 
-    /** Metadata that is appended at the end of a physical source row. */
+    /**
+     * Metadata that is appended at the end of a physical source row.
+     */
     protected List<String> metadataKeys;
 
-    /** Watermark strategy that is used to generate per-partition watermark. */
+    /**
+     * Watermark strategy that is used to generate per-partition watermark.
+     */
     protected @Nullable WatermarkStrategy<RowData> watermarkStrategy;
 
     // --------------------------------------------------------------------------------------------
@@ -108,39 +111,57 @@ public class KafkaDynamicSource
 
     private static final String VALUE_METADATA_PREFIX = "value.";
 
-    /** Data type to configure the formats. */
+    /**
+     * Data type to configure the formats.
+     */
     protected final DataType physicalDataType;
 
-    /** Optional format for decoding keys from Kafka. */
+    /**
+     * Optional format for decoding keys from Kafka.
+     */
     protected final @Nullable DecodingFormat<DeserializationSchema<RowData>> keyDecodingFormat;
 
-    /** Format for decoding values from Kafka. */
+    /**
+     * Format for decoding values from Kafka.
+     */
     protected final DecodingFormat<DeserializationSchema<RowData>> valueDecodingFormat;
 
-    /** Indices that determine the key fields and the target position in the produced row. */
+    /**
+     * Indices that determine the key fields and the target position in the produced row.
+     */
     protected final int[] keyProjection;
 
-    /** Indices that determine the value fields and the target position in the produced row. */
+    /**
+     * Indices that determine the value fields and the target position in the produced row.
+     */
     protected final int[] valueProjection;
 
-    /** Prefix that needs to be removed from fields when constructing the physical data type. */
+    /**
+     * Prefix that needs to be removed from fields when constructing the physical data type.
+     */
     protected final @Nullable String keyPrefix;
 
     // --------------------------------------------------------------------------------------------
     // Kafka-specific attributes
     // --------------------------------------------------------------------------------------------
 
-    /** The Kafka topics to consume. */
+    /**
+     * The Kafka topics to consume.
+     */
     protected final List<String> topics;
 
-    /** The Kafka topic pattern to consume. */
+    /**
+     * The Kafka topic pattern to consume.
+     */
     protected final Pattern topicPattern;
 
-    /** Properties for the Kafka consumer. */
+    /**
+     * Properties for the Kafka consumer.
+     */
     protected final Properties properties;
 
     /**
-     * The startup mode for the contained consumer (default is {StartupMode#GROUP_OFFSETS}).
+     * The startup mode for the contained consumer (default is {@link StartupMode#GROUP_OFFSETS}).
      */
     protected final StartupMode startupMode;
 
@@ -156,13 +177,30 @@ public class KafkaDynamicSource
      */
     protected final long startupTimestampMillis;
 
-    /** Flag to determine source mode. In upsert mode, it will keep the tombstone message. * */
+    /**
+     * The bounded mode for the contained consumer (default is an unbounded data stream).
+     */
+    protected final BoundedMode boundedMode;
+
+    /**
+     * Specific end offsets; only relevant when bounded mode is {@link
+     * BoundedMode#SPECIFIC_OFFSETS}.
+     */
+    protected final Map<KafkaTopicPartition, Long> specificBoundedOffsets;
+
+    /**
+     * The bounded timestamp to locate partition offsets; only relevant when bounded mode is {@link
+     * BoundedMode#TIMESTAMP}.
+     */
+    protected final long boundedTimestampMillis;
+
+    /**
+     * Flag to determine source mode. In upsert mode, it will keep the tombstone message. *
+     */
     protected final boolean upsertMode;
 
     protected final String tableIdentifier;
 
-    private final MetricOption metricOption;
-
     public KafkaDynamicSource(
             DataType physicalDataType,
             @Nullable DecodingFormat<DeserializationSchema<RowData>> keyDecodingFormat,
@@ -176,9 +214,11 @@ public class KafkaDynamicSource
             StartupMode startupMode,
             Map<KafkaTopicPartition, Long> specificStartupOffsets,
             long startupTimestampMillis,
+            BoundedMode boundedMode,
+            Map<KafkaTopicPartition, Long> specificBoundedOffsets,
+            long boundedTimestampMillis,
             boolean upsertMode,
-            String tableIdentifier,
-            MetricOption metricOption) {
+            String tableIdentifier) {
         // Format attributes
         this.physicalDataType =
                 Preconditions.checkNotNull(
@@ -210,9 +250,14 @@ public class KafkaDynamicSource
                 Preconditions.checkNotNull(
                         specificStartupOffsets, "Specific offsets must not be null.");
         this.startupTimestampMillis = startupTimestampMillis;
+        this.boundedMode =
+                Preconditions.checkNotNull(boundedMode, "Bounded mode must not be null.");
+        this.specificBoundedOffsets =
+                Preconditions.checkNotNull(
+                        specificBoundedOffsets, "Specific bounded offsets must not be null.");
+        this.boundedTimestampMillis = boundedTimestampMillis;
         this.upsertMode = upsertMode;
         this.tableIdentifier = tableIdentifier;
-        this.metricOption = metricOption;
     }
 
     @Override
@@ -326,9 +371,11 @@ public class KafkaDynamicSource
                         startupMode,
                         specificStartupOffsets,
                         startupTimestampMillis,
+                        boundedMode,
+                        specificBoundedOffsets,
+                        boundedTimestampMillis,
                         upsertMode,
-                        tableIdentifier,
-                        metricOption);
+                        tableIdentifier);
         copy.producedDataType = producedDataType;
         copy.metadataKeys = metadataKeys;
         copy.watermarkStrategy = watermarkStrategy;
@@ -363,10 +410,12 @@ public class KafkaDynamicSource
                 && startupMode == that.startupMode
                 && Objects.equals(specificStartupOffsets, that.specificStartupOffsets)
                 && startupTimestampMillis == that.startupTimestampMillis
+                && boundedMode == that.boundedMode
+                && Objects.equals(specificBoundedOffsets, that.specificBoundedOffsets)
+                && boundedTimestampMillis == that.boundedTimestampMillis
                 && Objects.equals(upsertMode, that.upsertMode)
                 && Objects.equals(tableIdentifier, that.tableIdentifier)
-                && Objects.equals(watermarkStrategy, that.watermarkStrategy)
-                && Objects.equals(metricOption, that.metricOption);
+                && Objects.equals(watermarkStrategy, that.watermarkStrategy);
     }
 
     @Override
@@ -377,8 +426,8 @@ public class KafkaDynamicSource
                 physicalDataType,
                 keyDecodingFormat,
                 valueDecodingFormat,
-                keyProjection,
-                valueProjection,
+                Arrays.hashCode(keyProjection),
+                Arrays.hashCode(valueProjection),
                 keyPrefix,
                 topics,
                 topicPattern,
@@ -386,10 +435,12 @@ public class KafkaDynamicSource
                 startupMode,
                 specificStartupOffsets,
                 startupTimestampMillis,
+                boundedMode,
+                specificBoundedOffsets,
+                boundedTimestampMillis,
                 upsertMode,
                 tableIdentifier,
-                watermarkStrategy,
-                metricOption);
+                watermarkStrategy);
     }
 
     // --------------------------------------------------------------------------------------------
@@ -440,10 +491,34 @@ public class KafkaDynamicSource
                         OffsetsInitializer.timestamp(startupTimestampMillis));
                 break;
         }
+
+        switch (boundedMode) {
+            case UNBOUNDED:
+                kafkaSourceBuilder.setUnbounded(new NoStoppingOffsetsInitializer());
+                break;
+            case LATEST:
+                kafkaSourceBuilder.setBounded(OffsetsInitializer.latest());
+                break;
+            case GROUP_OFFSETS:
+                kafkaSourceBuilder.setBounded(OffsetsInitializer.committedOffsets());
+                break;
+            case SPECIFIC_OFFSETS:
+                Map<TopicPartition, Long> offsets = new HashMap<>();
+                specificBoundedOffsets.forEach(
+                        (tp, offset) -> offsets.put(
+                                new TopicPartition(tp.getTopic(), tp.getPartition()),
+                                offset));
+                kafkaSourceBuilder.setBounded(OffsetsInitializer.offsets(offsets));
+                break;
+            case TIMESTAMP:
+                kafkaSourceBuilder.setBounded(OffsetsInitializer.timestamp(boundedTimestampMillis));
+                break;
+        }
+
         kafkaSourceBuilder
                 .setProperties(properties)
-                .setDeserializer(KafkaRecordDeserializationSchema.of(kafkaDeserializer))
-                .setMetricSchema(kafkaDeserializer);
+                .setDeserializer(KafkaRecordDeserializationSchema.of(kafkaDeserializer));
+
         return kafkaSourceBuilder.build();
     }
 
@@ -467,7 +542,7 @@ public class KafkaDynamicSource
             DeserializationSchema<RowData> keyDeserialization,
             DeserializationSchema<RowData> valueDeserialization,
             TypeInformation<RowData> producedTypeInfo) {
-        final MetadataConverter[] metadataConverters =
+        final DynamicKafkaDeserializationSchema.MetadataConverter[] metadataConverters =
                 metadataKeys.stream()
                         .map(
                                 k -> Stream.of(ReadableMetadata.values())
@@ -475,7 +550,7 @@ public class KafkaDynamicSource
                                         .findFirst()
                                         .orElseThrow(IllegalStateException::new))
                         .map(m -> m.converter)
-                        .toArray(MetadataConverter[]::new);
+                        .toArray(DynamicKafkaDeserializationSchema.MetadataConverter[]::new);
 
         // check if connector metadata is used at all
         final boolean hasMetadata = metadataKeys.size() > 0;
@@ -492,6 +567,7 @@ public class KafkaDynamicSource
                                 keyProjection.length + valueProjection.length,
                                 adjustedPhysicalArity))
                         .toArray();
+
         return new DynamicKafkaDeserializationSchema(
                 adjustedPhysicalArity,
                 keyDeserialization,
@@ -501,13 +577,11 @@ public class KafkaDynamicSource
                 hasMetadata,
                 metadataConverters,
                 producedTypeInfo,
-                upsertMode,
-                metricOption,
-                metadataKeys);
+                upsertMode);
     }
 
     private @Nullable DeserializationSchema<RowData> createDeserialization(
-            Context context,
+            DynamicTableSource.Context context,
             @Nullable DecodingFormat<DeserializationSchema<RowData>> format,
             int[] projection,
             @Nullable String prefix) {
@@ -530,7 +604,7 @@ public class KafkaDynamicSource
         TOPIC(
                 "topic",
                 DataTypes.STRING().notNull(),
-                new MetadataConverter() {
+                new DynamicKafkaDeserializationSchema.MetadataConverter() {
 
                     private static final long serialVersionUID = 1L;
 
@@ -543,7 +617,7 @@ public class KafkaDynamicSource
         PARTITION(
                 "partition",
                 DataTypes.INT().notNull(),
-                new MetadataConverter() {
+                new DynamicKafkaDeserializationSchema.MetadataConverter() {
 
                     private static final long serialVersionUID = 1L;
 
@@ -558,7 +632,7 @@ public class KafkaDynamicSource
                 // key and value of the map are nullable to make handling easier in queries
                 DataTypes.MAP(DataTypes.STRING().nullable(), DataTypes.BYTES().nullable())
                         .notNull(),
-                new MetadataConverter() {
+                new DynamicKafkaDeserializationSchema.MetadataConverter() {
 
                     private static final long serialVersionUID = 1L;
 
@@ -575,7 +649,7 @@ public class KafkaDynamicSource
         LEADER_EPOCH(
                 "leader-epoch",
                 DataTypes.INT().nullable(),
-                new MetadataConverter() {
+                new DynamicKafkaDeserializationSchema.MetadataConverter() {
 
                     private static final long serialVersionUID = 1L;
 
@@ -588,7 +662,7 @@ public class KafkaDynamicSource
         OFFSET(
                 "offset",
                 DataTypes.BIGINT().notNull(),
-                new MetadataConverter() {
+                new DynamicKafkaDeserializationSchema.MetadataConverter() {
 
                     private static final long serialVersionUID = 1L;
 
@@ -601,7 +675,7 @@ public class KafkaDynamicSource
         TIMESTAMP(
                 "timestamp",
                 DataTypes.TIMESTAMP_WITH_LOCAL_TIME_ZONE(3).notNull(),
-                new MetadataConverter() {
+                new DynamicKafkaDeserializationSchema.MetadataConverter() {
 
                     private static final long serialVersionUID = 1L;
 
@@ -614,7 +688,7 @@ public class KafkaDynamicSource
         TIMESTAMP_TYPE(
                 "timestamp-type",
                 DataTypes.STRING().notNull(),
-                new MetadataConverter() {
+                new DynamicKafkaDeserializationSchema.MetadataConverter() {
 
                     private static final long serialVersionUID = 1L;
 
@@ -622,27 +696,15 @@ public class KafkaDynamicSource
                     public Object read(ConsumerRecord<?, ?> record) {
                         return StringData.fromString(record.timestampType().toString());
                     }
-                }),
-        CONSUME_TIME(
-                ExtractNode.CONSUME_AUDIT_TIME,
-                DataTypes.BIGINT().notNull(),
-                new MetadataConverter() {
-
-                    private static final long serialVersionUID = 1L;
-
-                    @Override
-                    public Object read(ConsumerRecord<?, ?> record) {
-                        return System.currentTimeMillis();
-                    }
                 });
 
         final String key;
 
         final DataType dataType;
 
-        final MetadataConverter converter;
+        final DynamicKafkaDeserializationSchema.MetadataConverter converter;
 
-        ReadableMetadata(String key, DataType dataType, MetadataConverter converter) {
+        ReadableMetadata(String key, DataType dataType, DynamicKafkaDeserializationSchema.MetadataConverter converter) {
             this.key = key;
             this.dataType = dataType;
             this.converter = converter;
