@@ -60,6 +60,7 @@ import org.apache.inlong.common.pojo.sort.dataflow.field.format.VarBinaryFormatI
 import org.apache.inlong.common.pojo.sort.dataflow.field.format.VarCharFormatInfo;
 import org.apache.inlong.sort.formats.inlongmsg.FailureHandler;
 
+import org.apache.commons.lang3.StringUtils;
 import org.apache.flink.api.common.typeinfo.TypeInformation;
 import org.apache.flink.api.common.typeinfo.Types;
 import org.apache.flink.table.api.DataTypes;
@@ -582,6 +583,35 @@ public class TableFormatUtils {
         return null;
     }
 
+    public static long getFormatValueLength(FormatInfo fieldFormatInfo, String fieldText) {
+        if (fieldFormatInfo instanceof BooleanFormatInfo) {
+            return 4;
+        } else if (fieldFormatInfo instanceof ByteFormatInfo) {
+            return 4;
+        } else if (fieldFormatInfo instanceof BooleanFormatInfo) {
+            return 4;
+        } else if (fieldFormatInfo instanceof ShortFormatInfo) {
+            return 4;
+        } else if (fieldFormatInfo instanceof IntFormatInfo) {
+            return 4;
+        } else if (fieldFormatInfo instanceof LongFormatInfo) {
+            return 8;
+        } else if (fieldFormatInfo instanceof FloatFormatInfo) {
+            return 8;
+        } else if (fieldFormatInfo instanceof DoubleFormatInfo) {
+            return 8;
+        } else if (fieldFormatInfo instanceof DecimalFormatInfo) {
+            return 8;
+        } else if (fieldFormatInfo instanceof DateFormatInfo
+                || fieldFormatInfo instanceof TimeFormatInfo
+                || fieldFormatInfo instanceof TimestampFormatInfo) {
+            return 8;
+        } else if (StringUtils.isNotEmpty(fieldText)) {
+            return fieldText.length();
+        }
+        return 0L;
+    }
+
     /**
      * Serializes the basic field.
      */
