@@ -21,6 +21,7 @@ import org.apache.inlong.common.pojo.sort.dataflow.field.format.FormatInfo;
 import org.apache.inlong.common.pojo.sort.dataflow.field.format.RowFormatInfo;
 import org.apache.inlong.sort.formats.base.FieldToRowDataConverters;
 import org.apache.inlong.sort.formats.base.FieldToRowDataConverters.FieldToRowDataConverter;
+import org.apache.inlong.sort.formats.base.FormatMsg;
 import org.apache.inlong.sort.formats.inlongmsg.FailureHandler;
 import org.apache.inlong.sort.formats.inlongmsg.InLongMsgBody;
 import org.apache.inlong.sort.formats.inlongmsg.InLongMsgHead;
@@ -38,6 +39,7 @@ import java.util.Map;
 import java.util.stream.Collectors;
 
 import static org.apache.inlong.sort.formats.base.TableFormatUtils.deserializeBasicField;
+import static org.apache.inlong.sort.formats.base.TableFormatUtils.getFormatValueLength;
 import static org.apache.inlong.sort.formats.inlongmsg.InLongMsgUtils.INLONGMSG_ATTR_INTERFACE_ID;
 import static org.apache.inlong.sort.formats.inlongmsg.InLongMsgUtils.INLONGMSG_ATTR_INTERFACE_NAME;
 import static org.apache.inlong.sort.formats.inlongmsg.InLongMsgUtils.INLONGMSG_ATTR_INTERFACE_TID;
@@ -129,7 +131,7 @@ public class InLongMsgCsvUtils {
                 }).collect(Collectors.toList());
     }
 
-    public static GenericRowData deserializeRowData(
+    public static FormatMsg deserializeFormatMsgData(
             RowFormatInfo rowFormatInfo,
             String nullLiteral,
             List<String> predefinedFields,
@@ -139,13 +141,67 @@ public class InLongMsgCsvUtils {
         String[] fieldNames = rowFormatInfo.getFieldNames();
         FormatInfo[] fieldFormatInfos = rowFormatInfo.getFieldFormatInfos();
 
-        int actualNumFields = predefinedFields.size() + fields.size();
-        if (actualNumFields != fieldNames.length) {
-            LOG.warn("The number of fields mismatches: expected={}, actual={}. " +
-                    "PredefinedFields=[{}], Fields=[{}]", fieldNames.length, actualNumFields,
-                    predefinedFields, fields);
+        GenericRowData rowData = new GenericRowData(fieldNames.length);
+        long rowDataLength = 0L;
+        // Deserialize pre-defined fields
+        for (int i = 0; i < predefinedFields.size(); ++i) {
+            if (i >= fieldNames.length) {
+                break;
+            }
+
+            String fieldName = fieldNames[i];
+            FormatInfo fieldFormatInfo = fieldFormatInfos[i];
+            FieldToRowDataConverter converter = converters[i];
+            String fieldText = predefinedFields.get(i);
+
+            Object field = converter.convert(deserializeBasicField(
+                    fieldName,
+                    fieldFormatInfo,
+                    fieldText,
+                    nullLiteral, failureHandler));
+            rowData.setField(i, field);
+            rowDataLength += getFormatValueLength(fieldFormatInfo, fieldText);
         }
 
+        // Deserialize fields
+        for (int i = 0; i < fields.size(); ++i) {
+
+            if (i + predefinedFields.size() >= fieldNames.length) {
+                break;
+            }
+
+            String fieldName = fieldNames[i + predefinedFields.size()];
+            FormatInfo fieldFormatInfo = fieldFormatInfos[i + predefinedFields.size()];
+            FieldToRowDataConverter converter = converters[i + predefinedFields.size()];
+            String fieldText = fields.get(i);
+
+            Object field = converter.convert(deserializeBasicField(
+                    fieldName,
+                    fieldFormatInfo,
+                    fieldText,
+                    nullLiteral, failureHandler));
+            rowData.setField(i + predefinedFields.size(), field);
+            rowDataLength += getFormatValueLength(fieldFormatInfo, fieldText);
+        }
+
+        // If schema length is larger than fields' length, use `null` to fill in the blanks
+        for (int i = predefinedFields.size() + fields.size(); i < fieldNames.length; ++i) {
+            rowData.setField(i, null);
+        }
+
+        return new FormatMsg(rowData, rowDataLength);
+    }
+
+    public static GenericRowData deserializeRowData(
+            RowFormatInfo rowFormatInfo,
+            String nullLiteral,
+            List<String> predefinedFields,
+            List<String> fields,
+            FieldToRowDataConverters.FieldToRowDataConverter[] converters,
+            FailureHandler failureHandler) throws Exception {
+        String[] fieldNames = rowFormatInfo.getFieldNames();
+        FormatInfo[] fieldFormatInfos = rowFormatInfo.getFieldFormatInfos();
+
         GenericRowData rowData = new GenericRowData(fieldNames.length);
 
         // Deserialize pre-defined fields
