@@ -47,13 +47,13 @@ import static org.junit.Assert.assertNull;
 public class TableFormatUtilsTest {
 
     @Test
-    public void testDeserializeStringWithoutNullLiteral() {
+    public void testDeserializeStringWithoutNullLiteral() throws Exception {
         Object result1 =
                 deserializeBasicField(
                         "f",
                         StringFormatInfo.INSTANCE,
                         "data",
-                        null);
+                        null, null);
         assertEquals("data", result1);
 
         Object result2 =
@@ -61,7 +61,7 @@ public class TableFormatUtilsTest {
                         "f",
                         StringFormatInfo.INSTANCE,
                         "",
-                        null);
+                        null, null);
         assertEquals("", result2);
     }
 
@@ -85,13 +85,13 @@ public class TableFormatUtilsTest {
     }
 
     @Test
-    public void testDeserializeStringWithNullLiteral() {
+    public void testDeserializeStringWithNullLiteral() throws Exception {
         Object result1 =
                 deserializeBasicField(
                         "f",
                         StringFormatInfo.INSTANCE,
                         "data",
-                        "n/a");
+                        "n/a", null);
         assertEquals("data", result1);
 
         Object result2 =
@@ -99,7 +99,7 @@ public class TableFormatUtilsTest {
                         "f",
                         StringFormatInfo.INSTANCE,
                         "",
-                        "n/a");
+                        "n/a", null);
         assertEquals("", result2);
 
         Object result3 =
@@ -107,7 +107,7 @@ public class TableFormatUtilsTest {
                         "f",
                         StringFormatInfo.INSTANCE,
                         "n/a",
-                        "n/a");
+                        "n/a", null);
         assertNull(result3);
     }
 
@@ -139,13 +139,13 @@ public class TableFormatUtilsTest {
     }
 
     @Test
-    public void testDeserializeNumberWithoutNullLiteral() {
+    public void testDeserializeNumberWithoutNullLiteral() throws Exception {
         Object result1 =
                 deserializeBasicField(
                         "f",
                         IntFormatInfo.INSTANCE,
                         "1",
-                        null);
+                        null, null);
         assertEquals(1, result1);
 
         Object result2 =
@@ -153,7 +153,7 @@ public class TableFormatUtilsTest {
                         "f",
                         IntFormatInfo.INSTANCE,
                         "",
-                        null);
+                        null, null);
         assertNull(result2);
     }
 
@@ -177,13 +177,13 @@ public class TableFormatUtilsTest {
     }
 
     @Test
-    public void testDeserializeNumberWithNullLiteral() {
+    public void testDeserializeNumberWithNullLiteral() throws Exception {
         Object result1 =
                 deserializeBasicField(
                         "f",
                         IntFormatInfo.INSTANCE,
                         "1",
-                        "n/a");
+                        "n/a", null);
         assertEquals(1, result1);
 
         try {
@@ -191,7 +191,7 @@ public class TableFormatUtilsTest {
                     "f",
                     IntFormatInfo.INSTANCE,
                     "",
-                    "n/a");
+                    "n/a", null);
 
             assertNull(result2);
         } catch (Exception e) {
@@ -203,7 +203,7 @@ public class TableFormatUtilsTest {
                         "f",
                         IntFormatInfo.INSTANCE,
                         "n/a",
-                        "n/a");
+                        "n/a", null);
         assertNull(result3);
     }
 
