@@ -20,8 +20,8 @@ base_dir=$(dirname $0)
 
 # Prepare common dependency
 ROOT_DIR=$base_dir/../..
-if [ -e $ROOT_DIR/bin/prepare_module_dependencys.sh ]; then
-    $ROOT_DIR/bin/prepare_module_dependencys.sh ./inlong-tubemq-manager/lib
+if [ -e $ROOT_DIR/bin/prepare_module_dependencies.sh ]; then
+    $ROOT_DIR/bin/prepare_module_dependencies.sh ./inlong-tubemq-manager/lib
 fi
 
 DAEMON_NAME=${DAEMON_NAME:-"tubemq-manager"}
